nil subclass: #Object
instanceVariableNames: ''
classVariableNames: ''
!
Object class
!
new
  ^ self basicNew
!
Object
!
addEvent: aString action: aBlock
  Handler on: self event: aString block: aBlock
!
asConsOrAtom
  ^ self
!
asObject
   ^ self
!
asString
   ^ self printString
!
debug
  Debugger open
!
debug: nr
   Transcript showCr: 'Here : ' + nr asString
!
defaultInspector
  ^ DefaultInspector
!
doesNotUnderstand: aMessage
  Transcript showCr: self printString + ' does not understand ' + aMessage printString
!
inspect
  self defaultInspector openOn: self
!
isArray
   ^ false
!
isBehavior
   ^ false
!
isBigInteger
   ^ false
!
isBoolean
   ^ false
!
isButton
   ^ false
!
isDictionary
   ^ false
!
isDouble
   ^ false
!
isFloat
   ^ false
!
isInteger
   ^ false
!
isList
   ^ false
!
isMemberOf: aClass 
   ^ self class == aClass
!
isNil
   ^ false
!
isNumber
   ^ false
!
isString
   ^ false
!
isSystemDictionary
   ^ false
!
notNil
   ^ true
!
performArray: anArray
  self perform: anArray first asSymbol withArguments: anArray withoutFirst
!
performArrayIndirect: anArray
  (Smalltalk at: anArray first asSymbol) perform: anArray second asSymbol
                                   withArguments: anArray withoutFirst2
!
printString
  <primitive: 'object tostring'>
!
readSite: aFile
  self readSite: aFile callback: [:response | self onReadResponse: response]
!
readSite: aFile callback: aBlock
  | php |
  php := PhpConnect new.
  php url: 'http://vistascript.net/vistascript/docuwiki/' + aFile.
  php callback: aBlock.
  php serialized: false.
  php queryServer: ''
!
readWiki: aFile
  self readWiki: aFile replace: ''
!
readWiki: aFile callback: aBlock
  self readWiki: aFile replace: '' callback: aBlock
!
readWiki: aFile replace: aString
  self readWiki: aFile replace: aString callback: [:response | self onWikiResponse: response]
!
readWiki: aFile replace: aString callback: aBlock
  | php |
  php := PhpConnect new.
  php url: 'http://vistascript.net/vistascript/docuwiki/load.php'.
  php callback: aBlock.
  php serialized: false.
  php queryServer: 'file=' + aFile + '&replace=' + aString
!
show: aString
   Transcript showCr: aString asString
!
sleep: milliseconds
  Processor currentProcess sleep: milliseconds
!
topWindowClass
  Vm virtualDesktop
    ifTrue: [^ DesktopWindow]
    ifFalse: [^ Window]
!
value
  ^ self
!
yield
  Processor currentProcess yield
!
yourself
   ^ self
!
Object subclass: #Behavior
instanceVariableNames: 'instanceVariables methodDict superclass'
classVariableNames: ''
maps: 'vbehavior'
!
Behavior
!
addSubclass: aString
   <primitive: 'vbehavior addsubclass string'>
!
hasSelector: aSymbol
   <primitive: 'vbehavior hasselector vsymbol'>
!
inheritsFrom: aClass 
   | aSuperclass |
   aSuperclass := self superclass.
   [aSuperclass == nil] whileFalse: [
      aSuperclass == aClass ifTrue: [^ true].
      aSuperclass := aSuperclass superclass].
   ^false
!
instanceVariables 
   <primitive: 'vbehavior getinstancevariables'>
!
isBehavior
   ^ true
!
lookupSelector: aSymbol
   <primitive: 'vbehavior lookupselector vsymbol'>
!
method: aString
   <primitive: 'vbehavior lookupselector string'>
!
methodDictionary
   <primitive: 'vbehavior getmethoddictionary'>
!
methodSelectors
   <primitive: 'vbehavior getmethodselectors'>
!
methodSelectorsSorted
   | methods |
   methods := self methodSelectors toArrayList.
   methods sort.
   ^ methods toArray
!
removeMethod: aSymbol
   <primitive: 'vbehavior removemethod vsymbol'>
!
superclass
   <primitive: 'vbehavior getsuperclass'>
!
Behavior subclass: #Class
instanceVariableNames: 'name subclasses'
classVariableNames: ''
maps: 'vclass'
!
Class class
!
allClassesAndMetaClasses
  | classes metaclasses |
  classes := Object withAllSubclasses.
  metaclasses := classes collect:[:cls | cls class].
  classes addList: metaclasses.
  ^ classes
!
template
   ^ ' subclass: #NameOfSubclass
      instanceVariableNames: ''''
      classVariableNames: '''''
!
Class
!
mapType
   <primitive: 'vclass getmaptype'>
!
name
   <primitive: 'vclass name'>
!
new
   <primitive: 'vclass createinstance'>
!
remove
   <primitive: 'vclass remove'>
!
storeString
   <primitive: 'vclass storestring'>
!
subclasses
   <primitive: 'vclass getsubclasses'>
!
withAllSubclasses
  | list |
  list := List new.
  self withAllSubclasses: list.
  list sort.
  ^ list
!
withAllSubclasses: aList
  aList add: self.
  self subclasses do:[:cls | cls withAllSubclasses: aList]
!
Behavior subclass: #MetaClass
instanceVariableNames: 'thisClass'
classVariableNames: ''
maps: 'vmetaclass'
!
MetaClass
!
thisClass
   <primitive: 'vmetaclass getthisclass'>
!
Object subclass: #Boolean
instanceVariableNames: ''
classVariableNames: ''
!
Boolean
!
==> aBlock
    "this is material implication, a ==> b, also known as:
	    b if a 
	    a implies b
	    if a then b
	    b is a consequence of a
	    a therefore b (but note: 'it is raining therefore it is cloudy' is implication;
                                    'it is autumn therefore the leaves are falling' is equivalence).
		
    Here is the truth table for material implication (view in a monospaced font):
	
    p   |   q   |   p ==> q
    -------|-------|-------------
    T   |   T   |      T
    T   |   F   |      F
    F   |   T   |      T
    F   |   F   |      T
    "

    ^self not or: [aBlock value]
!
and: block1 and: block2
  self ifFalse: [^ false].
  block1 value ifFalse: [^ false].
  block2 value ifFalse: [^ false].
  ^ true
!
and: block1 and: block2 and: block3
  self ifFalse: [^ false].
  block1 value ifFalse: [^ false].
  block2 value ifFalse: [^ false].
  block3 value ifFalse: [^ false].
  ^ true
!
and: block1 and: block2 and: block3 and: block4
  self ifFalse: [^ false].
  block1 value ifFalse: [^ false].
  block2 value ifFalse: [^ false].
  block3 value ifFalse: [^ false].
  block4 value ifFalse: [^ false].
  ^ true
!
and: block1 and: block2 and: block3 and: block4 and: block5
  self ifFalse: [^ false].
  block1 value ifFalse: [^ false].
  block2 value ifFalse: [^ false].
  block3 value ifFalse: [^ false].
  block4 value ifFalse: [^ false].
  block5 value ifFalse: [^ false].
  ^ true
!
eqv: aBoolean 
  "Answer true if the receiver is equivalent to aBoolean."
  ^self == aBoolean
!
isBoolean
 ^ true
!
or: block1 or: block2
  self ifTrue: [^ true].
  block1 value ifTrue: [^ true].
  block2 value ifTrue: [^ true].
  ^ false
!
or: block1 or: block2 or: block3
  self ifTrue: [^ true].
  block1 value ifTrue: [^ true].
  block2 value ifTrue: [^ true].
  block3 value ifTrue: [^ true].
  ^ false
!
or: block1 or: block2 or: block3 or: block4
 self ifTrue: [^ true].
 block1 value ifTrue: [^ true].
 block2 value ifTrue: [^ true].
 block3 value ifTrue: [^ true].
 block4 value ifTrue: [^ true].
 ^ false
!
or: block1 or: block2 or: block3 or: block4 or: block5
  self ifTrue: [^ true].
  block1 value ifTrue: [^ true].
  block2 value ifTrue: [^ true].
  block3 value ifTrue: [^ true].
  block4 value ifTrue: [^ true].
  block5 value ifTrue: [^ true].
  ^ false
!
xor: aBoolean 
  "Exclusive OR. Answer true if the receiver is not equivalent to aBoolean."  
  ^(self == aBoolean) not
!
Boolean subclass: #False
instanceVariableNames: ''
classVariableNames: ''
!
False
!
& aBoolean 
  "Evaluating conjunction -- answer false since receiver is false."
  ^self
!
| aBoolean 
  "Evaluating disjunction (OR) -- answer with the argument, aBoolean."
  ^aBoolean
!
and: aBoolean
  ^ self
!
asBit
  ^0
!
not
  ^ true
!
or: anObject
  ^ anObject value
!
Boolean subclass: #True
instanceVariableNames: ''
classVariableNames: ''
!
True
!
& aBoolean 
  "Evaluating conjunction -- answer aBoolean since receiver is true."
  ^aBoolean
!
| aBoolean 
  "Evaluating disjunction (OR) -- answer true since the receiver is true."
  ^self
!
and: anObject
  ^ anObject value
!
asBit
  ^1
!
not
  ^ false
!
or: anObject
  ^ self
!
Object subclass: #CalmoSoft
instanceVariableNames: ''
classVariableNames: ''
!
CalmoSoft class
!
copyright
   "   ~  written by: Gal Zsolt & Cathlyn Cosca ( CalmoSoft ) ~ 2006-2007 ~ calmosoft@gmail.com ~   "
!
CalmoSoft
!
debug: nr
   Transcript showCr: 'Here : ' + nr asString
!
show: aString
   Transcript showCr: aString asString
!
stringToEval
  | evalString |
  evalString := '$eval Transcript cr' +
                Environment newLine +
                '$eval Transcript showCr: ''CalmoSoft Project for Vista Smalltalk''' +
                Environment newLine +
               '$eval Transcript showCr: ''[build 842] for Aug 30, 2013''' +
                Environment newLine +
                '$eval PowerBrowser new open'.
  ^evalString
!
CalmoSoft subclass: #MethodFinder
instanceVariableNames: 'class methodEditor searchedText treeClassMethods type typeLine window'
classVariableNames: ''
!
MethodFinder class
!
copyright
   "   ~  written by: Gal Zsolt & Cathlyn Cosca ( CalmoSoft ) ~ 2006-2007 ~ calmosoft@gmail.com ~   "
!
MethodFinder
!
makeAbcClasses
  | buttonHeight dock sp |
  buttonHeight := 23.7. 
  dock := window dockpanel2.
  sp := StackPanel vertical.
  button1 := (Button content: 'a' callback: [self showhAbcMethods: 'a']).
  button2 := (Button content: 'b' callback: [self showhAbcMethods: 'b']).
  button3 := (Button content: 'c' callback: [self showhAbcMethods: 'c']).
  button4 := (Button content: 'd' callback: [self showhAbcMethods: 'd']).
  button5 := (Button content: 'e' callback: [self showhAbcMethods: 'e']).
  button6 := (Button content: 'f' callback: [self showhAbcMethods: 'f']).
  button7 := (Button content: 'g' callback: [self showhAbcMethods: 'g']).
  button8 := (Button content: 'h' callback: [self showhAbcMethods: 'h']).
  button9 := (Button content: 'i' callback: [self showhAbcMethods: 'i']).
  button10 := (Button content: 'j' callback: [self showhAbcMethods: 'j']).
  button11 := (Button content: 'k' callback: [self showhAbcMethods: 'k']).
  button12 := (Button content: 'l' callback: [self showhAbcMethods: 'l']).
  button13 := (Button content: 'm' callback: [self showhAbcMethods: 'm']).
  button14 := (Button content: 'n' callback: [self showhAbcMethods: 'n']).
  button15 := (Button content: 'o' callback: [self showhAbcMethods: 'o']).
  button16 := (Button content: 'p' callback: [self showhAbcMethods: 'p']).
  button17 := (Button content: 'q' callback: [self showhAbcMethods: 'q']).
  button18 := (Button content: 'r' callback: [self showhAbcMethods: 'r']).
  button19 := (Button content: 's' callback: [self showhAbcMethods: 's']).
  button20 := (Button content: 't' callback: [self showhAbcMethods: 't']).
  button21 := (Button content: 'u' callback: [self showhAbcMethods: 'u']).
  button22 := (Button content: 'v' callback: [self showhAbcMethods: 'v']).
  button23 := (Button content: 'w' callback: [self showhAbcMethods: 'w']).
  button24 := (Button content: 'x' callback: [self showhAbcMethods: 'x']).
  button25 := (Button content: 'y' callback: [self showhAbcMethods: 'y']).
  button26 := (Button content: 'z' callback: [self showhAbcMethods: 'z']).
  button1 height: buttonHeight.
  button2 height: buttonHeight.
  button3 height: buttonHeight.
  button4 height: buttonHeight.
  button5 height: buttonHeight.
  button6 height: buttonHeight.
  button7 height: buttonHeight.
  button8 height: buttonHeight.
  button9 height: buttonHeight.
  button10 height: buttonHeight.
  button11 height: buttonHeight.
  button12 height: buttonHeight.
  button13 height: buttonHeight.
  button14 height: buttonHeight.
  button15 height: buttonHeight.
  button16 height: buttonHeight.
  button17 height: buttonHeight.
  button18 height: buttonHeight.
  button19 height: buttonHeight.
  button20 height: buttonHeight.
  button21 height: buttonHeight.
  button22 height: buttonHeight.
  button23 height: buttonHeight.
  button24 height: buttonHeight.
  button25 height: buttonHeight.
  button26 height: buttonHeight.
  sp add: button1.
  sp add: button2.
  sp add: button3.
  sp add: button4.
  sp add: button5.
  sp add: button6.
  sp add: button7.
  sp add: button8.
  sp add: button9.
  sp add: button10.
  sp add: button11.
  sp add: button12.
  sp add: button13.
  sp add: button14.
  sp add: button15.
  sp add: button16.
  sp add: button17.
  sp add: button18.
  sp add: button19.
  sp add: button20.
  sp add: button21.
  sp add: button22.
  sp add: button23.
  sp add: button24.
  sp add: button25.
  sp add: button26.
  dock add: sp
!
makeSearch
  | dock sp |
  searchedText := window searchText.
  searchedText textalignment: TextAlignment center. 
  searchedText text: 'type text here to search in methods'.
  dock := window dockpanel.
  sp := StackPanel horizontal.
  sp add: (Button content: ' Search text in methods ' callback: [self searchMethods]).
  sp add: (Button content: ' Show all methods ' callback: [self showAllMethods]).
  dock add: sp
!
open
  "   MethodFinder new open   "
  window := MethodFinderandSystemBrowserLayout new.
  window title: '~~~ MethodFinder for Vista Smalltalk ~~~'.
  treeClassMethods := window treeLeft.
  treeClassMethods background: (SolidColorBrush new: Color customGray).
  methodEditor := window methodTextEditor.
  methodEditor foreground: Brushes navy.
  typeLine := window typeText.
  typeLine textalignment: TextAlignment center. 
  typeLine text: 'information line'.
  Handler on: treeClassMethods event: 'SelectedItemChanged' block: [self showMethod].
  methodEditor showLines: true.
  self makeSearch.
  self makeAbcClasses.
  self setEditorContextMenu.
  self setFontSize.
  window open
!
searchMethods
  | bool1 bool2 method methodClassDict methodDict methodList newMethod newTree nr nrTotal prim rootClass |
  nr := 0.
  nrTotal := 0.
  methodList := List new.
  treeClassMethods items clear.
  methodEditor text: ''.
  typeLine text: 'Loading ...'.
  prim := searchedText text.
  rootClass := Vm rootClass. 
  rootClass withAllSubclasses do:[:cls | methodDict := cls methodDictionary.
                                         methodDict keysDo: [:k | method := cls lookupSelector: k.
                                                                  bool1 := ((method text indexOf: prim start: 0) > 0).
                                                                  bool1 ifTrue: [newMethod := k + '>>' + cls name + '#i'.
                                                                                 methodList add: newMethod]].
                                         methodClassDict := cls class methodDictionary.
                                         methodClassDict keysDo: [:k | method := cls class lookupSelector: k.
                                                                       bool2 := ((method text indexOf: prim start: 0) > 0).
                                                                       bool2 ifTrue: [newMethod := k + '>>' + cls name + '#c'.
                                                                                      methodList add: newMethod]]].    
  methodList sort.
  nrTotal := methodList size.
  nrTotal = 0 ifTrue: [typeLine text: 'no results']
              ifFalse: [methodList do: [:item | nr := nr + 1.
                                                typeLine text: nr asString + ' / ' + nrTotal asString.
                                                newTree := TreeViewItem new.
                                                newTag := item. 
                                                newHeader := item substring: 0 len: (item length - 2).
                                                newTree header: newHeader.
                                                newTree tag: newTag.
                                                treeClassMethods items add: newTree]]
!
setEditorContextMenu
  | menu |
  menu := ContextMenu new.
  menu add: (MenuItem name: 'Save' action: [self textSave]).
  methodEditor contextMenu: menu
!
setFontSize
  | fntsize |
  fntsize := 12.
  treeClassMethods fontsize: fntsize.
  typeLine fontsize: fntsize.
  searchedText fontsize: fntsize
!
showAllMethods
  | methodClassDict methodDict methodList newMethod newTree nr nrTotal rootClass |
  nr := 0.
  nrTotal := 0.
  methodList := List new.
  treeClassMethods items clear.
  methodEditor text: ''.
  typeLine text: 'Loading ...'.
  searchedText text: 'type text here to search in methods'.
  rootClass := Vm rootClass. 
  rootClass withAllSubclasses do:[:cls | methodDict := cls methodDictionary.
                                         methodDict keysDo: [:k | newMethod := k + '>>' + cls name + '#i'.
                                                                  methodList add: newMethod].
                                         methodClassDict := cls class methodDictionary.
                                         methodClassDict keysDo: [:k | newMethod := k + '>>' + cls name + '#c'.
                                                                       methodList add: newMethod]].
  methodList sort.
  nrTotal := methodList size.
  nrTotal = 0 ifTrue: [typeLine text: 'no results']
              ifFalse: [methodList do: [:item | nr := nr + 1.
                                                typeLine text: nr asString + ' / ' + nrTotal asString.
                                                newTree := TreeViewItem new.
                                                newTag := item. 
                                                newHeader := item substring: 0 len: (item length - 2).
                                                newTree header: newHeader.
                                                newTree tag: newTag.
                                                treeClassMethods items add: newTree]]
!
showhAbcMethods: aCharacter
  | bool methodClassDict methodDict methodList newMethod newTree nr nrTotal rootClass |
  nr := 0.
  nrTotal := 0.
  methodList := List new.
  treeClassMethods items clear.
  methodEditor text: ''.
  typeLine text: 'Loading ...'.
  searchedText text: 'type text here to search in methods'.
  rootClass := Vm rootClass. 
  rootClass withAllSubclasses do:[:cls | methodDict := cls methodDictionary.
                                         methodDict keysDo: [:k | newMethod := k + '>>' + cls name + '#i'.
                                                                  methodList add: newMethod].
                                         methodClassDict := cls class methodDictionary.
                                         methodClassDict keysDo: [:k | newMethod := k + '>>' + cls name + '#c'.
                                                                       methodList add: newMethod]].  
  methodList sort.
  methodList do: [:item | (item startsWith: aCharacter) ifTrue: [nrTotal := nrTotal + 1]].
  nrTotal = 0 ifTrue: [typeLine text: 'no results']
              ifFalse: [methodList do: [:item | bool := (item startsWith: aCharacter).
                                                bool ifTrue: [nr := nr + 1.
                                                              typeLine text: nr asString + ' / ' + nrTotal asString.
                                                              newTree := TreeViewItem new.
                                                              newTag := item. 
                                                              newHeader := item substring: 0 len: (item length - 2).
                                                              newTree header: newHeader.
                                                              newTree tag: newTag.
                                                              treeClassMethods items add: newTree]]]
!
showMethod
   | className index item len method rootClass selector |
   item := (treeClassMethods selectedItem tag) asString.
   index := item indexOf: '>' start: 0.
   len := item length.
   className := (item substring: index + 2 len: len - index - 4).
   selector :=  (item substring: 0 len: index) asSymbol.
   rootClass := Vm rootClass.
   rootClass withAllSubclasses do:[:cls | cls name = className ifTrue: [class := cls]].
   (item endsWith: '#i') ifTrue: [method := class lookupSelector: selector.
                                  typeLine text: 'instance method'.
                                  type := 'i']
                         ifFalse: [method := class class lookupSelector: selector.
                                   typeLine text: 'class method'.
                                   type := 'c'].
   methodEditor text: method text
!
textSave
  | txt |
  txt := methodEditor text trim.
  type = 'i' ifTrue: [SmalltalkReader addMethod: class string: txt]
             ifFalse: [SmalltalkReader addMethod: class class string: txt].
  methodEditor text: txt
!
CalmoSoft subclass: #PowerBrowser
instanceVariableNames: 'classActual classCommentEditor classDict classesTvLeft classesTvRight classLb helpEditor inheritsText instDict instLb notesTextbox selectedClass selector tabctrl tabctrlBottom texteditor textLineBottom textLineTop undoText varLb welcomeEditor window'
classVariableNames: ''
!
PowerBrowser class
!
copyright
   "   ~  written by: Gal Zsolt & Cathlyn Cosca ( CalmoSoft ) ~ 2006-2007 ~ calmosoft@gmail.com ~   "
!
PowerBrowser
!
aboutPowerBrowser
   "   PowerBrowser new aboutPowerBrowser   "
  | string window xaml |
  window := self topWindowClass new.
  string := File readAllText: 'calmosoft/AboutPowerBrowser.xaml'.
  xaml := XamlUtility xamlFromString: string.
  xaml isNil ifFalse: [window add: xaml].
  window width: 550.
  window height: 350.
  window title: 'About Vista Smalltalk'.
  window open
!
classMethodSelection
  | method nrimplementors nrsenders selector2 |
  classLb selectedItem notNil ifTrue: [
          selector := classLb selectedItem content.
          method := selectedClass class lookupSelector: selector.
          texteditor text: method text.
          undoText := texteditor text.
          selector2 := classLb selectedItem content.
          nrsenders := (Vm sendersOf: selector2) size.
          nrimplementors := (Vm implementorsOf: selector2) size.
          textLineTop text: selector asString +
                            ' : ' +
                            nrsenders asString +
                            ' senders / ' +
                            nrimplementors asString +
                            ' implementors']
!
classSave
  | boolean classOutFile evalString startupFile txt |
  evalString := self stringToEval.
  startupFile := File readAllText: 'scripts/image.st'.
  startupFile := startupFile replace: evalString with: ''.
  txt := texteditor text trim.
  txt length == 0 ifTrue: [^nil].
  boolean := ((txt at: 0) isUpper and: (txt indexOf: ' subclass:') > 0 and: (txt endsWith: '!')).
  boolean ifTrue: [startupFile := startupFile + txt + Environment newLine + evalString.
                   classOutFile := File writeAllText: 'scripts/image.st' from: startupFile.
                   texteditor text: ''.
                   textLineTop text: ''.
                   instLb items clear.
                   classLb items clear.
                   varLb items clear.
                   inheritsText text: ''.
                   textLineTop text: '~~~ Done. Please quit and restart Vista Smalltalk without Fileout all !!! ~~~']
          ifFalse: [^nil]
!
classSelectionChangedLeft
  | cls nrMethods1 nrMethods2 |
  classesTvLeft selectedItem isNil ifTrue:[^nil].
  classesTvLeft background: (SolidColorBrush new: Color customBlue).
  classesTvRight background: (SolidColorBrush new: Color customGray).
  textLineTop text: ''.
  textLineBottom text: ''.
  cls := classesTvLeft selectedItem tag.
  selectedClass := cls.
  self refreshMethodsLists.
  self showClassText.
  selectedClass name ~= Object ifTrue: [self refreshVariables.
                                        self showClassInherits]
                               ifFalse: [varLb items clear.
                                         inheritsText text: ''].
  nrMethods1 := (selectedClass methodDictionary size).
  nrMethods2 := (selectedClass class methodDictionary size).
  textLineTop text: selectedClass asString +
                    ' class has : ' +
                     nrMethods1 asString +
                    ' instance methods / ' +
                     nrMethods2 asString +
                    ' class methods'.
  self showClassComment
!
classSelectionChangedRight
  | cls nrMethods1 nrMethods2 |
  classesTvRight selectedItem isNil ifTrue:[^nil].
  classesTvRight background: (SolidColorBrush new: Color customBlue).
  classesTvLeft background: (SolidColorBrush new: Color customGray).
  textLineTop text: ''.
  cls := classesTvRight selectedItem tag.
  selectedClass := cls.
  self refreshMethodsLists.
  self showClassText.
  selectedClass name ~= Object ifTrue: [self refreshVariables.
                                        self showClassInherits]
                               ifFalse: [varLb items clear.
                                         inheritsText text: ''].
  nrMethods1 := (selectedClass methodDictionary size).
  nrMethods2 := (selectedClass class methodDictionary size).
  textLineTop text: selectedClass asString +
                    ' class has : ' +
                     nrMethods1 asString +
                    ' instance methods / ' +
                     nrMethods2 asString +
                    ' class methods'.
  self showClassComment
!
clearAppendFile
  File writeAllText: 'vista.st' from: ''
!
copyWithAppend
  Clipboard setText: Clipboard getText +
                               Environment newline +
                               texteditor selectedText
!
createNewClass
  textLineTop text: ''.
  texteditor text: Class template
!
createNewMethod
  textLineTop text: ''.
  texteditor text: MethodContext template
!
cutText
 | cutStart text textLeft textRight |
  Clipboard setText: texteditor selectedText.
  text := texteditor text.
  cutStart := texteditor selectionStart.
  textLeft := text substring: 0 len: cutStart.
  textRight := text substring: (cutStart + texteditor selectionLength)
                    len: (text length - textLeft length - texteditor selectionLength).
  texteditor text: (textLeft + textRight).
  texteditor selectionStart: cutStart
!
doIt
  | method str |
  (tabctrlBottom selectedIndex == 2) ifTrue: [str := notesTextbox selectedText trim]
                                     ifFalse: [str := texteditor selectedText trim].
  str length == 0 ifTrue: [^nil].
  method := Compiler compileSnippet: str.
  method isNil ifTrue:[^nil].
  Processor scheduleProcess: (Process fromMethod: method)
!
doItPrompt
   | index1 index2 |
   index1 := texteditor text indexOf: '"   '.
   index2 := texteditor text indexOf: '   "'.
   ((index1 > 0) and: (index2 > 0)) ifTrue: [texteditor selectionStart: index1 + 4.
                                             texteditor selectionLength: index2 - index1 - 4].
   self doIt
!
doItPromptSave
   | index1 index2 |
   index1 := texteditor text indexOf: '"   '.
   index2 := texteditor text indexOf: '   "'.
   ((index1 > 0) and: (index2 > 0)) ifTrue: [texteditor selectionStart: index1 + 4.
                                             texteditor selectionLength: index2 - index1 - 4].
   self doIt
!
fileoutAll
  | datetime datetimeString evalString newImage textSave timeStart |  
  textSave := File readAllText: 'scripts/image.st'.
  datetime := self getDateTime.
  datetime length > 13 ifTrue: [datetime length = 14 ifTrue: [timeStart := 8]
                                                     ifFalse: [timeStart := 9].
                                datetimeString := 'scripts/image_' +
                                                  (datetime substring: 0 len: 8) +
                                                  '_'+
                                                  (datetime substring: timeStart len: 6) +
                                                  '.st'] 
                       ifFalse: [datetimeString := 'scripts/image_save.st'].
  File writeAllText: datetimeString from: textSave.
  Vm fileOutAll.
  evalString := self stringToEval.
  newImage := File readAllText: 'scripts/image.st'.
  newImage := newImage + evalString.
  File writeAllText: 'scripts/image.st' from: newImage
!
fileoutClass
  | classOut classOutFile classOutString find1 find2 index1 index2 indexNextClass startupFile text |
  startupFile := File readAllText: 'scripts/image.st'.
  find1 := ' subclass:'.
  find2 := ' #'.
  classOut := (selectedClass superclass asString) +
               find1 +
               find2 +
               selectedClass asString.
  index1 := startupFile indexOf: classOut.
  indexNextClass := startupFile indexOf: find1 + find2 start: index1 + classOut length.
  text := startupFile substring: index1 len: indexNextClass - index1.
  index2 := text lastIndexOf: '!'.
  classOutString := startupFile substring: index1 len: index2 + 1.
  classOutFile := File writeAllText: selectedClass asString + '.st' from: classOutString
!
fileoutClassAppend
  | classOut classOutFile classOutString find1 find2 index1 index2 indexNextClass startupFile text textSave |
  startupFile := File readAllText: 'scripts/image.st'.
  find1 := ' subclass:'.
  find2 := ' #'.
  classOut := (selectedClass superclass asString) +
               find1 +
               find2 +
               selectedClass asString.
  index1 := startupFile indexOf: classOut.
  indexNextClass := startupFile indexOf: find1 + find2 start: index1 + classOut length.
  text := startupFile substring: index1 len: indexNextClass - index1.
  index2 := text lastIndexOf: '!'.
  (File exists: 'vista.st') ifTrue: [textSave := (File readAllText: 'vista.st') +
                                                 (startupFile substring: index1 len: index2 + 1)]
                            ifFalse: [textSave := startupFile substring: index1 len: index2 + 1].
  textSave := textSave +
              Environment newline.
  classOutFile := File writeAllText: 'vista.st' from: textSave
!
fileoutClassRecursive
  | className classOut classOutFile classOutString find1 find2 index1 index2 indexNextClass startupFile text textSave |
  className := selectedClass asString + '.st'.
  startupFile := File readAllText: 'scripts/image.st'.
  selectedClass withAllSubclasses do: [:class |
                find1 := ' subclass:'.
                find2 := ' #'.
                classOut := (class superclass asString) +
                             find1 +
                             find2 +
                             class asString.
                index1 := startupFile indexOf: classOut.
                indexNextClass := startupFile indexOf: find1 + find2 start: index1 + classOut length.
                text := startupFile substring: index1 len: indexNextClass - index1.
                index2 := text lastIndexOf: '!'.
                (File exists: className) ifTrue: [textSave := (File readAllText: className) +
                                                              (startupFile substring: index1 len: index2 + 1)]
                                         ifFalse: [textSave := startupFile substring: index1 len: index2 + 1].
                textSave := textSave +
                            Environment newline.
                classOutFile := File writeAllText: className from: textSave]
!
findIt
  | index string text |
  text := texteditor text.
  string := texteditor selectedText trim.
  string length == 0 ifTrue: [^nil].
  index := (text indexOf: string start: (texteditor selectionStart + string length)).
  index > 0 ifTrue: [texteditor selectionStart: index.
                     texteditor selectionLength: string length]
!
getDateTime
  | datetime |
  datetime := DateTime now asString.
  (datetime length = 19) ifTrue: [datetime := datetime replace: ' 0' with: '00'.
                                  datetime := datetime replace: ' 1' with: '01'.
                                  datetime := datetime replace: ' 2' with: '02'.
                                  datetime := datetime replace: ' 3' with: '03'.
                                  datetime := datetime replace: ' 4' with: '04'.
                                  datetime := datetime replace: ' 5' with: '05'.
                                  datetime := datetime replace: ' 6' with: '06'.
                                  datetime := datetime replace: ' 7' with: '07'.
                                  datetime := datetime replace: ' 8' with: '08'.
                                  datetime := datetime replace: ' 9' with: '09'].
  datetime := datetime replace: '.' with: ''.
  datetime := datetime replace: ':' with: ''.
  datetime := datetime replace: '/' with: ''.
  datetime := datetime replace: '-' with: ''.
  datetime := datetime replace: ' ' with: ''.
  ^datetime
!
implementorsClassMethod
  | selector |
  selector := classLb selectedItem content.
  (Vm implementorsOf: selector) inspect
!
implementorsInstMethod
  | selector |
  selector := instLb selectedItem content.
  (Vm implementorsOf: selector) inspect
!
implementorsMethodOfTextbox
  | selector string |
  (tabctrlBottom selectedIndex == 2) ifTrue: [string := notesTextbox selectedText trim]
                                     ifFalse: [string := texteditor selectedText trim].
  selector := string asSymbol.
  (Vm implementorsOf: selector) inspect
!
inheritsFromList
  | aList aString aSuperclass |
  texteditor text: ''.
  textLineTop text: selectedClass asString +
                    ' class inherits from :'.   
  aList := List new.
  aString := ''.
  aSuperclass := selectedClass superclass.
  aList add: (aSuperclass asString).
  [aSuperclass == Vm rootClass] whileFalse: [aSuperclass := aSuperclass superclass.
                                             aList add: (aSuperclass asString)].
  aList reverse.
  aList do: [:cls | aString := aString + '  '.
                    texteditor println: aString + cls].
  aString := aString + '  '.
  texteditor println: aString + (selectedClass asString)
!
inspectIt
  | method process str |
  (tabctrlBottom selectedIndex == 2) ifTrue: [str := notesTextbox selectedText trim]
                                     ifFalse: [str := texteditor selectedText trim].
  method := Compiler compileSnippet: str.
  method isNil ifTrue:[^nil].
  process := Process fromMethod: method.
  process callback: [:val | self inspectResult: val].
  Processor scheduleProcess: process
!
inspectResult: anObject
  anObject inspect
!
instMethodSelection
  | method nrimplementors nrsenders selector2 |
  instLb selectedItem notNil ifTrue: [selector := instLb selectedItem content.
                                      method := selectedClass lookupSelector: selector.
                                      texteditor text: method text.
                                      undoText := texteditor text.
                                      selector2 := instLb selectedItem content.
                                      nrsenders := (Vm sendersOf: selector2) size.
                                      nrimplementors := (Vm implementorsOf: selector2) size.
                                      textLineTop text: selector asString +
                                                        ' : ' +
                                                        nrsenders asString +
                                                        ' senders / ' +
                                                        nrimplementors asString +
                                                        ' implementors']
!
makeAbcClasses
  | dock buttonHeight sp |
  buttonHeight := 22.82. 
  dock := window dockpanel3.
  sp := StackPanel vertical.
  button1 := (Button content: 'all' callback: [self refreshClassTreeRight: 'a']).
  button2 := (Button content: 'A' callback: [self refreshClassTreeRight: 'A']).
  button3 := (Button content: 'B' callback: [self refreshClassTreeRight: 'B']).
  button4 := (Button content: 'C' callback: [self refreshClassTreeRight: 'C']).
  button5 := (Button content: 'D' callback: [self refreshClassTreeRight: 'D']).
  button6 := (Button content: 'E' callback: [self refreshClassTreeRight: 'E']).
  button7 := (Button content: 'F' callback: [self refreshClassTreeRight: 'F']).
  button8 := (Button content: 'G' callback: [self refreshClassTreeRight: 'G']).
  button9 := (Button content: 'H' callback: [self refreshClassTreeRight: 'H']).
  button10 := (Button content: 'I' callback: [self refreshClassTreeRight: 'I']).
  button11 := (Button content: 'J' callback: [self refreshClassTreeRight: 'J']).
  button12 := (Button content: 'K' callback: [self refreshClassTreeRight: 'K']).
  button13 := (Button content: 'L' callback: [self refreshClassTreeRight: 'L']).
  button14 := (Button content: 'M' callback: [self refreshClassTreeRight: 'M']).
  button15 := (Button content: 'N' callback: [self refreshClassTreeRight: 'N']).
  button16 := (Button content: 'O' callback: [self refreshClassTreeRight: 'O']).
  button17 := (Button content: 'P' callback: [self refreshClassTreeRight: 'P']).
  button18 := (Button content: 'Q' callback: [self refreshClassTreeRight: 'Q']).
  button19 := (Button content: 'R' callback: [self refreshClassTreeRight: 'R']).
  button20 := (Button content: 'S' callback: [self refreshClassTreeRight: 'S']).
  button21 := (Button content: 'T' callback: [self refreshClassTreeRight: 'T']).
  button22 := (Button content: 'U' callback: [self refreshClassTreeRight: 'U']).
  button23 := (Button content: 'V' callback: [self refreshClassTreeRight: 'V']).
  button24 := (Button content: 'W' callback: [self refreshClassTreeRight: 'W']).
  button25 := (Button content: 'X' callback: [self refreshClassTreeRight: 'X']).
  button26 := (Button content: 'Y' callback: [self refreshClassTreeRight: 'Y']).
  button27 := (Button content: 'Z' callback: [self refreshClassTreeRight: 'Z']).
  button1 height: buttonHeight.
  button2 height: buttonHeight.
  button3 height: buttonHeight.
  button4 height: buttonHeight.
  button5 height: buttonHeight.
  button6 height: buttonHeight.
  button7 height: buttonHeight.
  button8 height: buttonHeight.
  button9 height: buttonHeight.
  button10 height: buttonHeight.
  button11 height: buttonHeight.
  button12 height: buttonHeight.
  button13 height: buttonHeight.
  button14 height: buttonHeight.
  button15 height: buttonHeight.
  button16 height: buttonHeight.
  button17 height: buttonHeight.
  button18 height: buttonHeight.
  button19 height: buttonHeight.
  button20 height: buttonHeight.
  button21 height: buttonHeight.
  button22 height: buttonHeight.
  button23 height: buttonHeight.
  button24 height: buttonHeight.
  button25 height: buttonHeight.
  button26 height: buttonHeight.
  button27 height: buttonHeight.
  sp add: button1.
  sp add: button2.
  sp add: button3.
  sp add: button4.
  sp add: button5.
  sp add: button6.
  sp add: button7.
  sp add: button8.
  sp add: button9.
  sp add: button10.
  sp add: button11.
  sp add: button12.
  sp add: button13.
  sp add: button14.
  sp add: button15.
  sp add: button16.
  sp add: button17.
  sp add: button18.
  sp add: button19.
  sp add: button20.
  sp add: button21.
  sp add: button22.
  sp add: button23.
  sp add: button24.
  sp add: button25.
  sp add: button26.
  sp add: button27.
  dock add: sp
!
makeButtons
  | dock1 dock2 sp1 sp2 |
  dock1 := window dockpanel. 
  dock2 := window dockpanel2. 
  sp1 := StackPanel horizontal.
  sp2 := StackPanel horizontal.
  sp1 add: (Button content: '   Save   ' callback: [self textSave]).
  sp1 add: (Button content: '   File out all  ' callback: [self fileoutAll]).
  sp1 add: (Button content: '   Clear   ' callback: [texteditor text: '']).
  sp1 add: (Button content: '   Undo all   ' callback: [texteditor text: undoText]).
  sp1 add: (Button content: '   Copy   ' callback: [Clipboard setText: texteditor selectedText]).
  sp1 add: (Button content: '   Copy all   ' callback: [Clipboard setText: texteditor text]).
  sp1 add: (Button content: '   Copy with append   ' callback: [self copyWithAppend]).
  sp1 add: (Button content: '   Cut   ' callback: [self cutText]).
  sp1 add: (Button content: '   Paste   ' callback: [self pasteText]).
  sp1 add: (Button content: '   Clear Clipboard   ' callback: [Clipboard clear]).
  sp1 add: (Button content: '   Do It   ' callback: [self doIt]).
  sp1 add: (Button content: '    Do it prompt    ' callback: [self doItPrompt]).
  sp1 add: (Button content: '   Show It   ' callback: [self showIt]).
  sp1 add: (Button content: '  Inspect It   ' callback: [self inspectIt]).
  sp2 add: (Button content: '   Senders of it   ' callback: [self sendersMethodOfTextbox]).
  sp2 add: (Button content: '   Implementors of it   ' callback: [self implementorsMethodOfTextbox]).
  sp2 add: (Button content: '  Fileout class  ' callback: [self fileoutClass]).
  sp2 add: (Button content: '  Fileout class with append  ' callback: [self fileoutClassAppend]).
  sp2 add: (Button content: '  Remove class  ' callback: [self removeClass]).
  sp2 add: (Button content: '  Breakpoints  ' callback: [self toggleBreakpoints]).
  sp2 add: (Button content: '   Linenumbers   ' callback: [self toggleLines]).
  sp2 add: (Button content: '   PowerWorkspace   ' callback: [PowerWorkspace new open]).
  sp2 add: (Button content: '   MethodFinder   ' callback: [MethodFinder new open]).
  sp2 add: (Button content: '     SystemBrowser    ' callback: [SystemBrowser new open]).
  dock1 add: sp1.
  dock2 add: sp2
!
makeEditorsTab
  | tab |
  classCommentEditor := TextEditor new.
  self setCommentEditorContextMenu.
  welcomeEditor := TextEditor new.
  helpEditor := TextEditor new.
  texteditor := TextEditor new.
  texteditor foreground: Brushes navy.
  texteditor showLines: true.
  texteditor showBreakpoints: true.
  self setTextEditorContextMenu.
  self setWelcomeContextMenu.
  self setHelpContextMenu.
  tabctrlBottom := window tabcontrolBottom.
  tab := TabItem new.
  tab header: 'method code'.
  tab content: texteditor.
  tabctrlBottom tabStripPlacement: Dock top.
  tabctrlBottom items add: tab.
  tab := TabItem new.
  tab header: 'class comment'.
  tab content: classCommentEditor.
  tabctrlBottom items add: tab.
  tab := TabItem new.
  tab header: 'workspace'.
  tab content: notesTextbox.
  tabctrlBottom items add: tab.
  tab := TabItem new.
  tab header: 'welcome'.
  tab content: welcomeEditor.
  tabctrlBottom items add: tab.
  tab := TabItem new.
  tab header: 'help'.
  tab content: helpEditor.
  tabctrlBottom items add: tab
!
makeVariablesTab
  | tab tabctrlRight |
  varLb := ListBox new.
  inheritsText := TextBox new.
  tabctrlRight := window tabcontrolRight.
  tab := TabItem new.
  tab header: 'Instance variables'.
  tab content: varLb.
  tabctrlRight tabStripPlacement: Dock top.
  tabctrlRight items add: tab.
  tab := TabItem new.
  tab header: 'Class inherits from'.
  tab content: inheritsText.
  tabctrlRight items add: tab.
  Handler on: varLb event: 'SelectionChanged' block: [nil]
!
open
  "   PowerBrowser new open   "
  | tab |
  window := PowerBrowserLayout new.
  window title: '~~~ PowerBrowser for Vista Smalltalk ~~~'.
  textLineTop := window textboxLineTop.
  textLineBottom := window textboxLineBottom.
  classesTvLeft := window treeviewLeft.
  classesTvLeft background: (SolidColorBrush new: Color customGray).
  classesTvRight := window treeviewRight.
  classesTvRight background: (SolidColorBrush new: Color customGray).
  tabctrl := window tabcontrol.
  varLb := ListBox new.
  instLb := ListBox new.
  instLb background: (SolidColorBrush new: Color customGreen).
  instLb borderbrush: (SolidColorBrush new: Color customDarkGray).
  instLb foreground: Brushes darkGreen.
  classLb := ListBox new.
  classLb background: (SolidColorBrush new: Color customGreen).
  classLb borderbrush: (SolidColorBrush new: Color customDarkGray).
  classLb foreground: Brushes darkGreen.
  notesTextbox := TextEditor new.
  notesTextbox text: 'This is an enhanced workspace in classbrowser !' +
                      Environment newline + Environment newline +
                     'SuePuzzle new open. (Do It)'.
  notesTextbox foreground: Brushes navy.
  notesTextbox showLines: true.
  notesTextbox showBreakpoints: true.
  tab := TabItem new.
  tab header: 'Instance'.
  tab content: instLb.
  tabctrl tabStripPlacement: Dock top.
  tabctrl items add: tab.
  tab := TabItem new.
  tab header: 'Class'.
  tab content: classLb.
  tabctrl items add: tab.
  Handler on: classesTvLeft event: 'SelectedItemChanged' block: [self classSelectionChangedLeft].
  Handler on: classesTvRight event: 'SelectedItemChanged' block: [self classSelectionChangedRight].
  Handler on: instLb event: 'SelectionChanged' block: [self instMethodSelection].
  Handler on: classLb event: 'SelectionChanged' block: [self classMethodSelection].
  self setInstLbContextMenu;
       setClassLbContextMenu;
       setClassesTvRightContextMenu;
       setClassesTvLeftContextMenu;
       setNotesTextboxContextMenu.
  self setFontSize.
  window open.
  self refreshClassTreeLeft.
  self refreshClassTreeRightFirst.
  welcomeEditor text: self showWelcome.
  helpEditor text: self showHelp.
  classActual := 'a'
!
pasteText
  | insertStart text textLeft textRight |
  text := texteditor text.
  insertStart := texteditor selectionStart.
  textLeft := text substring: 0 len: insertStart.
  textRight := text substring: (insertStart + texteditor selectionLength)
                    len: (text length - textLeft length - texteditor selectionLength).
  texteditor text: (textLeft + Clipboard getText + textRight).
  texteditor selectionStart: insertStart
!
readNotes
  | string |
  (File exists: 'notes.txt') ifTrue: [string := File readAllText: 'notes.txt'.
                                      notesTextbox text: string]
                             ifFalse: [^nil]
!
refreshClassTreeLeft
  | rootClass rootNode |
  textLineTop text: 'Loading ...'.
  textLineBottom text: ''.
  rootClass := Vm rootClass.
  classesTvLeft items clear.
  rootNode := TreeViewItem new.
  rootNode foreground: Brushes fireBrick.
  rootNode header: rootClass name.
  rootNode tag: rootClass.
  classesTvLeft items add: rootNode.
  self refreshClassTreeLeft: rootClass node: rootNode
!
refreshClassTreeLeft: aClass node: aNode
  | childNode |
  aClass subclasses do:[:cls | childNode := TreeViewItem new.
                               childNode foreground: Brushes fireBrick.
                               childNode header: cls name.
                               childNode tag: cls.
                               aNode items add: childNode.
                               self refreshClassTreeLeft: cls node: childNode]
!
refreshClassTreeRight
  | childClass clsName emptynr noneemptynr nrMethod rootClass totalnr |
  emptynr := 0.
  textLineTop text: 'Loading ...'.
  classesTvRight items clear.
  rootClass := Vm rootClass.
  rootClass withAllSubclasses do:[:cls | nrMethod := (cls methodDictionary size) +
                                                     (cls class methodDictionary size).
                                         nrMethod = 0 ifTrue: [clsName := (cls name + ' (-)').
                                                               emptynr := emptynr + 1]
                                                      ifFalse: [clsName := (cls name)].
                                         childClass := TreeViewItem new.
                                         childClass header: clsName.
                                         childClass tag: cls.
                                         classesTvRight items add: childClass].
  totalnr := Vm rootClass withAllSubclasses size.
  noneemptynr := totalnr - emptynr.
  textLineBottom text: ' classes statistics : ' +
                       emptynr asString +
                       ' empty / ' +
                       noneemptynr asString +
                       ' noneempty / ' +
                       totalnr asString +
                       ' total'.
  textLineTop text: 'Ready'
!
refreshClassTreeRight: aCharacter
  | clsName childClass emptynr noneemptynr nrMethod rootClass totalnr |
  varLb items clear.
  classesTvRight items clear.
  inheritsText text: ''.
  classActual := aCharacter. 
  (aCharacter = 'a') ifTrue: [self refreshClassTreeRight.
                              ^nil].
  emptynr := 0.
  totalnr := 0.
  textLineTop text: 'Loading ...'.
  rootClass := Vm rootClass.
  rootClass withAllSubclasses do:[:cls | (cls name substring: 0 len: 1) = aCharacter ifTrue:[
                                                   totalnr := totalnr + 1.
                                                   nrMethod := (cls methodDictionary size) +
                                                   (cls class methodDictionary size).
                                                   nrMethod = 0 ifTrue: [clsName := (cls name + ' (-)').
                                                                         emptynr := emptynr + 1]
                                                                ifFalse: [clsName := (cls name)].
                                                   childClass := TreeViewItem new.
                                                   childClass header: clsName.
                                                   childClass tag: cls.
                                                   classesTvRight items add: childClass]].
  noneemptynr := totalnr - emptynr.
  textLineBottom text: ' classes statistics : ' +
                       emptynr asString +
                       ' empty / ' +
                       noneemptynr asString +
                       ' noneempty / ' +
                       totalnr asString +
                       ' total'.
  textLineTop text: 'Ready'
!
refreshClassTreeRightFirst
  | clsName childClass emptynr noneemptynr nrMethod rootClass totalnr |
  nr := 0.
  emptynr := 0.
  classesTvRight items clear.
  totalnr := Vm rootClass withAllSubclasses size.
  rootClass := Vm rootClass.
  rootClass withAllSubclasses do:[:cls | nrMethod := (cls methodDictionary size) + (cls class methodDictionary size).
                                         nrMethod = 0 ifTrue: [clsName := (cls name + ' (-)').
                                                               emptynr := emptynr + 1]
                                                      ifFalse: [clsName := (cls name)].
                                         childClass := TreeViewItem new.
                                         childClass header: clsName.
                                         childClass tag: cls.
                                         classesTvRight items add: childClass].
  noneemptynr := totalnr - emptynr.
  textLineBottom text: ' classes statistics : ' +
                       emptynr asString +
                       ' empty / ' +
                       noneemptynr asString +
                       ' noneempty / ' +
                       totalnr asString +
                       ' total'.
  self makeVariablesTab.
  self makeEditorsTab.
  self makeButtons.
  self makeAbcClasses.
  textLineTop text: DateTime now asString.
  texteditor text: self showWelcome
!
refreshMethodsLists
  | li |
  instDict := selectedClass methodDictionary.
  classDict := selectedClass class methodDictionary.
  instLb items clear.
  classLb items clear.
  texteditor text: ''.
  instDict keysDo: [:k | li := ListBoxItem new.
                               li content: k.
                               instLb items add: li].
  classDict keysDo: [:k | li := ListBoxItem new.
                          li content: k.
                          classLb items add: li]
!
refreshVariables
  | li varDict |
  varDict := selectedClass instanceVariables sorted.
  varLb items clear.
  varDict do: [:k | li := ListBoxItem new.
                    li content: k.
                    varLb items add: li]
!
removeClass
  texteditor text: ''.
  textLineTop text: ''.
  instLb items clear.
  classLb items clear.
  varLb items clear.
  inheritsText text: ''.
  selectedClass remove.
  self removeClassComment.
  self refreshClassTreeLeft.
  self refreshClassTreeRight: classActual
!
removeClassComment
  | commentFile commentFileOut commentReplace commentText indexBegin indexEnd lenEnd |
  commentFile :='classcomments/ClassComments.cmt'.
  commentText := File readAllText: commentFile.
  indexBegin := commentText indexOf: selectedClass asString + ' class comment begin !'.
  indexBegin >= 0 ifTrue: [indexEnd := commentText indexOf: selectedClass asString + ' class comment end !!!'.
                           lenEnd := (selectedClass asString + ' class comment end !!!') length.
                           commentReplace := commentText substring: indexBegin len: (indexEnd + lenEnd - indexBegin).
                           commentText := commentText replace: commentReplace with: '']
                  ifFalse: [^nil].
  commentFileOut := File writeAllText: commentFile from: commentText
!
removeClassMethod
  | selector |
  textLineTop text: ''.
  selector := classLb selectedItem content.
  selectedClass class removeMethod: selector.
  self refreshMethodsLists.
  nrMethod := (selectedClass methodDictionary size) +
              (selectedClass class methodDictionary size).
  nrMethod == 0 ifTrue: [self refreshClassTreeLeft.
                         self refreshClassTreeRight: classActual]
!
removeInstMethod
  | nrMethod selector |
  textLineTop text: ''.
  selector := instLb selectedItem content.
  selectedClass removeMethod: selector.
  self refreshMethodsLists.
  nrMethod := (selectedClass methodDictionary size) +
              (selectedClass class methodDictionary size).
  nrMethod == 0 ifTrue: [self refreshClassTreeLeft.
                         self refreshClassTreeRight: classActual]
!
saveClassComment
  | commentFile commentFileOut commentNew commentReplace commentText indexBegin indexEnd lenEnd |
  commentFile :='classcomments/ClassComments.cmt'.
  commentText := File readAllText: commentFile.
  commentNew := selectedClass asString + ' class comment begin !' +
                Environment newLine + 
                classCommentEditor text +
                Environment newLine + 
                selectedClass asString + ' class comment end !!!'.
  indexBegin := commentText indexOf: selectedClass asString + ' class comment begin !'.
  indexBegin >= 0 ifTrue: [indexEnd := commentText indexOf: selectedClass asString + ' class comment end !!!'.
                           lenEnd := (selectedClass asString + ' class comment end !!!') length.
                           commentReplace := commentText substring: indexBegin len: (indexEnd + lenEnd - indexBegin).
                           commentText := commentText replace: commentReplace with: commentNew]
                  ifFalse: [commentText := commentText asString +
                                           Environment newLine +
                                           commentNew asString].
  commentFileOut := File writeAllText: commentFile from: commentText
!
saveImage
  | datetime datetimeString start1 start2 text textSave timeStart |  
  text := texteditor text.
  start1 := 'nil subclass:'.
  start2 := ' #Object'.
  textSave := File readAllText: 'scripts/image.st'.
  datetime := self getDateTime.
  datetime length > 13 ifTrue: [datetime length = 14 ifTrue: [timeStart := 8]
                                                     ifFalse: [timeStart := 9].
                                datetimeString := 'scripts/image_' +
                                                  (datetime substring: 0 len: 8) +
                                                  '_' +
                                                  (datetime substring: timeStart len: 6) +
                                                  '.st'] 
                       ifFalse: [datetimeString := 'scripts/image_save.st'].
  File writeAllText: datetimeString from: textSave.
  (text startsWith: start1 + start2) ifTrue: [File writeAllText: 'scripts/image.st' from: text].
  texteditor text: ''. 
  textLineTop text: '~~~ Done. Please quit and restart Vista Smalltalk without Fileout all !!! ~~~']
!
selectAllText
  texteditor selectionStart: 0.
  texteditor selectionLength: (texteditor text length)
!
selectedClass
  | index |
  index := tabctrl selectedIndex.
  index == 0 ifTrue: [^ selectedClass]
             ifFalse: [^ selectedClass class]
!
sendersClassMethod
  | selector |
  selector := classLb selectedItem content.
  (Vm sendersOf: selector) inspect
!
sendersInstMethod
  | selector |
  selector := instLb selectedItem content.
  (Vm sendersOf: selector) inspect
!
sendersMethodOfTextbox
  | selector string |
  (tabctrlBottom selectedIndex == 2) ifTrue: [string := notesTextbox selectedText trim]
                                     ifFalse: [string := texteditor selectedText trim].
  selector := string asSymbol.
  (Vm sendersOf: selector) inspect
!
setClassesTvLeftContextMenu
  | menu |
  menu := ContextMenu new.
  menu add: (MenuItem name: 'New class' action: [self createNewClass]).
  menu add: (MenuItem name: 'Remove class !!!' action: [self removeClass]).
  menu add: Separator new.
  menu add: (MenuItem name: 'Show class' action: [self showClass]).
  menu add: (MenuItem name: 'File out class' action: [self fileoutClass]).
  menu add: (MenuItem name: 'File out class recursive' action: [self fileoutClassRecursive]).
  menu add: (MenuItem name: 'File out class with append' action: [self fileoutClassAppend]).
  menu add: (MenuItem name: 'Clear append file' action: [self clearAppendFile]).
  menu add: Separator new.
  menu add: (MenuItem name: 'Inherits from ...' action: [self inheritsFromList]).
  classesTvLeft contextMenu: menu
!
setClassesTvRightContextMenu
  | menu |
  menu := ContextMenu new.
  menu add: (MenuItem name: 'New class' action: [self createNewClass]).
  menu add: (MenuItem name: 'Remove class !!!' action: [self removeClass]).
  menu add: Separator new.
  menu add: (MenuItem name: 'Show class' action: [self showClass]).
  menu add: (MenuItem name: 'File out class' action: [self fileoutClass]).
  menu add: (MenuItem name: 'File out class recursive' action: [self fileoutClassRecursive]).
  menu add: (MenuItem name: 'File out class with append' action: [self fileoutClassAppend]).
  menu add: (MenuItem name: 'Clear append file' action: [self clearAppendFile]).
  menu add: Separator new.
  menu add: (MenuItem name: 'Inherits from ...' action: [self inheritsFromList]).
  classesTvRight contextMenu: menu
!
setClassLbContextMenu
  | menu |
  menu := ContextMenu new.
  menu add: (MenuItem name: 'New method' action: [self createNewMethod]).
  menu add: (MenuItem name: 'Remove method' action: [self removeClassMethod]).
  menu add: Separator new.
  menu add: (MenuItem name: 'Senders of method ...' action: [self sendersClassMethod]).
  menu add: (MenuItem name: 'Implementors of method ...' action: [self implementorsClassMethod]).
  classLb contextMenu: menu
!
setCommentEditorContextMenu
  | menu |
  menu := ContextMenu new.
  menu add: (MenuItem name: 'Save class comment' action: [self saveClassComment]).
  classCommentEditor contextMenu: menu
!
setFontSize
  | fntsize |
  fntsize := 12.
  classesTvLeft fontsize: fntsize.
  classesTvRight fontsize: fntsize.
  classLb fontsize: fntsize.
  instLb fontsize: fntsize.
  notesTextbox fontsize: fntsize.
  textLineTop fontsize: fntsize.
  textLineBottom fontsize: fntsize
!
setHelpContextMenu
  | menu |
  menu := ContextMenu new.
  menu add: (MenuItem name: 'Save help text' action: [File writeAllText: 'help.txt' from: helpEditor text]).
  helpEditor contextMenu: menu
!
setInstLbContextMenu
  | menu |
  menu := ContextMenu new.
  menu add: (MenuItem name: 'New method' action: [self createNewMethod]).
  menu add: (MenuItem name: 'Remove method' action: [self removeInstMethod]).
  menu add: Separator new.
  menu add: (MenuItem name: 'Senders of method ...' action: [self sendersInstMethod]).
  menu add: (MenuItem name: 'Implementors of method ...' action: [self implementorsInstMethod]).
  instLb contextMenu: menu
!
setNotesTextboxContextMenu
  | menu |
  menu := ContextMenu new.
  menu add: (MenuItem name: 'Clear' action: [notesTextbox text: '']).
  menu add: Separator new.
  menu add: (MenuItem name: 'Filein Notes' action: [self readNotes]).
  menu add: (MenuItem name: 'Fileout Notes' action: [self writeNotes]).
  menu add: Separator new.
  menu add: (MenuItem name: 'Do It' action: [self doIt]).
  menu add: (MenuItem name: 'Show It' action: [self showIt]).
  menu add: (MenuItem name: 'Inspect It' action: [self inspectIt]).
  menu add: Separator new.
  menu add: (MenuItem name: 'Senders of it ...' action: [self sendersMethodOfTextbox]).
  menu add: (MenuItem name: 'Implementors of it ...' action: [self implementorsMethodOfTextbox]).
  menu add: Separator new.
  menu add: (MenuItem name: 'CalmoSoft Home' action: [self showCalmoSoftHome]).
  menu add: (MenuItem name: 'Hungarian Smalltalk Users Group' action: [self showHsug]).
  menu add: Separator new.
  menu add: (MenuItem name: 'Overview' action: [self showOverview]).
  menu add: (MenuItem name: 'About' action: [self aboutPowerBrowser]).
  menu add: Separator new.
  menu add: (MenuItem name: 'Breakpoints' action: [self toggleBreakpoints]).
  menu add: (MenuItem name: 'Linenumbers' action: [self toggleLines]).
  notesTextbox contextMenu: menu
!
setTextEditorContextMenu
  | menu |
  menu := ContextMenu new.
  menu add: (MenuItem name: 'Save' action: [self textSave]).
  menu add: (MenuItem name: 'Save class' action: [self classSave]).
  menu add: (MenuItem name: 'Save with timestamp' action: [self textSaveWithTimestamp]).
  menu add: (MenuItem name: 'File out all' action: [self fileoutAll]).
  menu add: (MenuItem name: 'Clear' action: [texteditor text: '']).
  menu add: (MenuItem name: 'Undo all' action: [texteditor text: undoText]).
  menu add: Separator new.
  menu add: (MenuItem name: 'Copy' action: [Clipboard setText: texteditor selectedText]).
  menu add: (MenuItem name: 'Copy all' action: [Clipboard setText: texteditor text]).
  menu add: (MenuItem name: 'Copy with append' action: [self copyWithAppend]).
  menu add: (MenuItem name: 'Cut' action: [self cutText]).
  menu add: (MenuItem name: 'Paste' action: [self pasteText]).
  menu add: (MenuItem name: 'Select all' action: [self selectAllText]).
  menu add: (MenuItem name: 'Clear Clipboard' action: [Clipboard clear]).
  menu add: Separator new.
  menu add: (MenuItem name: 'Find it ...' action: [self findIt]).
  menu add: Separator new.
  menu add: (MenuItem name: 'Do It' action: [self doIt]).
  menu add: (MenuItem name: 'Do it prompt' action: [self doItPrompt]).
  menu add: (MenuItem name: 'Show It' action: [self showIt]).
  menu add: (MenuItem name: 'Inspect It' action: [self inspectIt]).
  menu add: Separator new.
  menu add: (MenuItem name: 'Senders of it ...' action: [self sendersMethodOfTextbox]).
  menu add: (MenuItem name: 'Implementors of it ...' action: [self implementorsMethodOfTextbox]).
  menu add: Separator new.
  menu add: (MenuItem name: 'Filein image.st' action: [self showImage]).
  menu add: (MenuItem name: 'Fileout image.st' action: [self saveImage]).
  menu add: Separator new.
  menu add: (MenuItem name: 'Breakpoints' action: [self toggleBreakpoints]).
  menu add: (MenuItem name: 'Linenumbers' action: [self toggleLines]).
  texteditor contextMenu: menu
!
setWelcomeContextMenu
  | menu |
  menu := ContextMenu new.
  menu add: (MenuItem name: 'Save welcome text' action: [File writeAllText: 'welcome.txt' from: welcomeEditor text]).
  welcomeEditor contextMenu: menu
!
showCalmoSoftHome
| frame |
  address := 'http://calmosoft.webnode.hu'.
  frame := Frame new.
  frame source: (Uri new: address).
  frame show
!
showClass
  | classOut classOutFile classOutString find1 find2 index1 index2 indexNextClass startupFile text |
  startupFile := File readAllText: 'scripts/image.st'.
  find1 := ' subclass:'.
  find2 := ' #'.
  classOut := (selectedClass superclass asString) +
               find1 +
               find2 +
               selectedClass asString.
  index1 := startupFile indexOf: classOut.
  indexNextClass := startupFile indexOf: find1 + find2 start: index1 + classOut length.
  text := startupFile substring: index1 len: indexNextClass - index1.
  index2 := text lastIndexOf: '!'.
  classOutString := startupFile substring: index1 len: index2 + 1.
  texteditor text: classOutString
!
showClassComment
  | commentClass commentFile commentText indexBegin indexEnd lenBegin lenEnd |
  commentFile :='classcomments/ClassComments.cmt'.
  commentText := File readAllText: commentFile.
  indexBegin := commentText indexOf: selectedClass asString + ' class comment begin !'.
  indexBegin >= 0 ifTrue: [lenBegin := (selectedClass asString + ' class comment begin !') length.
                           indexEnd := commentText indexOf: selectedClass asString + ' class comment end !!!'.
                           lenEnd := (selectedClass asString + ' class comment end !!!') length.
                           commentClass := commentText substring: indexBegin + lenBegin + 1
                                                       len: indexEnd - indexBegin - lenBegin - 1.
                           classCommentEditor text: commentClass trim]
                  ifFalse: [classCommentEditor text: selectedClass asString + ' class has no comment']
!
showClassInherits
  | aList aString aSuperclass |
  aList := List new.
  aString := ''.
  inheritsText text: ''.
  aSuperclass := selectedClass superclass.
  aList add: (aSuperclass asString).
  [aSuperclass == Vm rootClass] whileFalse: [ aSuperclass := aSuperclass superclass.
                                              aList add: (aSuperclass asString)].
  aList reverse.
  aList do: [:cls | inheritsText println: cls].
  inheritsText println: (selectedClass asString)
!
showClassText
  texteditor text: selectedClass storeString
!
showHelp
  | helpText |
  helpText := File readAllText:'help.txt'.
  ^helpText
!
showHsug
  | frame |
  address := 'http://hsug.freeblog.hu/'.
  frame := Frame new.
  frame source: (Uri new: address).
  frame show
!
showImage
  | string textLineBottomSave |
  texteditor text: ''.
  textLineBottomSave := textLineBottom text.
  textLineBottom text: 'Please wait patiently. It is a long file. Loading ...'.
  string := File readAllText: 'scripts/image.st'.
  texteditor text: string.
  textLineBottom text: textLineBottomSave
!
showIt
  | method process str |
  (tabctrlBottom selectedIndex == 2) ifTrue: [str := notesTextbox selectedText trim]
                                     ifFalse: [str := texteditor selectedText trim].
  str length == 0 ifTrue: [^nil].
  method := Compiler compileSnippet: str.
  method isNil ifTrue:[^nil].
  process := Process fromMethod: method.
  process callback: [:val | self showResult: val].
  Processor scheduleProcess: process
!
showOverview
  | overviewText |
  overviewText := File readAllText:'overview.txt'.
  notesTextbox text: overviewText +
                     Environment newline +
                     Environment newline +
                     'Copyright © 2000-2007 ~ RoboWiz Corporation'.
!
showResult: anObject
  | box n |
  (tabctrlBottom selectedIndex == 2) ifTrue: [box := notesTextbox]
                                     ifFalse: [box := texteditor].
  n := box selectionStart + box selectionLength.
  box selectionStart: n+1.
  box selectedText: anObject printString
!
showWelcome
  | welcomeText |
  welcomeText := File readAllText:'welcome.txt'.
  ^welcomeText
!
template
  ^' subclass:' +
   ' #NameOfSubclass' +
   Environment newline +
   'instanceVariableNames: ''''' +
   Environment newline +
   'classVariableNames: '''''
!
textSave
  | index method nrMethod selectorText txt |
  txt := texteditor text trim.
  txt length == 0 ifTrue: [^nil].
  index := txt indexOf: ' '.
  index > 0 ifTrue: [selectorText := txt substring: 0 len: index - 1.
                     selectorText ~= selector ifTrue: [selector := (selectorText asSymbol)]]
            ifFalse: [selector := (txt asSymbol)].    
  ((txt at: 0) isUpper and: (txt indexOf: ' subclass:') > 0)
               ifTrue: [SmalltalkReader addSubclass: self selectedClass string: txt.
                        texteditor text: ''.
                        textLineTop text: ''.
                        instLb items clear.
                        classLb items clear.
                        varLb items clear.
                        inheritsText text: ''.
                        self refreshClassTreeLeft.
                        self refreshClassTreeRight: classActual.
                        self refreshVariables]
               ifFalse: [SmalltalkReader addMethod: self selectedClass string: txt.
                         (tabctrl selectedIndex == 0) ifTrue: [method := selectedClass lookupSelector: selector].
                         (tabctrl selectedIndex == 1) ifTrue: [method := selectedClass class lookupSelector: selector].
                         method notNil ifTrue: [self refreshMethodsLists.
                                                texteditor text: method text]]
!
textSaveWithTimestamp
  | className classNameFirst classNameLower classNameRest datetime lenMethod methodBackup methodSave nameMethod nrMethod timeStart txt txtBackup txtLen |
  txt := texteditor text trim.
  txtLen := txt length.
  lenMethod := (txt indexOf: ' ' start: 0).
  lenMethod := lenMethod - 1.
  nameMethod := txt substring: 0 len: lenMethod.
  className := selectedClass asString. 
  classNameFirst := (className substring: 0 len: 1) toLower.
  classNameRest := className substring: 1 len: (className length - 1).
  classNameLower := classNameFirst + classNameRest.
  txt length == 0 ifTrue: [^nil].
  nrMethod := (selectedClass methodDictionary size) +
              (selectedClass class methodDictionary size).
  ((txt at: 0) isUpper and: (txt indexOf: ' subclass:') > 0)
               ifTrue: [SmalltalkReader addSubclass: self selectedClass string: txt.
                        self refreshClassTreeLeft.
                        self refreshClassTreeRight: classActual]
               ifFalse: [txt := txt + Environment newline. 
                         txt := txt + '" Modified : ' + DateTime now asString + ' "'.
                         datetime := self getDateTime.
                         methodSave := 'methodsbackup/' +
                                        className +
                                        '_' +
                                        nameMethod +
                                        '_' +        
                                        (datetime substring: 0 len: 4) +
                                        '_' +
                                        (datetime substring: 4 len: 4) +
                                        '_' +
                                        (datetime substring: 8 len: 4) +
                                        '_' +
                                        (datetime substring: 12 len: 2) +
                                        '.st'.
                         File writeAllText: methodSave from: txt.
                         methodBackup := classNameLower +  
                                         nameMethod +
                                         datetime.
                         txtBackup := methodBackup + (txt substring: lenMethod len: txtLen - lenMethod).
                         SmalltalkReader addMethod: self selectedClass string: txt.
                         SmalltalkReader addMethod: MethodsBackup string: txtBackup.
                         self refreshMethodsLists.
                         nrMethod == 0 ifTrue: [self refreshClassTreeLeft.
                                                self refreshClassTreeRight: classActual]].
  texteditor text: txt
!
toggleBreakpoints
  (tabctrlBottom selectedIndex == 2) ifTrue: [notesTextbox showBreakpoints: notesTextbox showBreakpoints not]
                                     ifFalse:[texteditor showBreakpoints: texteditor showBreakpoints not]
!
toggleLines
  (tabctrlBottom selectedIndex == 2) ifTrue: [notesTextbox showLines: notesTextbox showLines not]
                                     ifFalse:[texteditor showLines: texteditor showLines not]
!
writeNotes
    File writeAllText: 'notes.txt' from: notesTextbox text
!
CalmoSoft subclass: #PowerLauncher
instanceVariableNames: 't1 t2 t3 t4 t5 t6 t7'
classVariableNames: ''
!
PowerLauncher class
!
copyright
   "   ~  written by: Gal Zsolt & Cathlyn Cosca ( CalmoSoft ) ~ 2006-2007 ~ calmosoft@gmail.com ~   "
!
PowerLauncher
!
buildBottom
  | sp tWidth |
  tWidth := 130.
  sp := StackPanel horizontal.
  t1 := TreeView new.
  t2 := TreeView new.
  t3 := TreeView new.
  t4 := TreeView new.
  t5 := TreeView new.
  t6 := TreeView new.
  t7 := TreeView new.
  t1 width: tWidth.
  t2 width: tWidth.
  t3 width: tWidth.
  t4 width: tWidth.
  t5 width: tWidth.
  t6 width: tWidth.
  t7 width: tWidth.
  t1 borderbrush: Brushes red.
  t2 borderbrush: Brushes red.
  t3 borderbrush: Brushes red.
  t4 borderbrush: Brushes red.
  t5 borderbrush: Brushes red.
  t6 borderbrush: Brushes red.
  t7 borderbrush: Brushes red.
  sp add: t1.
  sp add: t2.
  sp add: t3.
  sp add: t4.
  sp add: t5.
  sp add: t6.
  sp add: t7.
  t1 isenabled: true.
  t2 isenabled: false.
  t3 isenabled: false.
  t4 isenabled: false.
  t5 isenabled: false.
  t6 isenabled: false.
  t7 isenabled: false.

  "   Tools   "
  t1 items add: 'ClassBrowser'.
  t1 items add: 'MethodFinder'.
  t1 items add: 'PowerBrowser'.
  t1 items add: 'PowerLauncher'.
  t1 items add: 'PowerObjects'.
  t1 items add: 'PowerWorkspace'.
  t1 items add: 'PowerWriter'.
  t1 items add: 'SystemBrowser'.
  t1 items add: 'Workspace'.

  "   Demos   "
  t2 items add: 'RssDemo'.
  t2 items add: 'Video Store'.
  t2 items add: 'Yahoo Local Search'.
  t2 items add: 'Yahoo News Search'.

  "   Games   "
  t3 items add: 'CalmoPuzzle'.
  t3 items add: 'SuePuzzle'.

  "   Graphics   "
  t4 items add: 'RotateBlocks'.
  t4 items add: 'RotateText'.
  t4 items add: 'ScaleDemo'.
  t4 items add: 'SketchPad'.
  t4 items add: 'WheelDemo'.

  "   Remote   "
  t5 items add: 'DrawAndChat-A'.
  t5 items add: 'DrawAndChat-B'.
  t5 items add: 'DrawAndChat-C'.
  t5 items add: 'Robot TicTacToe'.
  t5 items add: 'TicTacToe-X'.
  t5 items add: 'TicTacToe-O'.
  t5 items add: 'TmsInspect-1'.
  t5 items add: 'TmsInspect-2'.
  t5 items add: 'TmsXaml-1'.
  t5 items add: 'TmsXaml-2'.

  "   Xaml   "
  t6 items add: 'ColorButtons'.
  t6 items add: 'CombinedXaml'.
  t6 items add: 'Greetings'.
  t6 items add: 'List2Text'.
  t6 items add: 'VideoStore2'.
  t6 items add: 'XamlDemo'.

  "   Designer   "
  t7 items add: 'Designer'.

  ^ sp
!
buildTop
  | bWidth sp |
  bWidth := 130.
  sp := StackPanel horizontal.
  sp add: (button1 := (Button content: 'Tools' callback: [self setMenus: 1])).
  sp add: (button2 := (Button content: 'Demos' callback: [self setMenus: 2])).
  sp add: (button3 := (Button content: 'Games' callback: [self setMenus: 3])).
  sp add: (button4 := (Button content: 'Graphics' callback: [self setMenus: 4])).
  sp add: (button5 := (Button content: 'Remote' callback: [self setMenus: 5])).
  sp add: (button6 := (Button content: 'Xaml' callback: [self setMenus: 6])).
  sp add: (button7 := (Button content: 'Designer' callback: [self setMenus: 7])).
  button1 width: bWidth. 
  button2 width: bWidth. 
  button3 width: bWidth. 
  button4 width: bWidth. 
  button5 width: bWidth. 
  button6 width: bWidth. 
  button7 width: bWidth. 
  button1 background: Brushes yellow. 
  button2 background: Brushes yellow. 
  button3 background: Brushes yellow. 
  button4 background: Brushes yellow. 
  button5 background: Brushes yellow. 
  button6 background: Brushes yellow. 
  button7 background: Brushes yellow. 
  ^ sp
!
open 
  "   PowerLauncher new open   "
  | dockpanel top window |
  window := self topWindowClass new.
  window title: '~~~ PowerLauncher for Vista Smalltalk ~~~'.
  window width: 925; height: 215.
  dockpanel := DockPanel new.
  top := self buildTop.
  top clipToBounds: True.
  dockpanel add: top.
  DockPanel setDock: top to: Dock top.
  top := self buildBottom.
  dockpanel add: top.
  DockPanel setDock: top to: Dock top.
  window add: dockpanel.
  Handler on: t1 event: 'SelectedItemChanged' block: [self selectionChangedT1].
  Handler on: t2 event: 'SelectedItemChanged' block: [self selectionChangedT2].
  Handler on: t3 event: 'SelectedItemChanged' block: [self selectionChangedT3].
  Handler on: t4 event: 'SelectedItemChanged' block: [self selectionChangedT4].
  Handler on: t5 event: 'SelectedItemChanged' block: [self selectionChangedT5].
  Handler on: t6 event: 'SelectedItemChanged' block: [self selectionChangedT6].
  Handler on: t7 event: 'SelectedItemChanged' block: [self selectionChangedT7].
  self setFontSize.
  window open
!
selectionChangedT1
   "   Tools   "
  (t1 selectedItem='ClassBrowser') ifTrue: [ClassBrowser new open].
  (t1 selectedItem='MethodFinder') ifTrue: [MethodFinder new open].
  (t1 selectedItem='PowerBrowser') ifTrue: [PowerBrowser new open].
  (t1 selectedItem='PowerLauncher') ifTrue: [PowerLauncher new open].
  (t1 selectedItem='PowerObjects') ifTrue: [PowerObjects new open].
  (t1 selectedItem='PowerWorkspace') ifTrue: [PowerWorkspace new open].
  (t1 selectedItem='PowerWriter') ifTrue: [PowerWriter new open].  (t1 selectedItem='ClassBrowser') ifTrue: [ClassBrowser new open].
  (t1 selectedItem='SystemBrowser') ifTrue: [SystemBrowser new open].
  (t1 selectedItem='Workspace') ifTrue: [Workspace open]
!
selectionChangedT2
  "   Demos   "
  (t2 selectedItem='RssDemo') ifTrue: [RssDemo open].
  (t2 selectedItem='Video Store') ifTrue: [VideoStore open].
  (t2 selectedItem='Yahoo Local Search') ifTrue: [YahooLocalSearch open].
  (t2 selectedItem='Yahoo News Search') ifTrue: [YahooNewsSearch open]
!
selectionChangedT3
  "   Games   "
  (t3 selectedItem='CalmoPuzzle') ifTrue: [CalmoPuzzle new open].
  (t3 selectedItem='SuePuzzle') ifTrue: [SuePuzzle new open]
!
selectionChangedT4
  "   Graphics   "
  (t4 selectedItem='RotateBlocks') ifTrue: [RotateBlocks open].
  (t4 selectedItem='RotateText') ifTrue: [RotateText open].
  (t4 selectedItem='ScaleDemo') ifTrue: [ScaleDemo open].
  (t4 selectedItem='SketchPad') ifTrue: [SketchPad open].
  (t4 selectedItem='WheelDemo') ifTrue: [WheelDemo open]
!
selectionChangedT5
  "   Remote   "
  (t5 selectedItem='DrawAndChat-A') ifTrue: [DrawAndChat tms: 'A' listenTo: #('B' 'C')].
  (t5 selectedItem='DrawAndChat-B') ifTrue: [DrawAndChat tms: 'B' listenTo: #('A' 'C')].
  (t5 selectedItem='DrawAndChat-C') ifTrue: [DrawAndChat tms: 'C' listenTo: #('A' 'B')].
  (t5 selectedItem='Robot TicTacToe') ifTrue: [RobotTicTacToe open].
  (t5 selectedItem='TicTacToe-X') ifTrue: [TmsTicTacToe token1: 'X' token2: 'O'].
  (t5 selectedItem='TicTacToe-O') ifTrue: [TmsTicTacToe token1: 'O' token2: 'X'].
  (t5 selectedItem='TmsInspect-1') ifTrue: [TmsInspect me: 1 you: 2].
  (t5 selectedItem='TmsInspect-2') ifTrue: [TmsInspect me: 2 you: 1].
  (t5 selectedItem='TmsXaml-1') ifTrue: [TmsXaml me: 1 you: 2].
  (t5 selectedItem='TmsXaml-2') ifTrue: [TmsXaml me: 2 you: 1]
!
selectionChangedT6
  "   Xaml   "
  (t6 selectedItem='ColorButtons') ifTrue: [ColorButtons open].
  (t6 selectedItem='CombinedXaml') ifTrue: [CombinedXaml open].
  (t6 selectedItem='Greetings') ifTrue: [Greetings open].
  (t6 selectedItem='List2Text') ifTrue: [List2Text open].
  (t6 selectedItem='VideoStore2') ifTrue: [VideoStore2 open].
  (t6 selectedItem='XamlDemo') ifTrue: [XamlDemo open]
!
selectionChangedT7
  "   Designer   "
  (t7 selectedItem='Designer') ifTrue: [OnePaneDesigner open]
!
setFontSize
  | fntsize |
  fntsize := 12.
  t1 fontsize: fntsize.
  t2 fontsize: fntsize.
  t3 fontsize: fntsize.
  t4 fontsize: fntsize.
  t5 fontsize: fntsize.
  t6 fontsize: fntsize.
  t7 fontsize: fntsize
!
setMenus: nr
  (nr = 1) ifTrue: [t1 isenabled: true] ifFalse: [t1 isenabled: false].
  (nr = 2) ifTrue: [t2 isenabled: true] ifFalse: [t2 isenabled: false].
  (nr = 3) ifTrue: [t3 isenabled: true] ifFalse: [t3 isenabled: false].
  (nr = 4) ifTrue: [t4 isenabled: true] ifFalse: [t4 isenabled: false].
  (nr = 5) ifTrue: [t5 isenabled: true] ifFalse: [t5 isenabled: false].
  (nr = 6) ifTrue: [t6 isenabled: true] ifFalse: [t6 isenabled: false].
  (nr = 7) ifTrue: [t7 isenabled: true] ifFalse: [t7 isenabled: false]
!
CalmoSoft subclass: #PowerObjects
instanceVariableNames: 'openEditorBox openListBox selectedClass window'
classVariableNames: ''
!
PowerObjects class
!
copyright
   "   ~  written by: Gal Zsolt & Cathlyn Cosca ( CalmoSoft ) ~ 2006-2007 ~ calmosoft@gmail.com ~   "
!
PowerObjects
!
classSave
  | boolean classOutFile evalString message startupFile txt |
  message := '~~~ Done. Please quit and restart Vista Smalltalk without Fileout all !!! ~~~'.
  evalString := self stringToEval.
  startupFile := File readAllText: 'scripts/image.st'.
  startupFile := startupFile replace: evalString with: ''.
  txt := openEditorBox text trim.
  txt length == 0 ifTrue: [^nil].
  boolean := ((txt at: 0) isUpper and: (txt indexOf: ' subclass:') > 0 and: (txt endsWith: '!')).
  boolean ifTrue: [startupFile := startupFile +
                                  txt +
                                  Environment newLine +
                                  evalString.
                   classOutFile := File writeAllText: 'scripts/image.st' from: startupFile.
                   openEditorBox text: message]
          ifFalse: [^nil]
!
findOpenMethods
  | blnOpen rootclass selector|  
  selector := 'open' asSymbol.
  rootClass := Vm rootClass.
  rootClass withAllSubclasses do:[:class | blnOpen := (class hasSelector: selector).
                                           blnOpen ifTrue: [openListBox items add: class name]]
!
open
  "   PowerObjects new open   "
  window := PowerObjectsLayout new.
  window title: '~~~ PowerObjects for Vista Smalltalk ~~~'.
  openListBox := window listbox.
  openListBox background: (SolidColorBrush new: Color customGray).
  openEditorBox := window editorbox.
  openEditorBox foreground: Brushes navy.
  openEditorBox showLines: true.
  Handler on: openListBox event: 'SelectionChanged' block: [self openRunShow].
  self setEditorContextMenu.
  self setFontSize.
  window open.
  self findOpenMethods
!
openRunShow
  | className method methodString methodToShow selector string |
  className := openListBox selectedItem asString.
  rootClass := Vm rootClass.
  rootClass withAllSubclasses do:[:cls | cls name = className ifTrue: [selectedClass := cls]].
  methodString := openListBox selectedItem asString + ' new open'.
  method := Compiler compileSnippet: methodString.
  method isNil ifTrue:[^nil].
  self showClass.
  Processor scheduleProcess: (Process fromMethod: method)
!
setEditorContextMenu
  | menu |
  menu := ContextMenu new.
  menu add: (MenuItem name: 'Save' action: [self classSave]).
  openEditorBox contextMenu: menu
!
setFontSize
  | fntsize |
  fntsize := 12.
  openListBox fontsize: fntsize.
  openEditorBox fontsize: fntsize
!
showClass
  | classOut classOutFile classOutString find1 find2 index1 index2 indexNextClass startupFile text |
  startupFile := File readAllText: 'scripts/image.st'.
  find1 := ' subclass:'.
  find2 := ' #'.
  classOut := (selectedClass superclass asString) +
               find1 +
               find2 +
               selectedClass asString.
  index1 := startupFile indexOf: classOut.
  indexNextClass := startupFile indexOf: find1 + find2 start: index1 + classOut length.
  text := startupFile substring: index1 len: indexNextClass - index1.
  index2 := text lastIndexOf: '!'.
  classOutString := startupFile substring: index1 len: index2 + 1.
  openEditorBox text: classOutString
!
CalmoSoft subclass: #PowerWorkspace
instanceVariableNames: 'textBox window'
classVariableNames: ''
!
PowerWorkspace class
!
copyright
   "   ~  written by: Gal Zsolt & Cathlyn Cosca ( CalmoSoft ) ~ 2006-2007 ~ calmosoft@gmail.com ~   "
!
PowerWorkspace
!
buildTop
  | bWidth sp |
  bWidth := 130.
  sp := StackPanel horizontal.
  sp add: (button1 := (Button content: 'Clear' callback: [textBox text: ''])).
  sp add: (button2 := (Button content: 'Method Template' callback: [self methodTemplate])).
  sp add: (button3 := (Button content: 'Save to file' callback: [self saveToFile])).
  sp add: (button4 := (Button content: 'Save to append file' callback: [self saveToAppendFile])).
  sp add: (button5 := (Button content: 'Clear saved file' callback: [self clearSavedFile])).
  sp add: (button6 := (Button content: 'Clear append file' callback: [self clearAppendFile])).
  button1 width: bWidth. 
  button2 width: bWidth. 
  button3 width: bWidth. 
  button4 width: bWidth. 
  button5 width: bWidth. 
  button6 width: bWidth. 
  button1 background: Brushes yellow. 
  button2 background: Brushes yellow. 
  button3 background: Brushes yellow. 
  button4 background: Brushes yellow. 
  button5 background: Brushes yellow. 
  button6 background: Brushes yellow. 
  ^ sp
!
clearAppendFile
  File writeAllText: 'power_space_append.st' from: ''
!
clearSavedFile
  File writeAllText: 'power_space.st' from: ''
!
cutText
 | cutStart text textLeft textRight |
  Clipboard setText: textBox selectedText.
  text := textBox text.
  cutStart := textBox selectionStart.
  textLeft := text substring: 0 len: cutStart.
  textRight := text substring: (cutStart + textBox selectionLength)
                    len: (text length - textLeft length - textBox selectionLength).
  textBox text: (textLeft + textRight).
  textBox selectionStart: cutStart
!
doIt
  | method str |
  str := textBox selectedText trim.
  str length == 0 ifTrue: [^nil].
  method := Compiler compileSnippet: str.
  method isNil ifTrue:[^nil].
  Processor scheduleProcess: (Process fromMethod: method)
!
findIt
  | index string text |
  text := textBox text.
  string := textBox selectedText trim.
  string length == 0 ifTrue: [^nil].
  index := (text indexOf: string start: (textBox selectionStart + string length)).
  index > 0 ifTrue: [textBox selectionStart: index.
                     textBox selectionLength: string length]
!
implementorsMethodOfTextbox
  | selector string |
  string := textBox selectedText trim.
  selector := string asSymbol.
  (Vm implementorsOf: selector) inspect
!
inspectIt
  | method process str |
  str := textBox selectedText trim.
  method := Compiler compileSnippet: str.
  method isNil ifTrue:[^nil].
  process := Process fromMethod: method.
  process callback: [:val | self inspectResult: val].
  Processor scheduleProcess: process
!
inspectResult: anObject
  anObject inspect
!
methodTemplate
  textBox println: '| myVar |'.
  textBox println: ''.
  textBox appendText: 'Transcript showCr:'
!
open 
  "   PowerWorkspace new open   "
  | dockpanel top |
  window := self topWindowClass new.
  window title: '~~~ PowerWorkspace for Vista Smalltalk ~~~'.
  window width: 797; height: 560.
  window background: Brushes gray.
  dockpanel := DockPanel new.
  top := self buildTop.
  top clipToBounds: True.
  dockpanel add: top.
  DockPanel setDock: top to: Dock top.
  textBox := TextEditor new.
  textBox showLines: true. 
  textBox showBreakpoints: true. 
  textBox height: 450.
  textBox width: 790. 
  textBox background: Brushes ivory.
  textBox foreground: Brushes navy.
  dockpanel add: textBox.
  DockPanel setDock: textBox to: Dock top.
  window add: dockpanel.
  self setTextBoxContextMenu.
  window open
!
pasteText
  | insertStart text textLeft textRight |
  text := textBox text.
  insertStart := textBox selectionStart.
  textLeft := text substring: 0 len: insertStart.
  textRight := text substring: (insertStart + textBox selectionLength)
                    len: (text length - textLeft length - textBox selectionLength).
  textBox text: (textLeft + Clipboard getText + textRight).
  textBox selectionStart: insertStart
!
saveToAppendFile
  | outFile textSave |
  (File exists: 'power_space_append.st') ifTrue: [textSave := (File readAllText: 'power_space_append.st') + (textBox text)]
                                         ifFalse: [textSave := textBox text].
  textSave := textSave+ Environment newline.
  outFile := File writeAllText: 'power_space_append.st' from: textSave
!
saveToFile
    File writeAllText: 'power_space.st' from: textBox text
!
selectAllText
  textBox selectionStart: 0.
  textBox selectionLength: (textBox text length)
!
sendersMethodOfTextbox
  | selector string |
  string := textBox selectedText trim.
  selector := string asSymbol.
  (Vm sendersOf: selector) inspect
!
setTextBoxContextMenu
  | menu |
  menu := ContextMenu new.
  menu add: (MenuItem name: 'Copy' action: [Clipboard setText: textBox selectedText]).
  menu add: (MenuItem name: 'Cut' action: [self cutText]).
  menu add: (MenuItem name: 'Paste' action: [self pasteText]).
  menu add: Separator new.
  menu add: (MenuItem name: 'Copy all' action: [Clipboard setText: textBox text]).
  menu add: (MenuItem name: 'Select all' action: [self selectAllText]).
  menu add: Separator new.
  menu add: (MenuItem name: 'Find it ...' action: [self findIt]).
  menu add: Separator new.
  menu add: (MenuItem name: 'Do It' action: [self doIt]).
  menu add: (MenuItem name: 'Show It' action: [self showIt]).
  menu add: (MenuItem name: 'Inspect It' action: [self inspectIt]).
  menu add: Separator new.
  menu add: (MenuItem name: 'Senders of it ...' action: [self sendersMethodOfTextbox]).
  menu add: (MenuItem name: 'Implementors of it ...' action: [self implementorsMethodOfTextbox]).
  menu add: Separator new.
  menu add: (MenuItem name: 'Breakpoints' action: [self toggleBreakpoints]).
  menu add: (MenuItem name: 'Linenumbers' action: [self toggleLines]).
  textBox contextMenu: menu
!
showIt
  | method process str |
  str := (textBox selectedText trim).
  str length == 0 ifTrue: [^nil].
  method := Compiler compileSnippet: str.
  method isNil ifTrue:[^nil].
  process := Process fromMethod: method.
  process callback: [:val | self showResult: val].
  Processor scheduleProcess: process
!
showResult: anObject
  | box n |
  box := textBox.
  n := box selectionStart + box selectionLength.
  box selectionStart: n+1.
  box selectedText: anObject printString
!
toggleBreakpoints
  textBox showBreakpoints: textBox showBreakpoints not
!
toggleLines
  textBox showLines: textBox showLines not
!
CalmoSoft subclass: #PowerWriter
instanceVariableNames: 'textBox window'
classVariableNames: ''
!
PowerWriter class
!
copyright
   "   ~  written by: Gal Zsolt & Cathlyn Cosca ( CalmoSoft ) ~ 2006-2007 ~ calmosoft@gmail.com ~   "
!
PowerWriter
!
buildTop1
  | bWidth sp |
  bWidth := 130.
  sp := StackPanel horizontal.
  sp add: (button1 := (Button content: 'Clear' callback: [textBox text: ''])).
  sp add: (button2 := (Button content: 'Method Template' callback: [self methodTemplate])).
  sp add: (button3 := (Button content: 'Save to file' callback: [self saveToFile])).
  sp add: (button4 := (Button content: 'Save to append file' callback: [self saveToAppendFile])).
  sp add: (button5 := (Button content: 'Clear saved file' callback: [self clearSavedFile])).
  sp add: (button6 := (Button content: 'Clear append file' callback: [self clearAppendFile])).
  button1 width: bWidth. 
  button2 width: bWidth. 
  button3 width: bWidth. 
  button4 width: bWidth. 
  button5 width: bWidth. 
  button6 width: bWidth. 
  button1 background: Brushes yellow. 
  button2 background: Brushes yellow. 
  button3 background: Brushes yellow. 
  button4 background: Brushes yellow. 
  button5 background: Brushes yellow. 
  button6 background: Brushes yellow. 
  ^ sp
!
buildTop2
  | bWidth sp |
  bWidth := (130/8).
  sp := StackPanel horizontal.
  sp add: (button1 := (Button content: 'a' callback: [textBox text: textBox text + 'a'])).
  sp add: (button2 := (Button content: 'b' callback: [textBox text: textBox text + 'b'])).
  sp add: (button3 := (Button content: 'c' callback: [textBox text: textBox text + 'c'])).
  sp add: (button4 := (Button content: 'd' callback: [textBox text: textBox text + 'd'])).
  sp add: (button5 := (Button content: 'e' callback: [textBox text: textBox text + 'e'])).
  sp add: (button6 := (Button content: 'f' callback: [textBox text: textBox text + 'f'])).
  sp add: (button7 := (Button content: 'g' callback: [textBox text: textBox text + 'g'])).
  sp add: (button8 := (Button content: 'h' callback: [textBox text: textBox text + 'h'])).
  sp add: (button9 := (Button content: 'i' callback: [textBox text: textBox text + 'i'])).
  sp add: (button10 := (Button content: 'j' callback: [textBox text: textBox text + 'j'])).
  sp add: (button11 := (Button content: 'k' callback: [textBox text: textBox text + 'k'])).
  sp add: (button12 := (Button content: 'l' callback: [textBox text: textBox text + 'l'])).
  sp add: (button13 := (Button content: 'm' callback: [textBox text: textBox text + 'm'])).
  sp add: (button14 := (Button content: 'n' callback: [textBox text: textBox text + 'n'])).
  sp add: (button15 := (Button content: 'o' callback: [textBox text: textBox text + 'o'])).
  sp add: (button16 := (Button content: 'p' callback: [textBox text: textBox text + 'p'])).
  button1 width: bWidth. 
  button2 width: bWidth. 
  button3 width: bWidth. 
  button4 width: bWidth. 
  button5 width: bWidth. 
  button6 width: bWidth. 
  button7 width: bWidth. 
  button8 width: bWidth. 
  button9 width: bWidth. 
  button10 width: bWidth. 
  button11 width: bWidth. 
  button12 width: bWidth. 
  button13 width: bWidth. 
  button14 width: bWidth. 
  button15 width: bWidth. 
  button16 width: bWidth. 
  button1 background: Brushes yellow. 
  button2 background: Brushes yellow. 
  button3 background: Brushes yellow. 
  button4 background: Brushes yellow. 
  button5 background: Brushes yellow. 
  button6 background: Brushes yellow.
  button7 background: Brushes yellow.
  button8 background: Brushes yellow.
  button9 background: Brushes yellow.
  button10 background: Brushes yellow. 
  button11 background: Brushes yellow. 
  button12 background: Brushes yellow. 
  button13 background: Brushes yellow. 
  button14 background: Brushes yellow. 
  button15 background: Brushes yellow. 
  button16 background: Brushes yellow.
  ^ sp
!
buildTop3
  | bWidth sp |
  bWidth := (130/8).
  sp := StackPanel horizontal.
  sp add: (button17 := (Button content: 'q' callback: [textBox text: textBox text + 'q'])).
  sp add: (button18 := (Button content: 'r' callback: [textBox text: textBox text + 'r'])).
  sp add: (button19 := (Button content: 's' callback: [textBox text: textBox text + 's'])).
  sp add: (button20 := (Button content: 't' callback: [textBox text: textBox text + 't'])).
  sp add: (button21 := (Button content: 'u' callback: [textBox text: textBox text + 'u'])).
  sp add: (button22 := (Button content: 'x' callback: [textBox text: textBox text + 'x'])).
  sp add: (button23 := (Button content: 'y' callback: [textBox text: textBox text + 'y'])).
  sp add: (button24 := (Button content: 'v' callback: [textBox text: textBox text + 'v'])).
  sp add: (button25 := (Button content: 'w' callback: [textBox text: textBox text + 'w'])).
  sp add: (button26 := (Button content: 'z' callback: [textBox text: textBox text + 'z'])).
  sp add: (button27 := (Button content: ' ' callback: [textBox text: textBox text + ' '])).
  sp add: (button28 := (Button content: '. ' callback: [textBox text: textBox text + '.'])).
  sp add: (button29 := (Button content: '[ ' callback: [textBox text: textBox text + '['])).
  sp add: (button30 := (Button content: ' ]' callback: [textBox text: textBox text + ']'])).
  sp add: (button31 := (Button content: ' (' callback: [textBox text: textBox text + '('])).
  sp add: (button32 := (Button content: ' )' callback: [textBox text: textBox text + ')'])).
  button17 width: bWidth. 
  button18 width: bWidth. 
  button19 width: bWidth. 
  button20 width: bWidth. 
  button21 width: bWidth. 
  button22 width: bWidth. 
  button23 width: bWidth. 
  button24 width: bWidth. 
  button25 width: bWidth. 
  button26 width: bWidth. 
  button27 width: bWidth. 
  button28 width: bWidth. 
  button29 width: bWidth. 
  button30 width: bWidth. 
  button31 width: bWidth. 
  button32 width: bWidth. 
  button17 background: Brushes yellow.
  button18 background: Brushes yellow.
  button19 background: Brushes yellow.
  button20 background: Brushes yellow. 
  button21 background: Brushes yellow. 
  button22 background: Brushes yellow. 
  button23 background: Brushes yellow. 
  button24 background: Brushes yellow. 
  button25 background: Brushes yellow. 
  button26 background: Brushes yellow. 
  button27 background: Brushes yellow. 
  button28 background: Brushes yellow. 
  button29 background: Brushes yellow. 
  button30 background: Brushes yellow. 
  button31 background: Brushes yellow. 
  button32 background: Brushes yellow. 
  ^ sp
!
clearAppendFile
  File writeAllText: 'power_space_append.st' from: ''
!
clearSavedFile
  File writeAllText: 'power_space.st' from: ''
!
cutText
 | cutStart text textLeft textRight |
  Clipboard setText: textBox selectedText.
  text := textBox text.
  cutStart := textBox selectionStart.
  textLeft := text substring: 0 len: cutStart.
  textRight := text substring: (cutStart + textBox selectionLength)
                    len: (text length - textLeft length - textBox selectionLength).
  textBox text: (textLeft + textRight).
  textBox selectionStart: cutStart
!
doIt
  | method str |
  str := textBox selectedText trim.
  str length == 0 ifTrue: [^nil].
  method := Compiler compileSnippet: str.
  method isNil ifTrue:[^nil].
  Processor scheduleProcess: (Process fromMethod: method)
!
findIt
  | index string text |
  text := textBox text.
  string := textBox selectedText trim.
  string length == 0 ifTrue: [^nil].
  index := (text indexOf: string start: (textBox selectionStart + string length)).
  index > 0 ifTrue: [textBox selectionStart: index.
                     textBox selectionLength: string length]
!
implementorsMethodOfTextbox
  | selector string |
  string := textBox selectedText trim.
  selector := string asSymbol.
  (Vm implementorsOf: selector) inspect
!
inspectIt
  | method process str |
  str := textBox selectedText trim.
  method := Compiler compileSnippet: str.
  method isNil ifTrue:[^nil].
  process := Process fromMethod: method.
  process callback: [:val | self inspectResult: val].
  Processor scheduleProcess: process
!
inspectResult: anObject
  anObject inspect
!
methodTemplate
  textBox println: '| myVar |'.
  textBox println: ''.
  textBox appendText: 'Transcript showCr:'
!
open 
  "   PowerWriter new open   "
  | dockpanel top |
  window := self topWindowClass new.
  window title: '~~~ PowerWriter for Vista Smalltalk ~~~'.
  window width: 797; height: 560.
  window background: Brushes gray.
  dockpanel := DockPanel new.
  top := self buildTop1.
  top clipToBounds: True.
  dockpanel add: top.
  DockPanel setDock: top to: Dock top.
  top := self buildTop2.
  top clipToBounds: True.
  dockpanel add: top.
  DockPanel setDock: top to: Dock top.
  top := self buildTop3.
  top clipToBounds: True.
  dockpanel add: top.
  DockPanel setDock: top to: Dock top.
  textBox := TextEditor new.
  textBox showLines: true. 
  textBox showBreakpoints: true. 
  textBox height: 450.
  textBox width: 790. 
  textBox background: Brushes ivory.
  textBox foreground: Brushes navy.
  dockpanel add: textBox.
  DockPanel setDock: textBox to: Dock top.
  window add: dockpanel.
  self setTextBoxContextMenu.
  window open
!
pasteText
  | insertStart text textLeft textRight |
  text := textBox text.
  insertStart := textBox selectionStart.
  textLeft := text substring: 0 len: insertStart.
  textRight := text substring: (insertStart + textBox selectionLength)
                    len: (text length - textLeft length - textBox selectionLength).
  textBox text: (textLeft + Clipboard getText + textRight).
  textBox selectionStart: insertStart
!
saveToAppendFile
  | outFile textSave |
  (File exists: 'power_space_append.st') ifTrue: [textSave := (File readAllText: 'power_space_append.st') + (textBox text)]
                                         ifFalse: [textSave := textBox text].
  textSave := textSave+ Environment newline.
  outFile := File writeAllText: 'power_space_append.st' from: textSave
!
saveToFile
    File writeAllText: 'power_space.st' from: textBox text
!
selectAllText
  textBox selectionStart: 0.
  textBox selectionLength: (textBox text length)
!
sendersMethodOfTextbox
  | selector string |
  string := textBox selectedText trim.
  selector := string asSymbol.
  (Vm sendersOf: selector) inspect
!
setTextBoxContextMenu
  | menu |
  menu := ContextMenu new.
  menu add: (MenuItem name: 'Copy' action: [Clipboard setText: textBox selectedText]).
  menu add: (MenuItem name: 'Cut' action: [self cutText]).
  menu add: (MenuItem name: 'Paste' action: [self pasteText]).
  menu add: Separator new.
  menu add: (MenuItem name: 'Copy all' action: [Clipboard setText: textBox text]).
  menu add: (MenuItem name: 'Select all' action: [self selectAllText]).
  menu add: Separator new.
  menu add: (MenuItem name: 'Find it ...' action: [self findIt]).
  menu add: Separator new.
  menu add: (MenuItem name: 'Do It' action: [self doIt]).
  menu add: (MenuItem name: 'Show It' action: [self showIt]).
  menu add: (MenuItem name: 'Inspect It' action: [self inspectIt]).
  menu add: Separator new.
  menu add: (MenuItem name: 'Senders of it ...' action: [self sendersMethodOfTextbox]).
  menu add: (MenuItem name: 'Implementors of it ...' action: [self implementorsMethodOfTextbox]).
  menu add: Separator new.
  menu add: (MenuItem name: 'Breakpoints' action: [self toggleBreakpoints]).
  menu add: (MenuItem name: 'Linenumbers' action: [self toggleLines]).
  textBox contextMenu: menu
!
showIt
  | method process str |
  str := (textBox selectedText trim).
  str length == 0 ifTrue: [^nil].
  method := Compiler compileSnippet: str.
  method isNil ifTrue:[^nil].
  process := Process fromMethod: method.
  process callback: [:val | self showResult: val].
  Processor scheduleProcess: process
!
showResult: anObject
  | box n |
  box := textBox.
  n := box selectionStart + box selectionLength.
  box selectionStart: n+1.
  box selectedText: anObject printString
!
toggleBreakpoints
  textBox showBreakpoints: textBox showBreakpoints not
!
toggleLines
  textBox showLines: textBox showLines not
!
CalmoSoft subclass: #SuePuzzle
instanceVariableNames: 'canvas empty size size2 tileArray'
classVariableNames: ''
!
SuePuzzle class
!
copyright
   "   ~  written by: Gal Zsolt & Cathlyn Cosca ( CalmoSoft ) ~ 2006-2007 ~ calmosoft@gmail.com ~   "
!
SuePuzzle
!
addTiles
  1 to: (size2 - size) do:[:nr | self createTile: nr.
                                 self placeTile: nr].
  empty := size2 - size.
  (tileArray at: empty) content: ''.
  (size2 - 2) to: size2 do:[:nr | self createTile: nr.
                                  self placeTile: nr]
!
buildTopPanel
  | sp |
  sp := StackPanel horizontal.
  sp add: (Button content: '3x3' callback: [self changeSize: 3]).
  sp add: (Button content: '4x4' callback: [self changeSize: 4]).
  sp add: (Button content: '5x5' callback: [self changeSize: 5]).
  sp add: (Button content: '6x6' callback: [self changeSize: 6]).
  sp add: (Button content: '7x7' callback: [self changeSize: 7]).
  sp add: (Button content: '8x8' callback: [self changeSize: 8]).
  sp add: (Button content: '9x9' callback: [self changeSize: 9]).
  ^ sp
!
canMove: nr
  up := (empty = (nr - size)).
  down := (empty = (nr + size)).
  left := ((empty = (nr - 1)) and: ((nr\\size)~=1)).
  right := ((empty = (nr + 1)) and: ((nr\\size)~=0)).
  move := up or: down or: left or: right.
  ^move
!
changeSize: nr
  self deleteTiles.
  size := nr.
  size2 := (size*size) + size.
  tileArray := Array new: size2.
  self addTiles
!
createTile: nr
  tile := (Button content: nr callback: [self tryMove: nr]).
  (nr = (size2 - 1)) ifTrue: [tile := (Button content: 'Here' callback: [self tileOut])].
  (nr = size2) ifTrue: [tile := (Button content: '->'
                                        callback: [self rotate: (size2 - 1)
                                        angle: ((tileArray at: (size2 - 1)) renderTransform angle) + 90])].
  (nr = (size2 - 2)) ifTrue: [tile := (Button content: '<-'
                                              callback: [self rotate: (size2 - 1)
                                              angle: ((tileArray at: (size2 - 1)) renderTransform angle) - 90])].
  tile width: canvas actualWidth / size.
  "tile height: canvas actualHeight / size."
  tile height: tile width.
  tileArray at: nr put: tile.
  canvas add: (tileArray at: nr).
  ^ tile
!
deleteTiles
  canvas clear
!
gameOver
  1 to: (size2 - 1) do: [:nr | tileContent := (tileArray at: nr) content.
                               (tileContent ~= nr) ifTrue: [^false]].
  ^true
!
initVariables  
  size := 4.
  size2 := (size*size) + size.
  tileArray := Array new: size2
!
open
  "   SuePuzzle new open   "
  | button dockpanel top window |
  self initVariables.
  window := self topWindowClass new.
  window title: 'SuePuzzle~15 Puzzle Game'.
  dockpanel := DockPanel new.
  button := (Button content: 'Scramble' callback: [self scramble]).
  dockpanel add: button.
  DockPanel setDock: button to: Dock bottom.
  top := self buildTopPanel.
  dockpanel add: top.
  DockPanel setDock: top to: Dock top.
  canvas := Canvas new.
  canvas background: Brushes gray.
  dockpanel add: canvas.
  window add: dockpanel.
  window width: 190.
  window height: 250.
  window open.
  self addTiles
!
placeTile: nr
  | col row x y |
  tile := tileArray at: nr.
  row := ((nr - 1) // size) + 1.
  col := ((nr - 1) \\ size) + 1.
  x := canvas actualWidth * (col - 1) / size.
  y := canvas actualHeight * (row - 1) / size.
  Canvas setLeft: tile to: x.
  Canvas setTop: tile to: y.
  transform := RotateTransform new.
  transform angle: 0; centerX: (tile width)/2; centerY: (tile height)/2.
  tile renderTransform: transform
!
rotate: tileNr angle: tileAngle
  | tile transform |
  tile := tileArray at: tileNr.
  transform := RotateTransform new.
  transform angle: tileAngle;
            centerX: (tile width)/2;
            centerY: (tile height)/2.
  tile renderTransform: transform.
  (tileNr = (size2 - 1)) ifTrue: [transform := RotateTransform new.
                                  transform angle: (tile renderTransform angle);
                                            centerX: (tile width)/2;
                                            centerY: (tile height)/2.
                                  (tileArray at: size2 - 1) renderTransform: transform].
  ^tile
!
scramble
  | random tile |
  angleArray := # (0 90 180 270 -90 -180 -270).
  random := Random new.
  (size * 50 ) timesRepeat: [rand := (random nextMin: 1 max: (size2 -size + 1)).
                             self tryMove: rand].
  1 to: (size2 - size) do: [:nr | rand := (random nextMin: 1 max: 8).
                                  tileAngle := angleArray at: rand.
                                  self rotate: nr angle: tileAngle]
!
tileOut
  | tile1 tile2 |
  tile1 := (tileArray at: (size2 - 1)).
  tile2 := (tileArray at: (size2 - size - 1)).
  (tile1 content = 'Here' and: tile2 content ~= '') ifTrue: [tile1 content: tile2 content.
                                                             transform := RotateTransform new.
                                                             transform angle: (tile2 renderTransform angle);
                                                                       centerX: (tile1 width)/2;
                                                                       centerY: (tile1 height)/2.
                                                             tile1 renderTransform: transform.
                                                             tile2 content: 'Back'.
                                                             tile2 renderTransform: Transform identity.
                                                             1 to: size2 - size do: [:nr | (tileArray at: nr) isenabled: false].
                                                             (tileArray at: (size2 - size - 1)) isenabled: true]
!
tryMove: nr
  | tile1 tile2 |
  tile1 := (tileArray at: (size2 - 1)).
  tile2 := (tileArray at: (size2 - size - 1)).
  (nr = (size2 - size - 1) and: tile1 content ~= 'Here') ifTrue: [tile2 content: tile1 content.
                                                                  transform := RotateTransform new.
                                                                  transform angle: (tile1 renderTransform angle);
                                                                  centerX: (tile2 width)/2;
                                                                  centerY: (tile2 height)/2.
                                                                  tile2 renderTransform: transform.
                                                                  tile1 renderTransform: Transform identity.
                                                                  tile1 content: 'Here'.
                                                                  1 to: size2 - size do: [:nr |
                                                                                (tileArray at: nr) isenabled: true]. 
                                                                  ^tile1].
  (self canMove: nr) ifTrue: [(tileArray at: empty) content: (tileArray at: nr) content.
                              transform := RotateTransform new.
                              transform angle: ((tileArray at: nr) renderTransform angle);
                              centerX: ((tileArray at: empty) width)/2;
                              centerY: ((tileArray at: empty) height)/2.
                              (tileArray at: empty) renderTransform: transform.
                              (tileArray at: nr) content: ''.
                              (tileArray at: nr) renderTransform: Transform identity.
                              empty := nr.
                              self gameOver ifTrue: [(tileArray at: size2) content: 'Hooray!']]
!
CalmoSoft subclass: #SystemBrowser
instanceVariableNames: 'class methodEditor searchedText treeClassMethods type typeLine window'
classVariableNames: ''
!
SystemBrowser class
!
copyright
   "   ~  written by: Gal Zsolt & Cathlyn Cosca ( CalmoSoft ) ~ 2006-2007 ~ calmosoft@gmail.com ~   "
!
SystemBrowser
!
makeAbcClasses
  | buttonHeight dock sp |
  buttonHeight := 23.7. 
  dock := window dockpanel2.
  sp := StackPanel vertical.
  button1 := (Button content: 'A' callback: [self showhAbcMethods: 'A']).
  button2 := (Button content: 'B' callback: [self showhAbcMethods: 'B']).
  button3 := (Button content: 'C' callback: [self showhAbcMethods: 'C']).
  button4 := (Button content: 'D' callback: [self showhAbcMethods: 'D']).
  button5 := (Button content: 'E' callback: [self showhAbcMethods: 'E']).
  button6 := (Button content: 'F' callback: [self showhAbcMethods: 'F']).
  button7 := (Button content: 'G' callback: [self showhAbcMethods: 'G']).
  button8 := (Button content: 'H' callback: [self showhAbcMethods: 'H']).
  button9 := (Button content: 'I' callback: [self showhAbcMethods: 'I']).
  button10 := (Button content: 'J' callback: [self showhAbcMethods: 'J']).
  button11 := (Button content: 'K' callback: [self showhAbcMethods: 'K']).
  button12 := (Button content: 'L' callback: [self showhAbcMethods: 'L']).
  button13 := (Button content: 'M' callback: [self showhAbcMethods: 'M']).
  button14 := (Button content: 'N' callback: [self showhAbcMethods: 'N']).
  button15 := (Button content: 'O' callback: [self showhAbcMethods: 'O']).
  button16 := (Button content: 'P' callback: [self showhAbcMethods: 'P']).
  button17 := (Button content: 'Q' callback: [self showhAbcMethods: 'Q']).
  button18 := (Button content: 'R' callback: [self showhAbcMethods: 'R']).
  button19 := (Button content: 'S' callback: [self showhAbcMethods: 'S']).
  button20 := (Button content: 'T' callback: [self showhAbcMethods: 'T']).
  button21 := (Button content: 'U' callback: [self showhAbcMethods: 'U']).
  button22 := (Button content: 'V' callback: [self showhAbcMethods: 'V']).
  button23 := (Button content: 'W' callback: [self showhAbcMethods: 'W']).
  button24 := (Button content: 'X' callback: [self showhAbcMethods: 'X']).
  button25 := (Button content: 'Y' callback: [self showhAbcMethods: 'Y']).
  button26 := (Button content: 'Z' callback: [self showhAbcMethods: 'Z']).
  button1 height: buttonHeight.
  button2 height: buttonHeight.
  button3 height: buttonHeight.
  button4 height: buttonHeight.
  button5 height: buttonHeight.
  button6 height: buttonHeight.
  button7 height: buttonHeight.
  button8 height: buttonHeight.
  button9 height: buttonHeight.
  button10 height: buttonHeight.
  button11 height: buttonHeight.
  button12 height: buttonHeight.
  button13 height: buttonHeight.
  button14 height: buttonHeight.
  button15 height: buttonHeight.
  button16 height: buttonHeight.
  button17 height: buttonHeight.
  button18 height: buttonHeight.
  button19 height: buttonHeight.
  button20 height: buttonHeight.
  button21 height: buttonHeight.
  button22 height: buttonHeight.
  button23 height: buttonHeight.
  button24 height: buttonHeight.
  button25 height: buttonHeight.
  button26 height: buttonHeight.
  sp add: button1.
  sp add: button2.
  sp add: button3.
  sp add: button4.
  sp add: button5.
  sp add: button6.
  sp add: button7.
  sp add: button8.
  sp add: button9.
  sp add: button10.
  sp add: button11.
  sp add: button12.
  sp add: button13.
  sp add: button14.
  sp add: button15.
  sp add: button16.
  sp add: button17.
  sp add: button18.
  sp add: button19.
  sp add: button20.
  sp add: button21.
  sp add: button22.
  sp add: button23.
  sp add: button24.
  sp add: button25.
  sp add: button26.
  dock add: sp
!
makeSearch
  | dock sp |
  searchedText := window searchText.
  searchedText textalignment: TextAlignment center. 
  searchedText text: 'type text here to search in methods'.
  dock := window dockpanel.
  sp := StackPanel horizontal.
  sp add: (Button content: ' Search text in methods ' callback: [self searchMethods]).
  sp add: (Button content: ' Show all methods ' callback: [self showAllMethods]).
  dock add: sp
!
open
  "   SystemBrowser new open   "
  window := MethodFinderandSystemBrowserLayout new.
  window title: '~~~ SystemBrowser for Vista Smalltalk ~~~'.
  treeClassMethods := window treeLeft.
  treeClassMethods background: (SolidColorBrush new: Color customGray).
  methodEditor := window methodTextEditor.
  methodEditor foreground: Brushes navy.
  typeLine := window typeText.
  typeLine textalignment: TextAlignment center. 
  typeLine text: 'information line'.
  Handler on: treeClassMethods event: 'SelectedItemChanged' block: [self showMethod].
  methodEditor showLines: true.
  self makeSearch.
  self makeAbcClasses.
  self setEditorContextMenu.
  self setFontSize.
  window open
!
searchMethods
  | bool1 bool2 bool3 bool4 method methodClassDict methodDict newMethod newTree nr nrTotal prim rootClass |
  nr := 0.
  nrTotal := 0.
  treeClassMethods items clear.
  methodEditor text: ''.
  typeLine text: 'Loading ...'.
  prim := searchedText text.
  rootClass := Vm rootClass. 
  rootClass withAllSubclasses do:[:cls | methodDict := cls methodDictionary.
                                         methodDict keysDo: [:k | method := cls lookupSelector: k.
                                                                  bool1 := ((method text indexOf: prim start: 0) > 0).
                                                                  bool1 ifTrue: [nrTotal := nrTotal + 1]].
                                         methodClassDict := cls class methodDictionary.
                                         methodClassDict keysDo: [:k | method := cls class lookupSelector: k.
                                                                       bool2 := ((method text indexOf: prim start: 0) > 0).
                                                                       bool2 ifTrue: [nrTotal := nrTotal + 1]]].
  nrTotal = 0 ifTrue: [typeLine text: 'no results']
              ifFalse: [rootClass withAllSubclasses do:[:cls | methodDict := cls methodDictionary.
                                                               methodDict keysDo: [:k | method := cls lookupSelector: k.
                                                                                        bool3 := ((method text indexOf: prim start: 0) > 0).
                                                                                        bool3 ifTrue: [nr := nr + 1.
                                                                                                       typeLine text: nr asString + ' / ' + nrTotal asString. 
                                                                                                       newMethod := cls name + '>>' + k.
                                                                                                       newTree := TreeViewItem new.
                                                                                                       newTree header: newMethod asString.
                                                                                                       newTree tag: newMethod asString + '#i'.
                                                                                                       treeClassMethods items add: newTree]].
                                                               methodClassDict := cls class methodDictionary.
                                                               methodClassDict keysDo: [:k | method := cls class lookupSelector: k.
                                                                                             bool4 := ((method text indexOf: prim start: 0) > 0).
                                                                                             bool4 ifTrue: [nr := nr + 1.
                                                                                                            typeLine text: nr asString + ' / ' + nrTotal asString.   
                                                                                                            newMethod := cls name + '>>' + k.
                                                                                                            newTree := TreeViewItem new.
                                                                                                            newTree header: newMethod asString.
                                                                                                            newTree tag: newMethod asString + '#c'.
                                                                                                            treeClassMethods items add: newTree]]]]
!
setEditorContextMenu
  | menu |
  menu := ContextMenu new.
  menu add: (MenuItem name: 'Save' action: [self textSave]).
  methodEditor contextMenu: menu
!
setFontSize
  | fntsize |
  fntsize := 12.
  treeClassMethods fontsize: fntsize.
  typeLine fontsize: fntsize.
  searchedText fontsize: fntsize
!
showAllMethods
  | methodClassDict methodDict newMethod newTree nr nrTotal rootClass |
  nr := 0.
  nrTotal := 0.
  treeClassMethods items clear.
  methodEditor text: ''.
  typeLine text: 'Loading ...'.
  searchedText text: 'type text here to search in methods'.
  rootClass := Vm rootClass. 
  rootClass withAllSubclasses do:[:cls | methodDict := cls methodDictionary.
                                         methodClassDict := cls class methodDictionary.
                                         nrTotal := nrTotal + methodDict size + methodClassDict size].
  rootClass withAllSubclasses do:[:cls | methodDict := cls methodDictionary.
                                         methodDict keysDo: [:k | nr := nr + 1.
                                                                  typeLine text: nr asString + ' / ' + nrTotal asString. 
                                                                  newMethod := cls name + '>>' + k.
                                                                  newTree := TreeViewItem new.
                                                                  newTree header: newMethod asString.
                                                                  newTree tag: newMethod asString + '#i'.
                                                                  treeClassMethods items add: newTree].
                                         methodClassDict := cls class methodDictionary.
                                         methodClassDict keysDo: [:k | nr := nr + 1.
                                                                       typeLine text: nr asString + ' / ' + nrTotal asString.   
                                                                       newMethod := cls name + '>>' + k.
                                                                       newTree := TreeViewItem new.
                                                                       newTree header: newMethod asString.
                                                                       newTree tag: newMethod asString + '#c'.
                                                                       treeClassMethods items add: newTree]]
!
showhAbcMethods: aCharacter
  | bool1 bool2 methodClassDict methodDict newMethod newTree nr nrTotal rootClass |
  nr := 0.
  nrTotal := 0.
  treeClassMethods items clear.
  methodEditor text: ''.
  typeLine text: 'Loading ...'.
  searchedText text: 'type text here to search in methods'.
  rootClass := Vm rootClass. 
  rootClass withAllSubclasses do:[:cls | methodDict := cls methodDictionary.
                                         bool1 := (cls name substring: 0 len: 1) = aCharacter.
                                         bool1 ifTrue:[methodClassDict := cls class methodDictionary.
                                                       nrTotal := nrTotal + methodDict size + methodClassDict size]].
  nrTotal = 0 ifTrue: [typeLine text: 'no such methods']
              ifFalse: [rootClass withAllSubclasses do:[:cls | methodDict := cls methodDictionary.
                                                               bool2 := (cls name substring: 0 len: 1) = aCharacter.
                                                               bool2 ifTrue:[methodDict keysDo: [:k | nr := nr + 1.
                                                                                                      typeLine text: nr asString + ' / ' + nrTotal asString. 
                                                                                                      newMethod := cls name + '>>' + k.
                                                                                                      newTree := TreeViewItem new.
                                                                                                      newTree header: newMethod asString.
                                                                                                      newTree tag: newMethod asString + '#i'.
                                                                                                      treeClassMethods items add: newTree].
                                                                             methodClassDict := cls class methodDictionary.
                                                                             methodClassDict keysDo: [:k | nr := nr + 1.
                                                                                                           typeLine text: nr asString + ' / ' + nrTotal asString.   
                                                                                                           newMethod := cls name + '>>' + k.
                                                                                                           newTree := TreeViewItem new.
                                                                                                           newTree header: newMethod asString.
                                                                                                           newTree tag: newMethod asString + '#c'.
                                                                                                           treeClassMethods items add: newTree]]]]
!
showMethod
   | className index item len method rootClass selector |
   item := (treeClassMethods selectedItem tag) asString.
   index := item indexOf: '>' start: 0.
   len := item length.
   className := (item substring: 0 len: index).
   selector := (item substring: index + 2 len: len - index - 4) asSymbol.
   rootClass := Vm rootClass.
   rootClass withAllSubclasses do:[:cls | cls name = className ifTrue: [class := cls]].
   (item endsWith: '#i') ifTrue: [method := class lookupSelector: selector.
                                  typeLine text: 'instance method'.
                                  type := 'i']
                         ifFalse: [method := class class lookupSelector: selector.
                                   typeLine text: 'class method'.
                                   type := 'c'].
   methodEditor text: method text
!
textSave
  | txt |
  txt := methodEditor text trim.
  type = 'i' ifTrue: [SmalltalkReader addMethod: class string: txt]
             ifFalse: [SmalltalkReader addMethod: class class string: txt].
  methodEditor text: txt
!
Object subclass: #Collection
instanceVariableNames: ''
classVariableNames: ''
!
Collection
!
do: aBlock
  self reset.
  [self move] whileTrue: [aBlock value: self current]
!
Collection subclass: #Dictionary
instanceVariableNames: ''
classVariableNames: ''
maps: 'vdictionary'
!
Dictionary class
!
new
  <primitive: 'vdictionary .ctor'>
!
Dictionary
!
at: aKey
   <primitive: 'vdictionary get_item object'>
!
at: aKey put: aValue
   <primitive: 'vdictionary set_item object object'>
!
containsKey: aKey
   <primitive: 'vdictionary containskey object'>
!
current
  <primitive: 'vdictionary current'>
!
defaultInspector
  ^ DictionaryInspector
!
isDictionary
  ^ true
!
keys
  | list |
  list := List new.
  self keysDo:[:k | list add: k].
  ^ list
!
keysDo: aBlock
  self do:[:kvp | aBlock value: kvp key]
!
move
  <primitive: 'vdictionary move'>
!
reset
  <primitive: 'vdictionary reset'>
!
size
  <primitive: 'vdictionary count'>
!
values
  | list |
  list := List new.
  self valuesDo:[:v | list add: v].
  ^ list
!
valuesDo: aBlock
  self do:[:kvp | aBlock value: kvp value]
!
Dictionary subclass: #SystemDictionary
instanceVariableNames: ''
classVariableNames: ''
maps: 'vsystemdictionary'
!
SystemDictionary class
!
new
  <primitive: 'vsystemdictionary getinstance'>
!
SystemDictionary
!
at: aSymbol
   <primitive: 'vsystemdictionary get_item object'>
!
at: aSymbol put: aValue
   <primitive: 'vsystemdictionary set_item object voop'>
!
current
  <primitive: 'vsystemdictionary current'>
!
isSystemDictionary
  ^ true
!
move
  <primitive: 'vsystemdictionary move'>
!
reset
  <primitive: 'vsystemdictionary reset'>
!
size
  <primitive: 'vsystemdictionary count'>
!
Collection subclass: #OrderedCollection
instanceVariableNames: ''
classVariableNames: ''
!
OrderedCollection
!
asConsOrAtom
  ^ self asCons
!
collect: aBlock 
   | newCollection |
   newCollection := List new.
   self do: [:each | newCollection add: (aBlock value: each)].
   ^ newCollection
!
defaultInspector
  ^ ArrayInspector
!
select: aBlock 
   | newCollection |
   newCollection := List new.
   self do: [:each | (aBlock value: each) ifTrue: [newCollection add: each]].
   ^ newCollection
!
OrderedCollection subclass: #Array
instanceVariableNames: ''
classVariableNames: ''
maps: 'varray'
!
Array class
!
new: anInteger
  <primitive: 'varray .ctor int'>
!
with: anObject
   | array |
   array := self new: 1.
   array at: 1 put: anObject.
   ^ array
!
with: anObject1 with: anObject2
   | array |
   array := self new: 2.
   array at: 1 put: anObject1.
   array at: 2 put: anObject2.
   ^ array
!
with: anObject1 with: anObject2 with: anObject3
   | array |
   array := self new: 3.
   array at: 1 put: anObject1.
   array at: 2 put: anObject2.
   array at: 3 put: anObject3.
   ^ array
!
with: anObject1 with: anObject2 with: anObject3 with: anObject4
   | array |
   array := self new: 4.
   array at: 1 put: anObject1.
   array at: 2 put: anObject2.
   array at: 3 put: anObject3.
   array at: 4 put: anObject4.
   ^ array
!
Array
!
asArray
  ^ self
!
asCons
  ^ Cons fromArray: self
!
asList
   | list |
   list := List new.
   1 to: self size do:[:i | list add: (self at: i)].
   ^ list
!
at: anInteger
   <primitive: 'varray get_item int'>
!
at: anInteger put: anObject
   <primitive: 'varray set_item int object'>
!
current
  <primitive: 'varray get_current'>
!
first
  ^ self at: 1
!
isArray
   ^ true
!
move
  <primitive: 'varray move'>
!
reset
  <primitive: 'varray reset'>
!
second
  ^ self at: 2
!
size
   <primitive: 'varray get_length'>
!
sorted
  <primitive: 'varray sorted'>
!
withoutFirst
  <primitive: 'varray withoutfirst'>
!
withoutFirst2
  ^ self withoutFirst withoutFirst
!
OrderedCollection subclass: #Cons
instanceVariableNames: ''
classVariableNames: ''
maps: 'vcons'
!
Cons class
!
car: anObject
  <primitive: 'vcons .ctor object'>
!
car: anObject1 cdr: anObject2
  <primitive: 'vcons .ctor object object'>
!
fromArray: anArray
  <primitive: 'vcons fromarray varray'>
!
new
  <primitive: 'vcons .ctor'>
!
Cons
!
asArray
  <primitive: 'vcons toarray'>
!
asCons
  ^ self
!
car
  <primitive: 'vcons get_car'>
!
cdr
  <primitive: 'vcons get_cdr'>
!
length
  <primitive: 'vcons get_length'>
!
push: anObject
  <primitive: 'vcons push object'>
!
sorted
  ^ self asArray sorted asCons
!
OrderedCollection subclass: #List
instanceVariableNames: ''
classVariableNames: ''
maps: 'vlist'
!
List class
!
new
   <primitive: 'vlist .ctor'>
!
List
!
add: anObject
   <primitive: 'vlist add object'>
!
addList: aList
   aList do: [:x | self add: x]
!
asArray
   <primitive: 'vlist toarray'>
!
asCons
  ^ self asArray asCons
!
asList
   ^ self
!
at: anInteger
   <primitive: 'vlist get_item int'>
!
at: anInteger put: anObject
   <primitive: 'vlist set_item int object'>
!
current
  <primitive: 'vlist get_current'>
!
isList
   ^ true
!
move
  <primitive: 'vlist move'>
!
reset
  <primitive: 'vlist reset'>
!
reverse
   <primitive: 'vlist reverse'>
!
size
   <primitive: 'vlist get_count'>
!
sort
   <primitive: 'vlist sort'>
!
Object subclass: #Context
instanceVariableNames: ''
classVariableNames: ''
maps: 'vcontext'
!
Context subclass: #Block
instanceVariableNames: ''
classVariableNames: ''
maps: 'vblock'
!
Block
!
asBlock
   ^ self
!
homeContext
   <primitive: 'vblock homecontext'>
!
isBlock
   ^ true
!
nargs
   <primitive: 'vblock nargs'>
!
printString
   ^ 'a BlockContext'
!
reset
   <primitive: 'vblock  reset'>
!
run
  | process |
  process := Process fromBlock: self.
  Processor scheduleProcess: process
!
value
   <primitive: 'vblock value'>
!
value: arg1
   ^ self valueWithArguments: (Array with: arg1)
!
value: arg1 value: arg2
   ^ self valueWithArguments: (Array with: arg1 with: arg2)
!
value: arg1 value: arg2 value: arg3
   ^ self valueWithArguments: (Array with: arg1 with: arg2 with: arg3)
!
value: arg1 value: arg2 value: arg3 value: arg4
   ^ self valueWithArguments: (Array with: arg1 with: arg2 with: arg3 with: arg4)
!
valueWithArguments: anArray
   <primitive: 'vblock valuewitharguments object[]'>
!
Context subclass: #MethodContext
instanceVariableNames: ''
classVariableNames: ''
maps: 'vmethodcontext'
!
MethodContext class
!
template
   ^'selector
   "comments"

   | locals |
   statements'
!
MethodContext
!
homeContext
   ^ self
!
method
  <primitive: 'vmethodcontext get_method'>
!
receiver
   <primitive: 'vmethodContext receiver'>
!
Object subclass: #GraphicLibraries
instanceVariableNames: ''
classVariableNames: ''
!
GraphicLibraries subclass: #Wheel
instanceVariableNames: ''
classVariableNames: ''
!
Wheel class
!
createWheel: numberOfSpokes radius: aRadius center: aPoint
  | angle group rim wheel |
  angle := Math pi / numberOfSpokes.
  group := GeometryGroup new.
  rim := EllipseGeometry center: aPoint radius: aRadius.
  group add: rim.
  0 to: (numberOfSpokes - 1) do: [:i |
    group add: (self spoke: i * angle center: aPoint radius: aRadius)].
  wheel := Path new.
  wheel data: group; stroke: Brushes black.
  ^ wheel
!
spoke: anAngle center: aPoint radius: aRadius
  | xoffset yoffset |
  xoffset := aRadius * (Math sin: anAngle).
  yoffset := aRadius * (Math cos: anAngle).
  ^ LineGeometry start: aPoint + (Point x: xoffset y: yoffset)
                   end: aPoint+ (Point x: xoffset minus y: yoffset minus)
!
Object subclass: #InputOutput
instanceVariableNames: ''
classVariableNames: ''
!
InputOutput subclass: #File
instanceVariableNames: ''
classVariableNames: ''
maps: 'file'
!
File class
!
exists: aPath
  <primitive: 'file exists string'>
!
openText: aPath
  <primitive: 'file opentext string'>
!
readAllText: aPath
  <primitive: 'file readalltext string'>
!
writeAllText: aPath from: aString
  <primitive: 'file writealltext string string'>
!
InputOutput subclass: #MemoryStream
instanceVariableNames: ''
classVariableNames: ''
!
MemoryStream class
!
new: aByteArray
  <primitive: 'memorystream .ctor byte[]'>
!
InputOutput subclass: #SmalltalkReader
instanceVariableNames: ''
classVariableNames: ''
maps: 'vsmalltalkreader'
!
SmalltalkReader class
!
addMethod: aBehavior string: aString
  <primitive: 'vsmalltalkreader addmethod vbehavior string'>
!
addSubclass: aBehavior string: aString
  <primitive: 'vsmalltalkreader addsubclass vbehavior string'>
!
InputOutput subclass: #TextReader
instanceVariableNames: ''
classVariableNames: ''
maps: 'textreader'
!
TextReader subclass: #StreamReader
instanceVariableNames: ''
classVariableNames: ''
maps: 'streamreader'
!
TextReader subclass: #StringReader
instanceVariableNames: ''
classVariableNames: ''
maps: 'stringreader'
!
StringReader class
!
onString: aString
  <primitive: 'stringreader .ctor string'>
!
InputOutput subclass: #TextWriter
instanceVariableNames: ''
classVariableNames: ''
maps: 'textwriter'
!
TextWriter subclass: #StreamWriter
instanceVariableNames: ''
classVariableNames: ''
maps: 'streamwriter'
!
InputOutput subclass: #Transcript
instanceVariableNames: ''
classVariableNames: ''
!
Transcript class
!
cr
  <primitive: 'vm println'>
!
show: aString
  <primitive: 'vm print object'>
!
showCr: aString
  <primitive: 'vm println object'>
!
InputOutput subclass: #XamlReader
instanceVariableNames: ''
classVariableNames: ''
maps: 'xamlreader'
!
InputOutput subclass: #Xml
instanceVariableNames: ''
classVariableNames: ''
!
Xml subclass: #XmlDocument
instanceVariableNames: ''
classVariableNames: ''
maps: 'xmldocument'
!
XmlDocument class
!
new
  <primitive: 'xmldocument .ctor'>
!
XmlDocument
!
childNodes
  <primitive: 'xmldocument get_childnodes'>
!
load: anXmlReader
  <primitive: 'xmldocument load xmlreader'>
!
Xml subclass: #XmlNode
instanceVariableNames: ''
classVariableNames: ''
maps: 'xmlnode'
!
XmlNode
!
at: aString
  <primitive: 'xmlnode get_item string'>
!
childNodes
  <primitive: 'xmlnode get_childnodes'>
!
XmlNode subclass: #XmlLinkedNode
instanceVariableNames: ''
classVariableNames: ''
maps: 'xmllinkednode'
!
XmlLinkedNode subclass: #XmlDeclaration
instanceVariableNames: ''
classVariableNames: ''
maps: 'xmldeclaration'
!
XmlDeclaration
!
name
  <primitive: 'xmldeclaration get_name'>
!
XmlLinkedNode subclass: #XmlElement
instanceVariableNames: ''
classVariableNames: ''
maps: 'xmlelement'
!
XmlElement
!
innerText
  <primitive: 'xmlelement get_innertext'>
!
name
  <primitive: 'xmlelement get_name'>
!
Xml subclass: #XmlNodeList
instanceVariableNames: ''
classVariableNames: ''
maps: 'xmlnodelist'
!
XmlNodeList
!
count
  <primitive: 'xmlnodelist get_count'>
!
Xml subclass: #XmlNodeType
instanceVariableNames: ''
classVariableNames: ''
maps: 'xmlnodetype'
!
Xml subclass: #XmlTextReader
instanceVariableNames: ''
classVariableNames: ''
maps: 'xmltextreader'
!
XmlTextReader class
!
fromTextReader: aTextReader
  <primitive: 'xmltextreader .ctor textreader'>
!
fromUrl: aUrl
  <primitive: 'xmltextreader .ctor string'>
!
Object subclass: #Internet
instanceVariableNames: ''
classVariableNames: ''
!
Internet class
!
readTextFromUrl: aUrl callback: aBlock
  | php |
  php := PhpConnect new.
  php url: aUrl.
  php callback: aBlock.
  php queryServer: ''
!
Internet subclass: #GmailConnect
instanceVariableNames: ''
classVariableNames: ''
maps: 'gmailconnect'
!
GmailConnect class
!
send: fromString to: toString cc: ccString bcc: bccString subject: subjectString body: bodyString
  <primitive: 'gmailconnect sendmail string string string string string string'>
!
send: fromString to: toString subject: subjectString body: bodyString
  self send: fromString to: toString cc: '' bcc: '' subject: subjectString body: bodyString
!
Internet subclass: #HttpUtility
instanceVariableNames: ''
classVariableNames: ''
maps: 'httputility'
!
HttpUtility class
!
urlDecode: aString
  <primitive: 'httputility urldecode string'>
!
urlEncode: aString
  <primitive: 'httputility urlencode string'>
!
Internet subclass: #JsonConnect
instanceVariableNames: ''
classVariableNames: ''
maps: 'jsonconnect'
!
JsonConnect class
!
new
  <primitive: 'jsonconnect .ctor'>
!
JsonConnect
!
callback
  <primitive: 'jsonconnect get_callback'>
!
callback: aBlock
  <primitive: 'jsonconnect set_callback object'>
!
queryServer: aQueryString
  <primitive: 'jsonconnect queryserverasync string'>
!
rawResponse
  <primitive: 'jsonconnect get_rawresponse'>
!
rawResponse: aBoolean
  <primitive: 'jsonconnect set_rawresponse bool'>
!
sendData: anObject
  <primitive: 'jsonconnect senddata object'>
!
url
  <primitive: 'jsonconnect get_url'>
!
url: aString
  <primitive: 'jsonconnect set_url string'>
!
Internet subclass: #Loader
instanceVariableNames: 'reference'
classVariableNames: ''
!
Loader class
!
loadSite: aFile
  self new loadSite: aFile
!
loadWiki: wikiReference
  self new loadWiki: wikiReference
!
Loader
!
loadSite: aFile
  reference := aFile.
  Transcript showCr: 'loading ' + reference + '...'.
  self readSite: reference
!
loadWiki: wikiReference
  reference := 'libraries:smalltalk:loader:' + wikiReference.
  Transcript showCr: 'loading ' + reference + '...'.
  self readWiki: reference
!
onReadResponse: aString
  | success |
  success :=  Vm fileInFromString: aString.
  success ifFalse: [Transcript showCr: 'Failed: ' + reference]
!
Internet subclass: #MessagingBase
instanceVariableNames: ''
classVariableNames: ''
maps: 'messagingbase'
!
MessagingBase
!
callback
  <primitive: 'messagingbase get_callback'>
!
callback: aBlock
  <primitive: 'messagingbase set_callback object'>
!
channel
  <primitive: 'messagingbase get_channel'>
!
channel: aString
  <primitive: 'messagingbase set_channel string'>
!
contact
  <primitive: 'messagingbase get_contact'>
!
contact: aString
  <primitive: 'messagingbase set_contact string'>
!
MessagingBase subclass: #JabberConnect
instanceVariableNames: ''
classVariableNames: ''
maps: 'jabberconnect'
!
JabberConnect class
!
new: aBoolean
  <primitive: 'jabberconnect .ctor bool'>
!
JabberConnect
!
close
  <primitive: 'jabberconnect close'>
!
connect
  <primitive: 'jabberconnect connect'>
!
passwd: aString
  <primitive: 'jabberconnect set_passwd string'>
!
send: anObject
  self send: self contact object: anObject
!
send: aName object: anObject
  <primitive: 'jabberconnect sendto string object'>
!
user: aString
  <primitive: 'jabberconnect set_user string'>
!
MessagingBase subclass: #SocketClient
instanceVariableNames: ''
classVariableNames: ''
maps: 'socketclient'
!
SocketClient class
!
on: aString port: anInteger
  <primitive: 'socketclient .ctor string int'>
!
SocketClient
!
close
  <primitive: 'socketclient close'>
!
isConnected
  <primitive: 'socketclient get_isconnected'>
!
send: aString
  <primitive: 'socketclient send string'>
!
MessagingBase subclass: #SocketServer
instanceVariableNames: ''
classVariableNames: ''
maps: 'socketserver'
!
SocketServer class
!
on: aString port: anInteger
  <primitive: 'socketserver .ctor string int'>
!
SocketServer
!
isConnected
  <primitive: 'socketserver get_isconnected'>
!
start
  <primitive: 'socketserver start'>
!
stop
  <primitive: 'socketserver stop'>
!
MessagingBase subclass: #TmsConnect
instanceVariableNames: ''
classVariableNames: ''
maps: 'tmsconnect'
!
TmsConnect class
!
channel: aChannel name: aName
  | tms |
  tms := self new.
  tms url: 'http://vistascript.net/vistascript/webserv/tms.php'.
  tms channel: aChannel.
  tms name: aName.
  tms clear.
  ^ tms
!
channel: aChannel name: aName callback: aBlock
  | tms |
  tms := self channel: aChannel name: aName.
  tms callback: aBlock.
  ^ tms
!
new
  <primitive: 'tmsconnect .ctor'>
!
TmsConnect
!
clear
  <primitive: 'tmsconnect clear'>
!
listen
  <primitive: 'tmsconnect listen'>
!
name
  <primitive: 'tmsconnect get_name'>
!
name: aBlock
  <primitive: 'tmsconnect set_name string'>
!
send: anObject
  <primitive: 'tmsconnect send object'>
!
send64: anObject
  self send: anObject asString encodeBase64
!
startPolling: anInteger
  <primitive: 'tmsconnect startpolling int'>
!
stopPolling
  <primitive: 'tmsconnect stoppolling'>
!
url
  <primitive: 'tmsconnect get_url'>
!
url: aString
  <primitive: 'tmsconnect set_url string'>
!
Internet subclass: #PhpConnect
instanceVariableNames: ''
classVariableNames: ''
maps: 'phpconnect'
!
PhpConnect class
!
new
  <primitive: 'phpconnect .ctor'>
!
PhpConnect
!
callback
  <primitive: 'phpconnect get_callback'>
!
callback: aBlock
  <primitive: 'phpconnect set_callback object'>
!
queryServer: aQueryString
  <primitive: 'phpconnect queryserverasync string'>
!
serialized
  <primitive: 'phpconnect get_serialized'>
!
serialized: aBlock
  <primitive: 'phpconnect set_serialized bool'>
!
url
  <primitive: 'phpconnect get_url'>
!
url: aString
  <primitive: 'phpconnect set_url string'>
!
Object subclass: #Kernel
instanceVariableNames: ''
classVariableNames: ''
!
Kernel subclass: #CompiledMethod
instanceVariableNames: ''
classVariableNames: ''
maps: 'vcompiledmethod'
!
CompiledMethod
!
text
  <primitive: 'vcompiledmethod text'>
!
Kernel subclass: #Compiler
instanceVariableNames: ''
classVariableNames: ''
maps: 'vcompiler'
!
Compiler class
!
compileMethod: aString
  <primitive: 'vcompiler compilemethod string'>
!
compileSnippet: aString
  <primitive: 'vcompiler compilesnippet string'>
!
Kernel subclass: #EventArgs
instanceVariableNames: ''
classVariableNames: ''
!
EventArgs subclass: #ElementMovedArgs
instanceVariableNames: ''
classVariableNames: ''
maps: 'elementmovedargs'
!
ElementMovedArgs
!
name
  <primitive: 'elementmovedargs get_name'>
!
x
  <primitive: 'elementmovedargs get_x'>
!
y
  <primitive: 'elementmovedargs get_y'>
!
Kernel subclass: #Handler
instanceVariableNames: ''
classVariableNames: ''
maps: 'vhandler'
!
Handler class
!
on: anObject event: aString block: aBlock
  <primitive: 'vhandler addhandler object string vblock'>
!
Kernel subclass: #Lisp
instanceVariableNames: ''
classVariableNames: ''
maps: 'lispvm'
!
Lisp class
!
eval: anObject
  ^ self evalPrim: anObject asConsOrAtom
!
evalPrim: aConsOrAtom
  <primitive: 'lispvm eval object'>
!
evalStr: aString
  <primitive: 'lispvm evalstr string'>
!
evalStr: aString block: aBlock
  ^ self evalStr: aString block: aBlock sender: nil
!
evalStr: aString block: aBlock sender: anObject
  <primitive: 'lispvm evalstr string vblock object'>
!
Kernel subclass: #LispFunction
instanceVariableNames: ''
classVariableNames: ''
!
LispFunction subclass: #CompiledFunction
instanceVariableNames: ''
classVariableNames: ''
!
CompiledFunction subclass: #BuiltinFunction
instanceVariableNames: ''
classVariableNames: ''
!
CompiledFunction subclass: #Closure
instanceVariableNames: ''
classVariableNames: ''
!
LispFunction subclass: #Macro
instanceVariableNames: ''
classVariableNames: ''
!
LispFunction subclass: #SpecialOperator
instanceVariableNames: ''
classVariableNames: ''
!
Kernel subclass: #Message
instanceVariableNames: ''
classVariableNames: ''
maps: 'vmessage'
!
Message class
!
receiver: aReceiver selector: aSelector argumemts: anArray
  <primitive: 'vmessage .ctor voop voop voop[]'>
!
Message
!
arguments
  <primitive: 'vmessage get_arguments'>
!
receiver
  <primitive: 'vmessage get_receiver'>
!
selector
  <primitive: 'vmessage get_selector'>
!
Kernel subclass: #Process
instanceVariableNames: ''
classVariableNames: ''
maps: 'vprocess'
!
Process class
!
fromBlock: aBlock
  <primitive: 'vprocess fromblock vblock'>
!
fromMethod: aCompiledMethod
  <primitive: 'vprocess frommethod vcompiledmethod'>
!
Process
!
callback
  <primitive: 'vprocess get_callback'>
!
callback: aBlock
  <primitive: 'vprocess set_callback vblock'>
!
callstack
  <primitive: 'vprocess getcallstack'>
!
errorblock
  <primitive: 'vprocess get_errorblock'>
!
errorblock: aBlock
  <primitive: 'vprocess set_errorblock vblock'>
!
halt
  <primitive: 'vprocess halt'>
!
sleep: milliseconds
  <primitive: 'vprocess sleep int'>
!
yield
  <primitive: 'vprocess yield'>
!
Kernel subclass: #Processor
instanceVariableNames: ''
classVariableNames: ''
maps: 'vprocessor'
!
Processor class
!
activeProcessCount
  <primitive: 'vprocessor get_activeprocesscount'>
!
activeProcesses
  <primitive: 'vprocessor get_activeprocesses'>
!
currentProcess
  <primitive: 'vprocessor get_currentprocess'>
!
scheduleProcess: aProcess
  <primitive: 'vprocessor scheduleprocess vprocess'>
!
Kernel subclass: #RuleEngine
instanceVariableNames: ''
classVariableNames: ''
!
Kernel subclass: #Vm
instanceVariableNames: ''
classVariableNames: ''
!
Vm class
!
errorLog
  <primitive: 'vm geterrorlog'>
!
eval: aString
  <primitive: 'vm eval string'>
!
evalInline: aString
  <primitive: 'vm evalinline string'>
!
fileInFromString: aString
  <primitive: 'vm fileinfromstring string'>
!
fileOutAll
  <primitive: 'vm fileoutall'>
!
findEnum: clsname for: valuename
  <primitive: 'vm findenum string string'>
!
gateway
  <primitive: 'vm gateway'>
!
implementorsOf: aSymbol
  <primitive: 'vm implementorsof vsymbol'>
!
lastQuery
  <primitive: 'vm lastquery'>
!
rootClass
  <primitive: 'vm rootclass'>
!
sendersOf: aSymbol
  <primitive: 'vm sendersof vsymbol'>
!
start
  <primitive: 'vm start'>
!
typeList
  <primitive: 'vm get_typelist'>
!
virtualDesktop
  <primitive: 'vm get_virtualdesktop'>
!
Object subclass: #Magnitude
instanceVariableNames: ''
classVariableNames: ''
!
Magnitude subclass: #KeyedVariable
instanceVariableNames: ''
classVariableNames: ''
!
Magnitude subclass: #KeyValuePair
instanceVariableNames: ''
classVariableNames: ''
!
KeyValuePair
!
key
  <primitive: 'vkeyvaluepair get_key'>
!
value
  <primitive: 'vkeyvaluepair get_value'>
!
Magnitude subclass: #Number
instanceVariableNames: ''
classVariableNames: ''
!
Number
!
abs
  self < 0 ifTrue: [^ -1 * self].
  ^ self
!
asFloat
  ^ Convert toSingle: self
!
asInteger
   ^ self // 1
!
even
  ^ self \\ 2 == 0
!
isNumber
   ^ true
!
minus
  ^ 0 - self
!
odd
  ^ self even not
!
Number subclass: #Double
instanceVariableNames: ''
classVariableNames: ''
!
Double class
!
nan
  <primitive: 'vdouble get_nan'>
!
Double
!
isDouble
   ^ true
!
Number subclass: #Float
instanceVariableNames: ''
classVariableNames: ''
!
Float
!
isFloat
   ^ true
!
Number subclass: #Integer
instanceVariableNames: ''
classVariableNames: ''
!
Integer
!
isInteger
   ^ true
!
timesRepeat: aBlock
  1 to: self do:[:i | aBlock value]
!
Number subclass: #Long
instanceVariableNames: ''
classVariableNames: ''
!
Magnitude subclass: #Symbol
instanceVariableNames: ''
classVariableNames: ''
maps: 'vsymbol'
!
Symbol class
!
intern: aString
  <primitive: 'vsymbol intern string'>
!
Symbol
!
asSymbol
  ^ self
!
printString
  ^ '#' + super printString
!
Object subclass: #MethodsBackup
instanceVariableNames: ''
classVariableNames: ''
!
MethodsBackup class
!
copyright
   "   ~  written by: Gal Zsolt & Cathlyn Cosca ( CalmoSoft ) ~ 2006-2007 ~ calmosoft@gmail.com ~   "
!
Object subclass: #Models
instanceVariableNames: ''
classVariableNames: ''
!
Object subclass: #Tools
instanceVariableNames: ''
classVariableNames: ''
!
Tools class
!
open
  | w |
  w := super new.
  w open.
  ^ w
!
Tools
!
open
  ^ nil
!
Tools subclass: #ClassBrowser
instanceVariableNames: 'classesTv classDict classLb instDict instLb selectedClass tabctrl texteditor root window'
classVariableNames: ''
!
ClassBrowser
!
classMethodSelection
  | selector method |
  classLb selectedItem notNil ifTrue: [
    selector := classLb selectedItem content.
    method := selectedClass class lookupSelector: selector.
    self showMethodText: method]
!
classSelectionChanged
  | cls |
  classesTv selectedItem isNil ifTrue:[^nil].
  cls := classesTv selectedItem tag.
  selectedClass := cls.
  self refreshMethodsLists.
  self showClassText
!
implementorsClassMethod
  | selector |
  selector := classLb selectedItem content.
  (Vm implementorsOf: selector) inspect
!
implementorsInstMethod
   | selector |
   selector := instLb selectedItem content.
  (Vm implementorsOf: selector) inspect
!
instMethodSelection
  | selector method |
  instLb selectedItem notNil ifTrue: [
    selector := instLb selectedItem content.
    method := selectedClass lookupSelector: selector.
    self showMethodText: method]
!
open
  "   ClassBrowser open   " 
  | tab |
  window := ThreePaneTreeTabEditor new.
  window color: Colors darkCyan.
  window title: 'Class Browser'.
  classesTv := window treeview.
  classesTv background: (SolidColorBrush new: Colors darkSlateGray).
  tabctrl := window tabcontrol.
  texteditor := window textbox.
  texteditor foreground: Brushes navy.
  texteditor background: Brushes ivory.
  texteditor showLines: true.
  instLb := ListBox new.
  instLb background: (SolidColorBrush new: Colors darkSlateGray).
  instLb borderbrush: (SolidColorBrush new: Color customDarkGray).
  instLb foreground: (SolidColorBrush new: Colors gold).
  classLb := ListBox new.
  classLb background: (SolidColorBrush new: Colors darkSlateGray).
  classLb borderbrush: (SolidColorBrush new: Color customDarkGray).
  classLb foreground: (SolidColorBrush new: Colors gold).
  tab := TabItem new.
  tab header: 'Inst'.
  tab content: instLb.
  window tabcontrol tabStripPlacement: Dock bottom.
  window tabcontrol items add: tab.
  tab := TabItem new.
  tab header: 'Class'.
  tab content: classLb.
  window tabcontrol items add: tab.
  classesTv addEvent: 'SelectedItemChanged' action: [self classSelectionChanged].
  instLb addEvent: 'SelectionChanged' action: [self instMethodSelection].
  classLb addEvent: 'SelectionChanged' action: [self classMethodSelection].
  self setInstLbContextMenu; setClassLbContextMenu; setTextBoxContextMenu.
  self setFontSize.
  window open.
  self refreshClassTree
!
refreshClassTree
  | rootClass rootNode |
  rootClass := Vm rootClass.
  classesTv items clear.
  rootNode := TreeViewItem new.
  rootNode foreground: (SolidColorBrush new: Colors gold).
  rootNode header: rootClass name.
  rootNode tag: rootClass.
  classesTv items add: rootNode.
  self refreshClassTree: rootClass node: rootNode
!
refreshClassTree: aClass node: aNode
  | childNode |
  aClass subclasses do:[:cls |
    childNode := TreeViewItem new.
    childNode foreground: (SolidColorBrush new: Colors gold).
    childNode header: cls name.
    childNode tag: cls.
    aNode items add: childNode.
    self refreshClassTree: cls node: childNode]
!
refreshMethodsLists
  | li |
  instDict := selectedClass methodDictionary.
  classDict := selectedClass class methodDictionary.
  instLb items clear.
  classLb items clear.
  texteditor text: ''.
  instDict keysDo: [:k |
    li := ListBoxItem new.
    li content: k.
    instLb items add: li].
  classDict keysDo: [:k |
    li := ListBoxItem new.
    li content: k.
    classLb items add: li]
!
removeClassMethod
  | selector |
  selector := classLb selectedItem content.
  selectedClass class removeMethod: selector.
  self refreshMethodsLists
!
removeInstMethod
  | selector |
  selector := instLb selectedItem content.
  selectedClass removeMethod: selector.
  self refreshMethodsLists
!
selectedClass
  | index |
  index := tabctrl selectedIndex.
  index == 0
    ifTrue: [^ selectedClass]
    ifFalse: [^ selectedClass class]
!
sendersClassMethod
  | selector |
  selector := classLb selectedItem content.
  (Vm sendersOf: selector) inspect
!
sendersInstMethod
   | selector |
   selector := instLb selectedItem content.
  (Vm sendersOf: selector) inspect
!
setClassLbContextMenu
  | menu |
  menu := ContextMenu new.
  menu add: (MenuItem name: 'Implementors' action: [self implementorsClassMethod]).
  menu add: (MenuItem name: 'Senders' action: [self sendersClassMethod]).
  menu add: (MenuItem name: 'Remove' action: [self removeClassMethod]).
  classLb contextMenu: menu.
!
setFontSize
  | fntsize |
  fntsize := 12.
  classesTv fontsize: fntsize.
  classLb fontsize: fntsize.
  instLb fontsize: fntsize.
!
setInstLbContextMenu
  | menu |
  menu := ContextMenu new.
  menu add: (MenuItem name: 'Implementors' action: [self implementorsInstMethod]).
  menu add: (MenuItem name: 'Senders' action: [self sendersInstMethod]).
  menu add: (MenuItem name: 'Remove' action: [self removeInstMethod]).
  instLb contextMenu: menu.
!
setTextBoxContextMenu
  | menu |
  menu := ContextMenu new.
  menu add: (MenuItem name: 'Save' action: [self textSave]).
  menu add: Separator new.
  menu add: (MenuItem name: 'Breakpoints' action: [self toggleBreakpoints]).
  menu add: (MenuItem name: 'Linenumbers' action: [self toggleLines]).
  texteditor contextMenu: menu.
!
showClassText
  texteditor clearBreakpoints.
  texteditor text: selectedClass storeString
!
showMethodText: aMethod
  texteditor setMethod: aMethod.
  texteditor text: aMethod text
!
textSave
  | txt |
  txt := texteditor text trim.
  txt length == 0 ifTrue: [^nil].
  ((txt at: 0) isUpper and: (txt indexOf: ' subclass:') > 0)
  ifTrue: [
    SmalltalkReader addSubclass: self selectedClass string: txt.
    self refreshClassTree]
  ifFalse: [
    SmalltalkReader addMethod: self selectedClass string: txt.
    self refreshMethodsLists]
!
toggleBreakpoints
  texteditor showBreakpoints: texteditor showBreakpoints not
!
toggleLines
  texteditor showLines: texteditor showLines not
!
Tools subclass: #Debugger
instanceVariableNames: 'process sourceTb stackLb'
classVariableNames: ''
!
Debugger class
!
openOn: aProcess
  | w |
  w := super new.
  w openOn: aProcess.
  ^ w
!
openOnCurrentProcess
  | process |
  process := Processor currentProcess.
  [self openOn: process] run.
  process halt
!
Debugger
!
buildBottomPanel
  | buttonpanel dockpanel listpanel |
  buttonpanel := self buildButtonPanel.
  listpanel := self buildListPanel.
  sourceTb := TextEditor new.
  dockpanel := DockPanel new.
  dockpanel add: buttonpanel.
  DockPanel setDock: buttonpanel to: Dock top.
  dockpanel add: (Grid vsplit: 0.65
               child1: sourceTb 
               child2: listpanel).
  ^ dockpanel
!
buildButton: aName
  | btn |
  btn := Button new.
  btn content: aName.
  ^ btn
!
buildButtonPanel
  | border stackpanel |
  border := Border new.
  border background: Brushes lightGray.
  border borderBrush: Brushes black.
  border borderThickness: (Thickness left: 0 top: 0 right: 0 bottom: 1).
  stackpanel := StackPanel new.
  stackpanel orientation: Orientation horizontal.
  stackpanel
    add: (self buildButton: 'Proceed');
    add: (self buildButton: 'Restart');
    add: (self buildButton: 'Into');
    add: (self buildButton: 'Over');
    add: (self buildButton: 'Through').
  border child: stackpanel.
  ^ border
!
buildListPanel
  | brush list1 list2 list3 list4 |
  brush := SolidColorBrush new: Color customGreen.
  list1 := ListBox new.
  list1 background: brush.
  list2 := ListBox new.
  list2 background: brush.
  list3 := ListBox new.
  list3 background: brush.
  list4 := ListBox new.
  list4 background: brush.
  ^ Grid hsplit: Brushes gray child1: list1 child2: list2 child3: list3 child4: list4
!
buildTopPanel
  stackLb := ListBox new.
  stackLb background: (SolidColorBrush new: Color customGreen).
  stackLb addEvent: 'SelectionChanged' action: [self stackSelection].
  ^ stackLb
!
open
  | w |
  w := self topWindowClass new.
  w title: 'Debugger'.
  w add: (Grid vsplit: 0.25
               child1: self buildTopPanel
               child2: self buildBottomPanel).
  w width: 500; height: 450; open
!
openOn: aProcess
  | w |
  process := aProcess.
  w := self topWindowClass new.
  w title: 'Debugger'.
  w add: (Grid vsplit: 0.25
               child1: self buildTopPanel
               child2: self buildBottomPanel).
  w open.
  self showStack
!
showStack
  | li stack |
  stackLb clear.
  stack := process callstack.
  stack do:[:context |
    li := ListBoxItem new.
    li content: context.
    li tag: context.
    stackLb items add: li]
!
stackSelection
  | item |
  item := stackLb selectedItem.
  item isNil ifTrue: [^nil].
  sourceTb text: item tag method text
!
Tools subclass: #Inspectors
instanceVariableNames: 'view'
classVariableNames: ''
!
Inspectors class
!
openOn: anObject
  | w |
  w := self new.
  w openOn: anObject.
  ^ w
!
Inspectors
!
view
  ^ view
!
Inspectors subclass: #ArrayInspector
instanceVariableNames: 'array'
classVariableNames: ''
!
ArrayInspector
!
currentValue
  | index |
  index := view listbox selectedIndex + 1.
  ^ array at: index
!
inspectValue
  self currentValue inspect
!
openOn: anOrderedCollection
  | menu menuitem |
  array := anOrderedCollection asArray.
  view := TwoPaneListText new.
  view title: 'ArrayInspector on ' + anOrderedCollection class printString.
  view listbox addEvent: 'SelectionChanged' action: [self showValue].
  menu := ContextMenu new.
  menuitem := MenuItem new.
  menuitem header: 'Inspect'.
  menuitem addEvent: 'Click' action: [self inspectValue].
  menu items add: menuitem.
  view listbox contextMenu: menu.
  view open.
  self showIndices
!
showIndices
  | li n |
  n := array size.
  1 to: n do:[:i |
    li := ListBoxItem new.
    li content: i.
    view listbox items add: li]
!
showValue
  view textbox text: self currentValue printString
!
Inspectors subclass: #DefaultInspector
instanceVariableNames: ''
classVariableNames: ''
!
DefaultInspector
!
openOn: anObject
  view := OnePaneText new.
  view title: 'DefaultInspector on ' + anObject class printString.
  view text: anObject printString.
  view open
!
Inspectors subclass: #DictionaryInspector
instanceVariableNames: 'dictionary'
classVariableNames: ''
!
DictionaryInspector
!
currentValue
  | key |
  key := view listbox selectedItem content.
  ^ dictionary at: key
!
inspectValue
  self currentValue inspect
!
openOn: aDictionary
  | menu menuitem |
  dictionary := aDictionary.
  view := TwoPaneListText new.
  view title: 'DictionaryInspector on ' + aDictionary class printString.
  view listbox addEvent: 'SelectionChanged' action: [self showValue].
  menu := ContextMenu new.
  menuitem := MenuItem new.
  menuitem header: 'Inspect'.
  menuitem addEvent: 'Click' action: [self inspectValue].
  menu items add: menuitem.
  view listbox contextMenu: menu.
  view open.
  self showKeys
!
showKeys
  | li |
  dictionary keysDo:[:k |
    li := ListBoxItem new.
    li content: k.
    view listbox items add: li]
!
showValue
  view textbox text: self currentValue asString
!
Tools subclass: #Launcher
instanceVariableNames: ''
classVariableNames: ''
!
Launcher
!
open
  "   Launcher open   "
  | panel w |
  panel := StackPanel new.
  panel add: (Button content: 'PowerBrowser' callback: [PowerBrowser new open]).
  panel add: (Button content: 'PowerLauncher' callback: [PowerLauncher new open]).
  panel add: (Button content: 'Demos' callback: [DemoLauncher open]).
  panel add: (Button content: 'Games' callback: [GamesLauncher open]).
  panel add: (Button content: 'Graphics' callback: [GraphicsLauncher open]).
  panel add: (Button content: 'Remote' callback: [RemoteLauncher open]).
  panel add: (Button content: 'Xaml' callback: [XamlLauncher open]).
  panel add: (Button content: 'Designer' callback: [OnePaneDesigner open]).
  w := self topWindowClass new.
  w width: 150; height: 213; title: 'Main Launcher'; add: panel; open
!
Tools subclass: #Workspace
instanceVariableNames: 'texteditor window'
classVariableNames: ''
!
Workspace class
!
open
  ^ self openSmalltalk
!
openLisp
  ^ self openLisp: ''
!
openLisp: aString
  ^ super new openLisp: aString
!
openSmalltalk
  ^ self openSmalltalk: ''
!
openSmalltalk: aString
  ^ super new openSmalltalk: aString
!
Workspace
!
addCommonMenu: aMenu
  aMenu add: Separator new.
  aMenu items add: (MenuItem name: 'Clear' action: [texteditor text: '']).
  aMenu items add: (MenuItem name: 'Breakpoints' action: [self toggleBreakpoints]).
  aMenu items add: (MenuItem name: 'Linenumbers' action: [self toggleLines]).
  texteditor contextMenu: aMenu
!
addLispMenu
  | menu |
  menu := ContextMenu new.
  menu items add: (MenuItem name: 'Do It' action: [self lispDoIt]).
  menu items add: (MenuItem name: 'Show It' action: [self lispShowIt]).
  menu items add: (MenuItem name: 'Inspect It' action: [self lispInspectIt]).
  self addCommonMenu: menu
!
addSmalltalkMenu
  | menu |
  menu := ContextMenu new.
  menu items add: (MenuItem name: 'Do It' action: [self smalltalkDoIt]).
  menu items add: (MenuItem name: 'Show It' action: [self smalltalkShowIt]).
  menu items add: (MenuItem name: 'Inspect It' action: [self smalltalkInspectIt]).
  self addCommonMenu: menu
!
inspectResult: anObject
  anObject inspect
!
lispDoIt
  | str |
  str := texteditor selectedText trim.
  str length == 0 ifTrue: [^nil].
  Lisp evalStr: str
!
lispInspectIt
  | str |
  str := texteditor selectedText trim.
  str length == 0 ifTrue: [^nil].
  Lisp evalStr: str block: [:val | self inspectResult: val]
!
lispShowIt
  | str |
  str := texteditor selectedText trim.
  str length == 0 ifTrue: [^nil].
  Lisp evalStr: str block: [:val | self showResult: val]
!
makeWindow: aString
  window := OnePaneTextEditor new.
  window color: Colors darkGoldenrod.
  texteditor := window pane.
  texteditor text: aString + Environment newline + 'PowerBrowser new open'.
  texteditor foreground: Brushes navy.
!
openLisp: aString
  self makeWindow: aString.
  window title: 'Workspace(Lisp)'.
  self addLispMenu.
  window open
!
openSmalltalk: aString
  self makeWindow: aString.
  window title: 'Workspace(Smalltalk)'.
  self addSmalltalkMenu.
  window open
!
showResult: anObject
  texteditor insertAtEndOfSelection: anObject printString
!
smalltalkDoIt
  | method str |
  str := texteditor selectedText trim.
  str length == 0 ifTrue: [^nil].
  method := Compiler compileSnippet: str.
  method isNil ifTrue:[^nil].
  Processor scheduleProcess: (Process fromMethod: method)
!
smalltalkInspectIt
  | method process str |
  str := texteditor selectedText trim.
  str length == 0 ifTrue: [^nil].
  method := Compiler compileSnippet: str.
  method isNil ifTrue:[^nil].
  process := Process fromMethod: method.
  process callback: [:val | self inspectResult: val].
  Processor scheduleProcess: process
!
smalltalkShowIt
  | method process str |
  str := texteditor selectedText trim.
  str length == 0 ifTrue: [^nil].
  method := Compiler compileSnippet: str.
  method isNil ifTrue:[^nil].
  process := Process fromMethod: method.
  process callback: [:val | self showResult: val].
  Processor scheduleProcess: process
!
toggleBreakpoints
  texteditor showBreakpoints: texteditor showBreakpoints not
!
toggleLines
  texteditor showLines: texteditor showLines not
!
Object subclass: #Tutorial
instanceVariableNames: ''
classVariableNames: ''
!
Tutorial class
!
copyright
   "   ~  written by: Gal Zsolt & Cathlyn Cosca ( CalmoSoft ) ~ 2006-2007 ~ calmosoft@gmail.com ~   "
!
Tutorial subclass: #Classes
instanceVariableNames: ''
classVariableNames: ''
!
Classes class
!
copyright
   "   ~  written by: Gal Zsolt & Cathlyn Cosca ( CalmoSoft ) ~ 2006-2007 ~ calmosoft@gmail.com ~   "
!
readme
"   See this link :   "
"   http://vistascript.net/vistascript/docuwiki/doku.php?id=tutorial   "
!
Classes
!
array01
  "   Classes new array01   "
  "   This code create an array, add three items and write reversed items to Transcript   "
  | myArray nr |
  myArray := Array new: 3.
  myArray at: 1 put: 'Vista'.
  myArray at: 2 put: 'Smalltalk'.
  myArray at: 3 put: 'Forever'.
  1 to: 3 do: [:nr |
    Transcript showCr: (myArray at: 4-nr)]
!
array02
  "   Classes new array02   "
  "   Size of array   "
  | myArray nr |
  myArray := Array new: 3.
  myArray at: 1 put: 'Vista'.
  myArray at: 2 put: 'Smalltalk'.
  myArray at: 3 put: 'Forever'.
  1 to: myArray size do: [:nr |
    Transcript showCr: (myArray at: 4-nr)]
!
behavior01
  "   Classes new behavior01   "
  "   Shows the superclass of a class   "
  Transcript showCr: Button superclass
!
behavior02
  "   Classes new behavior02   "
  "   Shows the instancevariables of a class   "
  ClassBrowserPlus instanceVariables inspect
!
boolean01
  "   Classes new boolean01   "
  Transcript showCr: ((1<2) and: (4<3))
!
boolean02
  "   Classes new boolean02   "
  Transcript showCr: ((1<2) or: (4<3))
!
char01
  "   Classes new char01   "
  "   Check is a character upper   "
  | myChar |
  myChar := $a.
  Transcript showCr: myChar isUpper
!
char02
  "   Classes new char02   "
  "   Check is a character upper   "
  | myChar |
  myChar := $B.
  Transcript showCr: myChar isUpper
!
char03
  "   Classes new char03   "
  "   Check is a character upper   "
  Transcript showCr: $a isUpper
!
char04
  "   Classes new char04   "
  "   Check is a character upper   "
  Transcript showCr: $B isUpper
!
class01
  "   Classes new class01   "
  "   Print a class definition   "
  Transcript showCr: (CalmoSoft storeString)
!
class02
  "   Classes new class02   "
  "   Print the maptype of a class  "
  Transcript showCr: (Color mapType)
!
class03
  "   Classes new class03   "
  "   Print the subclasses of a class   " 
  CalmoSoft subclasses inspect
!
clipboard01
  "   Classes new clipboard01   "
  "   This code copy a text to the Clipboard and write to Transcript too   "
  | myText |
  myText := 'Vista Smalltalk Forever!'.
  Clipboard clear.
  Clipboard setText: myText.
  Transcript showCr: Clipboard getText
!
clipboard02
  "   Classes new clipboard02  "
  "   This code copy concatenation of two text to the Clipboard and write to Transcript too   "
  | myText1 myText2 |
  myText1 := 'Vista Smalltalk Forever!'.
  myText2 := 'Vista Smalltalk this Friday will win the IBM Vista Code Competition!'.
  Clipboard clear.
  Clipboard setText: myText1 + Environment newline + myText2.
  Transcript showCr: Clipboard getText
!
datetime01
  "   Classes new datetime01   "
  "   Usage of DateTime   "
  | time1 time2 |
  time1 := DateTime now.
  1 to: 100 do: [:nr |
    Transcript showCr: nr asString].
  time2 := DateTime now.
  Transcript showCr: time1.
  Transcript showCr: time2
!
dictionary01
  "    Classes new dictionary01   "
  "    Set dictionary elements at index   "
  | myDictionary |
  myDictionary := Dictionary new.
  myDictionary at: #a put: 'Vista'.
  myDictionary at: #b put: 'Smalltalk'.
  myDictionary at: #c put: 'Forever'.
  myDictionary inspect
!
dictionary02
  "   Classes new dictionary02   "
  "   Number of elements   "
  | myDictionary |
  myDictionary := Dictionary new.
  myDictionary at: #a put: 'Vista'.
  myDictionary at: #b put: 'Smalltalk'.
  myDictionary at: #c put: 'Forever'.
  Transcript showCr: myDictionary size
!
dictionary03
  "   Classes new dictionary03   "
  "   Retrieve element at index   "
  | myDictionary |
  myDictionary := Dictionary new.
  myDictionary at: #a put: 'Vista'.
  myDictionary at: #b put: 'Smalltalk'.
  myDictionary at: #c put: 'Forever'.
  Transcript showCr: (myDictionary at: #b)
!
file01
  "   Classes new file01   "
  "   This code shows the configuration file (config.vs) in Transcript   "
  Transcript show: (File readAllText: 'config.vs')
!
file02
  "   Classes new file02   "
  "   Verify if file exists   "
  Transcript show: (File exists: 'config.vs')
!
file03
  "   Classes new file03   "
  "   Copy config.vs to config2.vs   "
  | text |
  text := (File readAllText: 'config.vs').
  File writeAllText: 'config2.vs' from: text
!
file04
  "   Classes new file04   "
  "   Copy config.vs to config2.vs   "
  File writeAllText: 'config2.vs' from: (File readAllText: 'config.vs').
!
file05
  "   Classes new file05   "   
  "   This code write all classes name to a file.   "  
  | classesString |
  classesString := ''.
  Object withAllSubclasses do:  [ : cls | classesString := (classesString + cls name + Environment newline ) asString].
  File writeAllText: 'vst_classes.txt' from: classesString
!
file06
  "   Classes new file06   "   
  "   This code write all classes name to the DesktopTranscript.   "  
  | classesString |
  classesString := ''.
  Object withAllSubclasses do:  [ : cls | classesString := (classesString + cls name + 
    Environment newline ) asString].
  Transcript showCr: classesString
!
file07
  "   Classes new file07   "   
| myInputFile myList myArray myString index |
  myList := List new.
  (File exists: 'calmosoft/myInputFile.txt') ifTrue: [myString := (File readAllText: 'calmosoft/myInputFile.txt')]
                                             ifFalse: [Transcript showCr: 'File does not exist !'].
  [true] whileTrue:[myString := myString trim.
                    index := myString indexOf: ' '.
                    index > 0 ifTrue: [myList add: (myString substring: 0 len: index).   
                                       myString := (myString substring: index
                                                    len: myString length - index) trim]
                              ifFalse: [myList add: myString .
                                        myArray := myList asArray.
                                        1 to: (myArray size) do: [:nr | Transcript showCr:
                                              (myArray at: nr) asString].
                                        ^false]]
!
gc01
  "   Classes new gc01   "
  "   Print total memory   "
  Transcript showCr: (GC getTotalMemory: true)
!
list01
  "   Classes new list01   "
  "   This code create a list, add three items, reverse the items and write this result to Transcript   "
  | myList |
   myList := List new.
   myList add: 'Vista';
             add: 'Smalltalk';
             add: 'Forever'.
  myList reverse.
  myList do: [:item |
    Transcript showCr: item]
!
list02
  "   Classes new list02   "
  "   Sort the list   "
  | myList |
  myList := List new.
  myList add: 'Vista';
            add: 'Smalltalk';
            add: 'Forever'.
  myList sort.
  myList do: [:item |
    Transcript showCr: item]
!
math01
  "   Classes new math01   "
  "   Print a class definition   "
  Transcript showCr: (Math cos: 3.14).
  Transcript showCr: (Math sin: 3.14).
  Transcript showCr: (Math e).
  Transcript showCr: (Math pi).
  Transcript showCr: (Math round: 3.14).
!
random01
  "   Classes new random01   "
  "   This code generate 100 random numbers from 1 to 99 and write to Transcript   "
  | nr random |
  nr := 0.
  random := Random new.
  100 timesRepeat: [
    nr := nr + 1.
    rand := (random nextMin: 1 max: 100).
    Transcript show: nr; show: ' -> '; showCr: rand]
!
string01
  "   Classes new string01   "
  "   Substring of a string.   "
  | myString myNewString |
  myString := 'Vista Smalltalk'.
  myNewString := myString substring: 6 len: 9.
  Transcript showCr: myNewString.
!
string02
  "   Classes new string02   "
  "   Substring of a string.   "
  | myString |
  myString := 'Vista Smalltalk'.
  Transcript showCr: (myString substring: 6 len: 9).
!
string03
  "   Classes new string03   "
  "   Substring of a string.   "
  | myString index |
  myString := 'Vista Smalltalk'.
  index := myString indexOf: 'Smalltalk'.
  Transcript showCr: (myString substring: index len: myString length - index).
!
string04
  "   Classes new string04   "
  "   Substring of a string.   "
  Transcript showCr: ('Vista Smalltalk' substring: 6 len: 9).
!
string05
  "   Classes new string05   "
  "   Concatenation of two strings   "
  | string string1 string2 | 
  string1 := 'Vista '.
  string2 := 'Smalltalk'.
  string := string1 concat: string2.
  Transcript showCr: string
!
string06
  "   Classes new string06   "
  "   Concatenation of two strings   "
  | string string1 string2 | 
  string1 := 'Vista '.
  string2 := 'Smalltalk'.
  string := string1 + string2.
  Transcript showCr: string
!
string07
  "   Classes new string07   "
  "   Concatenation of two strings   "
  | string string1 string2 | 
  string1 := 'Vista '.
  string2 := 'Smalltalk'.
  Transcript showCr: string1 + string2
!
string08
  "   Classes new string08   "
  "   Concatenation of two strings   "
  Transcript showCr: 'Vista' + ' ' +'Smalltalk'
!
string09
  "   Classes new string09   "
  "   Evaluation of a string   "
  | myString |
  myString := 'CalmoPuzzle open'.
  myString eval.
!
string10
  "   Classes new string10   "
  "   Insert a string   "
  | string string1 string2 |
  string1 := 'Vista Forever!'.
  string2 := 'Smalltalk '.
  string := string1 insertAt: 6 string: string2.
  Transcript showCr: string
!
string11
  "   Classes new string11   "
  "   Trim method   "
  | string1 string2 |
  string1 := '   Vista Smalltalk   '.
  string2 := string1 trim.
  Transcript showCr: '>' + string1 + '<'.
  Transcript showCr: '>' + string2 + '<'
!
transcript01
  "   Classes new transcript01   "
  Transcript show: 'Vista Smalltalk'.
  Transcript cr.
  Transcript show: 'Forever!'
!
transcript02
  "   Classes new transcript02   "
  Transcript show: 'Vista Smalltalk'; cr; show: 'Forever!'
!
transcript03
  "   Classes new transcript03   "
  Transcript showCr: 'Vista Smalltalk'.
  Transcript show: 'Forever!'
!
vm01
  "   Classes new vm01   "
  "   You can find all implementors of a method   "
  (Vm implementorsOf: 'open' asSymbol) inspect
!
vm02
  "   Classes new vm02   "
  "   You can find all senders of a method   "
  (Vm sendersOf: 'size' asSymbol) inspect
!
Tutorial subclass: #GUI
instanceVariableNames: ''
classVariableNames: ''
!
GUI class
!
copyright
   "   ~  written by: Gal Zsolt & Cathlyn Cosca ( CalmoSoft ) ~ 2006-2007 ~ calmosoft@gmail.com ~   "
!
GUI subclass: #CalmoDialog
instanceVariableNames: ''
classVariableNames: ''
!
CalmoDialog class
!
copyright
   "   ~  written by: Gal Zsolt & Cathlyn Cosca ( CalmoSoft ) ~ 2006-2007 ~ calmosoft@gmail.com ~   "
!
CalmoDialog
!
open
  "   CalmoDialog new open   "
  | button canvas dialogTextbox dockpanel window |
  window := self topWindowClass new.
  window title: 'Dialog'.
  dockpanel := DockPanel new.
  dialogTextbox := TextBox new.
  dialogTextbox text: 'Vista Smalltalk Forever!'.
  button := (Button content: 'OK' callback: [Transcript showCr: (dialogTextbox text asString)]).
  dockpanel  add: button.
  DockPanel setDock: button to: Dock bottom.
  dockpanel add: dialogTextbox.
  DockPanel setDock: dialogTextbox to: Dock top.
  canvas := Canvas new.
  canvas background: Brushes gray.
  dockpanel add: canvas.
  window add: dockpanel.
  window width: 250; height: 82.
  window open
!
GUI subclass: #CalmoStackpanel
instanceVariableNames: ''
classVariableNames: ''
!
CalmoStackpanel class
!
copyright
   "   ~  written by: Gal Zsolt & Cathlyn Cosca ( CalmoSoft ) ~ 2006-2007 ~ calmosoft@gmail.com ~   "
!
CalmoStackpanel
!
open
  "   CalmoStackpanel new open   "
  | buttonOK buttonClear canvas dialogTextbox dockpanel stackpanel window |
  window := self topWindowClass new.
  window title: 'Dialog'.
  dockpanel := DockPanel new.
  dialogTextbox := TextBox new.
  stackpanel := StackPanel horizontal.
  dialogTextbox text: 'Vista Smalltalk Forever!'.
  buttonOK := (Button content: 'OK' callback: [Transcript showCr: (dialogTextbox text asString)]).
  buttonClear := (Button content: 'Clear' callback: [dialogTextbox text: '']).
  stackpanel add: buttonOK.
  stackpanel add: buttonClear.
  dockpanel  add: stackpanel.
  DockPanel setDock: stackpanel to: Dock bottom.
  dockpanel add: dialogTextbox.
  DockPanel setDock: dialogTextbox to: Dock top.
  canvas := Canvas new.
  canvas background: Brushes gray.
  dockpanel add: canvas.
  window add: dockpanel.
  window width: 250; height: 82.
  window open
!
GUI subclass: #DigitalClock
instanceVariableNames: 'textBox'
classVariableNames: ''
!
DigitalClock class
!
copyright
   "   ~  written by: Gal Zsolt & Cathlyn Cosca ( CalmoSoft ) ~ 2006-2007 ~ calmosoft@gmail.com ~   "
!
DigitalClock
!
open
  "   DigitalClock new open   "
  | button dockpanel  window |
  window := self topWindowClass new.
  window title: 'Digital Clock'.
  window width: 100; height: 80.
  dockpanel := DockPanel new.
  button := (Button content: 'Show Date & Time' callback: [self showDateTime]).
  dockpanel add: button.
  DockPanel setDock: button to: Dock bottom.
  textBox := TextBox new.
  textBox textalignment: TextAlignment center.
  textBox background: Brushes yellow.
  textBox text: (DateTime now) asString.
  dockpanel add: textBox.
  DockPanel setDock: textBox to: Dock top.
  window add: dockpanel.
  window open.
!
showDateTime
  textBox text: (DateTime now) asString.
!
GUI subclass: #ListSwapDialog
instanceVariableNames: 'dockpanel listLeft listRight'
classVariableNames: ''
!
ListSwapDialog class
!
copyright
   "   ~  written by: Gal Zsolt & Cathlyn Cosca ( CalmoSoft ) ~ 2006-2007 ~ calmosoft@gmail.com ~   "
!
ListSwapDialog
!
buildBottom
  | buttonMoveLeft buttonMoveRight stackpanel |
  buttonMoveLeft := (Button content: 'Copy to Left' callback: [self moveLeft]).
  buttonMoveLeft width: 120.
  buttonMoveLeft height: 20.
  buttonMoveLeft background: Brushes yellow.
  buttonMoveRight := (Button content: 'Copy to Right' callback: [self moveRight]).
  buttonMoveRight width: 120.
  buttonMoveRight height: 20.
  buttonMoveRight background: Brushes yellow.
  stackpanel := StackPanel horizontal.
  stackpanel add: buttonMoveRight.
  stackpanel add: buttonMoveLeft.
  dockpanel  add: stackpanel.
  DockPanel setDock: stackpanel to: Dock bottom.
!
buildTop
  | stackpanel |
  listLeft := ListBox new.
  listRight := ListBox new.
  listLeft width: 120.
  listRight width: 120.
  listLeft borderbrush: Brushes red.
  listRight borderbrush: Brushes red.
  listLeft add: 'Beatles'.
  listLeft add: 'Rolling Stones '.
  listLeft add: 'Pink Floyd'.
  listLeft add: 'ELP '.
  listLeft add: 'Yes'.
  listRight add: 'Abba'.
  listRight add: 'Smokie'.
  listRight add: 'Tina Turner'.
  listRight add: 'Baccrara'.
  listRight add: 'Tom Jones'.
  stackpanel := StackPanel horizontal.
  stackpanel add: listLeft.
  stackpanel add: listRight.
  dockpanel  add: stackpanel.
  DockPanel setDock: stackpanel to: Dock top.
!
moveLeft
  | selected |
  (listRight selectedIndex > -1) ifTrue: [
    selected := listRight selectedItem.
    listLeft items add: selected]
!
moveRight
  | selected |
  (listLeft selectedIndex > -1) ifTrue: [
    selected := listLeft selectedItem.
    listRight items add: selected]
!
open
  "   ListSwapDialog new open   "
  | dockpanel window |
  window := self topWindowClass new.
  window title: 'List Swap Dialog'.
  window width: 240.
  window height: 360.
  dockpanel := DockPanel new.
  self buildTop.
  self buildBottom.
  window add: dockpanel.
  window open.
!
Tutorial subclass: #Structures
instanceVariableNames: ''
classVariableNames: ''
!
Structures class
!
copyright
   "   ~  written by: Gal Zsolt & Cathlyn Cosca ( CalmoSoft ) ~ 2006-2007 ~ calmosoft@gmail.com ~   "
!
Structures
!
block01
  "   Structures new block01   "
  | myBlock |
  myBlock := [
    Transcript showCr: 'Vista'.
    Transcript showCr: 'Smalltalk'.
    Transcript showCr: 'Forever!']. 
  myBlock run
!
iteration01
  "   Structures new iteration01   "
  "   Usage of iteration   "
  | nr |
  1 to:10 do: [:nr |
    Transcript showCr: nr asString]
!
iteration02
  "   Structures new iteration02   "
  "   Usage of iteration   "
  | nr |
  nr := 0.
  10 timesRepeat: [
    nr := nr+1.
    Transcript showCr: nr asString]
!
Tutorial subclass: #Syntax
instanceVariableNames: ''
classVariableNames: ''
!
Syntax class
!
copyright
   "   ~  written by: Gal Zsolt & Cathlyn Cosca ( CalmoSoft ) ~ 2006-2007 ~ calmosoft@gmail.com ~   "
!
Syntax
!
syntax

"   source:   "
"   http://minnow.cc.gatech.edu/squeak/5699   "

"   The original was created by Chris Rathman, at http://www.angelfire.com/tx4/cus/notes/smalltalk.html   "

"
Allowable characters:                                                
    - a-z                                                             
    - A-Z                                                            
    - 0-9                                                            
    - .+/\*~<>@%|&?                                                   
    - blank, tab, cr, ff, lf                                          
                                                                      
 Variables:                                                           
    - variables must be declared before use                           
    - shared vars must begin with uppercase                          
    - local vars must begin with lowercase                            
    - reserved names: nil, true, false, self, super, and Smalltalk    
                                                                      
 Variable scope:                                                      
    - Global: defined in Dictionary Smalltalk and accessible by all   
         objects in system                                            
    - Special: (reserved) Smalltalk, super, self, true, false, & nil 
    - Method Temporary: local to a method                             
    - Block Temporary: local to a block                               
    - Pool: variables in a Dictionary object                          
    - Method Parameters: automatic local vars created as a result of  
         message call with params                                     
    - Block Parameters: automatic local vars created as a result of   
         value: message call                                          
    - Class: shared with all instances of one class & its subclasses  
    - Class Instance: unique to each instance of a class              
    - Instance Variables: unique to each instance                     
"
!
Object subclass: #UndefinedObject
instanceVariableNames: ''
classVariableNames: ''
!
UndefinedObject
!
isNil
   ^ true
!
notNil
   ^ false
!
Object subclass: #UserApps
instanceVariableNames: ''
classVariableNames: ''
!
UserApps class
!
open
  ^ super new open
!
UserApps
!
open
  ^ nil
!
UserApps subclass: #Demos
instanceVariableNames: ''
classVariableNames: ''
!
Demos subclass: #DemoLauncher
instanceVariableNames: ''
classVariableNames: ''
!
DemoLauncher
!
open
  "   DemoLauncher open   "
  | panel w |
  panel := StackPanel new.
  panel add: (Button content: 'RssDemo' callback: [RssDemo open]).
  panel add: (Button content: 'Video Store' callback: [VideoStore open]).
  panel add: (Button content: 'Yahoo Local Search' callback: [YahooLocalSearch open]).
  panel add: (Button content: 'Yahoo News Search' callback: [YahooNewsSearch open]).
  w := self topWindowClass new.
  w width: 150; height: 130; title: 'Demos'; add: panel; open
!
Demos subclass: #RssDemo
instanceVariableNames: 'channel data document rss titlesLb descTb urlTb window'
classVariableNames: ''
!
RssDemo
!
buildBottomPanel
  | button  textbox |
  button := Button new.
  button content: 'Load'.
  button addEvent: 'Click' action: [self loadFeed].
  urlTb := TextBox new.
  urlTb acceptsReturn: false.
  urlTb text: 'http://rss.cnn.com/rss/edition.rss'.
  dockpanel := DockPanel new.
  dockpanel add: button.
  DockPanel setDock: button to: Dock right.
  dockpanel add: urlTb .
  ^ dockpanel
!
buildTopPanel
  titlesLb := ListBox new.
  titlesLb background: (SolidColorBrush new: Color customBlue).
  titlesLb addEvent: 'SelectionChanged' action: [self selectedTitle].
  descTb := TextBox new.
  descTb background: (SolidColorBrush new: Color customGreen).
  descTb textwrapping: TextWrapping wrapWithOverflow.
  descTb horizontalScrollBarVisibility: 'Disabled'.
  ^ Grid hsplit: 0.45 child1: titlesLb child2: descTb
!
findChannel
  | children |
  children := XmlUtility childNodes: rss.
  children do:[:x | x name == 'channel' ifTrue: [channel := x]]
!
findRss
  | children |
  children := XmlUtility childNodes: document.
  children do:[:x | rss := x]
!
loadFeed
  | url |
  data := List new.
  titlesLb clear.
  descTb clear.
  url := urlTb text trim.
  url length == 0 ifTrue: [^nil].
  Internet readTextFromUrl: url callback: [:t | self loadFeed2: t]
!
loadFeed2: aString
  | children reader stringreader |
  stringreader := StringReader onString: aString.
  reader := XmlTextReader fromTextReader: stringreader.
  document := XmlDocument new.
  document load: reader.
  self findRss.
  rss isNil ifTrue: [^nil].
  self findChannel.
  channel isNil ifTrue:[^nil].
  self refreshHeading; refreshItems
!
open
  "   RssDemo new open   "
  | bottom dockpanel top |
  window := self topWindowClass new.
  window title: 'Rss Demo'.
  dockpanel := DockPanel new.
  bottom := self buildBottomPanel.
  dockpanel add: bottom.
  DockPanel setDock: bottom to: Dock bottom.
  top := self buildTopPanel.
  dockpanel add: top.
  window add: dockpanel.
  window open
!
refreshHeading
  | title language link description |
  title := (channel at: 'title') innerText.
  language := (channel at: 'language') innerText.
  link := (channel at: 'link') innerText.
  description := (channel at: 'description') innerText.
  window title: title
!
refreshItem: anItem
  | title description li link |
  title := (anItem at: 'title') innerText.
  description := (anItem at: 'description') innerText.
  link := (anItem at: 'link') innerText.
  data add: (Array with: title with: description with: link).
  li := ListBoxItem new.
  li content: title.
  titlesLb items add: li
!
refreshItems
  | children |
  children := XmlUtility childNodes: channel.
  children do: [:x | x name == 'item' ifTrue: [self refreshItem: x]]
!
selectedTitle
  | desc index |
  index := titlesLb selectedIndex.
  desc := (data at: index + 1) at: 2.
  descTb text: desc
!
Demos subclass: #VideoStore
instanceVariableNames: 'clientsLb rentalsLb textbox url'
classVariableNames: ''
!
VideoStore
!
buildBottomPanel
  textbox := TextBox new.
  ^ textbox
!
buildTopPanel
  clientsLb := ListBox new.
  clientsLb background: (SolidColorBrush new: Color customGreen).
  clientsLb foreground: Brushes darkGreen.
  clientsLb addEvent: 'SelectionChanged' action: [self clientSelection].
  rentalsLb := ListBox new.
  rentalsLb background: (SolidColorBrush new: Color customBlue).
  rentalsLb foreground: Brushes darkBlue.
  rentalsLb addEvent: 'SelectionChanged' action: [self rentalSelection].
  ^ Grid hsplit: 0.45
         child1: clientsLb
         child2: rentalsLb
!
clientDetail: aString
  | lines |
  lines := aString splitStr: ':'.
  textbox clear.
  lines do: [:line | textbox println: line]
!
clientRentals: aList
  | li |
  rentalsLb clear.
  aList do: [:item |
    li := ListBoxItem new.
    li content: (item at: 1).
    li tag: item.
    rentalsLb items add: li]
!
clientSelection
  | id php |
  clientsLb selectedItem isNil ifTrue:[^nil].
  id := clientsLb selectedItem tag.
  php := PhpConnect new.
  php url: url.
  php callback: [:detail | self clientDetail: detail].
  php serialized: true.
  php queryServer: 'cmd=clientdetail&id=' + id.
  php := PhpConnect new.
  php url: url.
  php callback: [:rentals | self clientRentals: rentals].
  php serialized: true.
  php queryServer: 'cmd=clientrentals&id=' + id
!
open
  | w |
  url := 'http://vistascript.net/vistascript/webserv/videostore.php'.
  w := self topWindowClass new.
  w title: 'Video Store Demo'.
  w add: (Grid vsplit: 0.60
               child1: self buildTopPanel
               child2: self buildBottomPanel).
  w open.
  self refreshClientList
!
refreshClientList
  | php |
  php := PhpConnect new.
  php url: url.
  php callback: [:list | self refreshClientList: list].
  php serialized: true.
  php queryServer: 'cmd=clientlist'
!
refreshClientList: aList
  | li |
  clientsLb clear.
  aList do: [:item |
    li := ListBoxItem new.
    li content: (item at: 1).
    li tag: (item at: 2).
    clientsLb items add: li]
!
rentalSelection
  | rental |
  rentalsLb selectedItem isNil ifTrue:[^nil].
  rental := rentalsLb selectedItem tag.
  textbox clear.
  rental do:[:item | textbox println: item]
!
Demos subclass: #YahooLocalSearch
instanceVariableNames: 'resultsLb resultTb searchTb url zipCb'
classVariableNames: ''
!
YahooLocalSearch
!
buildBottomPanel
  | button combobox dockpanel1 dockpanel2 |
  button := Button new.
  button content: 'Search'.
  button addEvent: 'Click' action: [self submitQuery].
  searchTb := TextBox new.
  searchTb acceptsReturn: false.
  zipCb := ComboBox new.
  zipCb width: 100.
  zipCb add: '10001'; add: '60001'; add: '90001'.
  zipCb selectedIndex: 0.
  dockpanel1 := DockPanel new.
  dockpanel1 add: zipCb.
  DockPanel setDock: zipCb to: Dock left.
  dockpanel1 add: searchTb.
  dockpanel2 := DockPanel new.
  dockpanel2 add: button.
  DockPanel setDock: button to: Dock right.
  dockpanel2 add: dockpanel1 .
  ^ dockpanel2
!
buildTopPanel
  resultsLb := ListBox new.
  resultsLb background: (SolidColorBrush new: Color customBlue).
  resultTb := TextBox new.
  resultsLb addEvent: 'SelectionChanged' action: [self selectedResult].
  resultTb background: (SolidColorBrush new: Color customGreen).
  resultTb textwrapping: TextWrapping wrapWithOverflow.
  resultTb horizontalScrollBarVisibility: 'Disabled'.
  ^ Grid hsplit: 0.45 child1: resultsLb child2: resultTb
!
noResult
  resultTb text: 'No results'
!
open
  | bottom dockpanel top w |
  url := 'http://api.local.yahoo.com/LocalSearchService/V3/localSearch'.
  w := self topWindowClass new.
  w title: 'Yahoo Local Search'.
  dockpanel := DockPanel new.
  bottom := self buildBottomPanel.
  dockpanel add: bottom.
  DockPanel setDock: bottom to: Dock bottom.
  top := self buildTopPanel.
  dockpanel add: top.
  w add: dockpanel.
  w open
!
selectedResult
  | item |
  item := resultsLb selectedItem.
  item isNil ifTrue: [^nil].
  resultTb text: item tag printString
!
showResults: aResultDictionary
  | li result resultset goodlist |
  aResultDictionary isDictionary ifFalse:[^self noResult].
  resultset := aResultDictionary at: 'ResultSet'.
  resultset isDictionary ifFalse: [^self noResult].
  result := resultset at: 'Result'.
  result isArray ifFalse:[^self noResult].
  goodlist := result select:[:v | (v isDictionary and:
                                  [v containsKey: 'Title']) and:
                                  [v containsKey: 'Address']].
  goodlist size == 0 ifTrue: [^self noResult].
  goodlist do:[:item |
    li := ListBoxItem new.
    li content: (item at: 'Title').
    li tag: (item at: 'Address').
    resultsLb items add: li].
!
submitQuery
  | query |
  resultsLb clear.
  resultTb clear.
  query := searchTb text trim.
  query length == 0 ifTrue:[^nil].
  self submitQuery: query
!
submitQuery: aQuery
  | json |
  json := JsonConnect new.
  json url: url.
  json callback: [:r | self showResults: r].
  json queryServer: 'appid=vstsearchnews&output=json&results=20&language=en&zip=' +
                     zipCb selectedValue + '&query=' + aQuery
!
talalat
  ^tru
!
Demos subclass: #YahooNewsSearch
instanceVariableNames: 'resultsLb resultTb searchTb url'
classVariableNames: ''
!
YahooNewsSearch
!
buildBottomPanel
  | button  textbox |
  button := Button new.
  button content: 'Search'.
  button addEvent: 'Click' action: [self submitQuery].
  searchTb := TextBox new.
  searchTb acceptsReturn: false.
  dockpanel := DockPanel new.
  dockpanel add: button.
  DockPanel setDock: button to: Dock right.
  dockpanel add: searchTb .
  ^ dockpanel
!
buildTopPanel
  resultsLb := ListBox new.
  resultsLb background: (SolidColorBrush new: Color customBlue).
  resultTb := TextBox new.
  resultsLb addEvent: 'SelectionChanged' action: [self selectedResult].
  resultTb background: (SolidColorBrush new: Color customGreen).
  resultTb textwrapping: TextWrapping wrapWithOverflow.
  resultTb horizontalScrollBarVisibility: 'Disabled'.
  ^ Grid hsplit: 0.45 child1: resultsLb child2: resultTb
!
noResult
  resultTb text: 'No results'
!
open
  | bottom dockpanel top w |
  url := 'http://api.search.yahoo.com/NewsSearchService/V1/newsSearch'.
  w := self topWindowClass new.
  w title: 'Yahoo News Search'.
  dockpanel := DockPanel new.
  bottom := self buildBottomPanel.
  dockpanel add: bottom.
  DockPanel setDock: bottom to: Dock bottom.
  top := self buildTopPanel.
  dockpanel add: top.
  w add: dockpanel.
  w open
!
selectedResult
  | item |
  item := resultsLb selectedItem.
  item isNil ifTrue: [^nil].
  resultTb text: item tag printString
!
showResults: aResultDictionary
  | li result resultset goodlist |
  aResultDictionary isDictionary ifFalse:[^self noResult].
  resultset := aResultDictionary at: 'ResultSet'.
  resultset isDictionary ifFalse: [^self noResult].
  result := resultset at: 'Result'.
  result isDictionary ifFalse:[^self noResult].
  goodlist := result values select:[:v | (v isDictionary and:
                                         [v containsKey: 'Title']) and:
                                         [v containsKey: 'Summary']].
  goodlist size == 0 ifTrue: [^self noResult].
  goodlist do:[:item |
    li := ListBoxItem new.
    li content: (item at: 'Title').
    li tag: (item at: 'Summary').
    resultsLb items add: li].
!
submitQuery
  | query |
  resultsLb clear.
  resultTb clear.
  query := searchTb text trim.
  query length == 0 ifTrue:[^nil].
  self submitQuery: query
!
submitQuery: aQuery
  | php |
  php := PhpConnect new.
  php url: url.
  php callback: [:r | self showResults: r].
  php serialized: true.
  php queryServer: 'appid=vstsearchnews&output=php&results=50&language=en&query=' + aQuery
!
UserApps subclass: #Games
instanceVariableNames: ''
classVariableNames: ''
!
Games subclass: #CalmoPuzzle
instanceVariableNames: 'canvas empty size size2 tileArray'
classVariableNames: ''
!
CalmoPuzzle class
!
copyright
   "   ~  written by: Gal Zsolt & Cathlyn Cosca ( CalmoSoft ) ~ 2006-2007 ~ calmosoft@gmail.com ~   "
!
CalmoPuzzle
!
addTiles
  1 to: size2 do:[:nr | self createTile: nr.
                        self placeTile: nr].
  empty := size2.
  (tileArray at: empty) content: ''
!
buildTopPanel
  | sp |
  sp := StackPanel horizontal.
  sp add: (Button content: '2x2' callback: [self changeSize: 2]).
  sp add: (Button content: '3x3' callback: [self changeSize: 3]).
  sp add: (Button content: '4x4' callback: [self changeSize: 4]).
  sp add: (Button content: '5x5' callback: [self changeSize: 5]).
  sp add: (Button content: '6x6' callback: [self changeSize: 6]).
  sp add: (Button content: '7x7' callback: [self changeSize: 7]).
  sp add: (Button content: '8x8' callback: [self changeSize: 8]).
  sp add: (Button content: '9x9' callback: [self changeSize: 9]).
  ^ sp
!
canMove: nr
  up := (empty = (nr - size)).
  down := (empty = (nr + size)).
  left := ((empty = (nr - 1)) and: ((nr\\size)~=1)).
  right := ((empty = (nr + 1)) and: ((nr\\size)~=0)).
  move := up or: down or: left or: right.
  ^move
!
changeSize: nr
  self deleteTiles.
  size := nr.
  size2 := size*size.
  tileArray := Array new: size2.
  self addTiles
!
createTile: nr
  tile := (Button content: nr callback: [self tryMove: nr]).
  tile width: canvas actualWidth / size.
  tile height: canvas actualHeight / size.
  tileArray at: nr put: tile.
  canvas add: (tileArray at: nr).
  ^ tile
!
deleteTiles
  canvas clear
!
gameOver
  1 to: (size2 - 1) do: [:nr | tileContent := (tileArray at: nr) content.
                               (tileContent ~= nr) ifTrue: [^false]].
  ^true
!
initVariables  
  size := 4.
  size2 := size*size.
  tileArray := Array new: size2
!
open
  "   CalmoPuzzle open   "
  "   Written by Gal Zsolt (CalmoSoft) ~ 2006   "
  | button dockpanel top window |
  self initVariables.
  window := self topWindowClass new.
  window title: '15 Puzzle'.
  dockpanel := DockPanel new.
  button := (Button content: 'Scramble' callback: [self scramble]).
  dockpanel add: button.
  DockPanel setDock: button to: Dock bottom.
  top := self buildTopPanel.
  dockpanel add: top.
  DockPanel setDock: top to: Dock top.
  canvas := Canvas new.
  canvas background: Brushes gray.
  dockpanel add: canvas.
  window add: dockpanel.
  window open.
  self addTiles
!
placeTile: nr
  | row col x y |
  tile := tileArray at: nr.
  row := ((nr - 1) // size) + 1.
  col := ((nr - 1) \\ size) + 1.
  x := canvas actualWidth * (col - 1) / size.
  y := canvas actualHeight * (row - 1) / size.
  Canvas setLeft: tile to: x.
  Canvas setTop: tile to: y
!
scramble
  | random |
  random := Random new.
  1000 timesRepeat: [rand := (random nextMin: 1 max: (size2 + 1)).
                     self tryMove: rand]
!
tryMove: nr
  (self canMove: nr) ifTrue: [
  (tileArray at: empty) content: (tileArray at: nr) content.
  (tileArray at: nr) content: ''.
  empty := nr.
  self gameOver ifTrue: [(tileArray at: size2) content: 'Hooray!']]
!
Games subclass: #GamesLauncher
instanceVariableNames: ''
classVariableNames: ''
!
GamesLauncher
!
open
  "   GamesLauncher open   "
  | panel w |
  panel := StackPanel new.
  panel add: (Button content: 'CalmoPuzzle' callback: [CalmoPuzzle open]).
  w := self topWindowClass new.
  w width: 150; height: 62; title: 'Games'; add: panel; open
!
UserApps subclass: #Graphics
instanceVariableNames: ''
classVariableNames: ''
!
Graphics subclass: #GraphicsLauncher
instanceVariableNames: ''
classVariableNames: ''
!
GraphicsLauncher
!
open
  "   GraphicsLauncher open   "
  | panel w |
  panel := StackPanel new.
  panel add: (Button content: 'RotateBlocks' callback: [RotateBlocks open]).
  panel add: (Button content: 'RotateText' callback: [RotateText open]).
  panel add: (Button content: 'ScaleDemo' callback: [ScaleDemo open]).
  panel add: (Button content: 'SketchPad' callback: [SketchPad open]).
  panel add: (Button content: 'WheelDemo' callback: [WheelDemo open]).
  w := self topWindowClass new.
  w width: 150; height: 150; title: 'Graphics'; add: panel; open
!
Graphics subclass: #RotateBlocks
instanceVariableNames: 'canvas storyboard'
classVariableNames: ''
!
RotateBlocks
!
addRectangle: aName x: x y: y top: top
  | animation rect1 rect2 transform tname |
  rect1 := Rectangle new.
  rect1 width: 50; height: 50.
  rect1 stroke: Brushes black.
  rect1 strokethickness: 5.
  rect1 opacity: 0.25.
  canvas add: rect1.
  Canvas setTop: rect1 to: top; setLeft: rect1 to: 85.
  rect2 := Rectangle new.
  rect2 width: 50; height: 50.
  rect2 stroke: Brushes black.
  rect2 strokethickness: 5.
  canvas add: rect2.
  Canvas setTop: rect2 to: top; setLeft: rect2 to: 85.
  tname := aName.
  transform := RotateTransform new.
  canvas registerName: tname for: transform.
  transform angle: 0; centerX: x; centerY: y.
  rect2 renderTransform: transform.
  animation := DoubleAnimation from: 0.0 to: 360.0 duration: (Duration new: (TimeSpan fromSeconds: 2.0)).
  StoryBoard setTargetName: animation to: tname.
  StoryBoard setTargetProperty: animation to: (PropertyPath new: RotateTransform angleProperty).
  storyboard children add: animation
!
open
  "   RotateBlocks open   "
  | btn dp w |
  storyboard := StoryBoard new.
  w := self topWindowClass new.
  w title: 'Rotate Blocks'.
  dp := DockPanel new.
  btn := Button new.
  btn content: 'Start'.
  btn addEvent: 'Click' action: [self startStop].
  dp add: btn.
  DockPanel setDock: btn to: Dock bottom.
  canvas := Canvas new.
  canvas clipToBounds: true.
  NameScope setNameScope: canvas to: NameScope new.
  dp add: canvas.
  w add: dp.
  w width: 250; height: 300; open.
  self addRectangle: 'CenteredRotation' x: 25 y: 25 top: 30.
  self addRectangle: 'CornerRotation' x: 0 y: 0 top: 120
!
startStop
   storyboard begin: canvas
!
Graphics subclass: #RotateText
instanceVariableNames: 'angle1 angle2 canvas storyboard'
classVariableNames: ''
!
RotateText
!
addRectangle: aName x: x y: y top: top
  | animation rect1 rect2 transform tname |
  rect1 := Rectangle new.
  rect1 width: 250; height: 150.
  rect1 stroke: Brushes black.
  rect1 strokethickness: 5.
  rect1 opacity: 0.25.
  canvas add: rect1.
  Canvas setTop: rect1 to: top; setLeft: rect1 to: 75.
  rect2 := TextEditor new.
  rect2 showLines: true.
  rect2 text: 'Hello world'.
  rect2 width: 250; height: 150.
  rect2 background: Brushes ivory.
  canvas add: rect2.
  Canvas setTop: rect2 to: top; setLeft: rect2 to: 75.
  tname := aName.
  transform := RotateTransform new.
  canvas registerName: tname for: transform.
  transform angle: angle1 ; centerX: x; centerY: y.
  rect2 renderTransform: transform.
  animation := DoubleAnimation from: angle1 to: angle2 duration: (Duration new: (TimeSpan fromSeconds: 1.0)).
  StoryBoard setTargetName: animation to: tname.
  StoryBoard setTargetProperty: animation to: (PropertyPath new: RotateTransform angleProperty).
  storyboard children add: animation
!
open
  "   RotateText open   "
  | btn dp w |
  angle1 := 0.0.
  angle2 := 45.0.
  storyboard := StoryBoard new.
  w := self topWindowClass new.
  w title: 'Rotate Text'.
  dp := DockPanel new.
  btn := Button new.
  btn content: 'Start'.
  btn addEvent: 'Click' action: [self startStop].
  dp add: btn.
  DockPanel setDock: btn to: Dock bottom.
  canvas := Canvas new.
  canvas background: Brushes aliceBlue.
  canvas clipToBounds: true.
  NameScope setNameScope: canvas to: NameScope new.
  dp add: canvas.
  w add: dp.
  w width: 450; height: 300; open.
  self addRectangle: 'CenteredRotation' x: 125 y: 75 top: 60.
!
startStop
   storyboard begin: canvas
!
Graphics subclass: #ScaleDemo
instanceVariableNames: 'text'
classVariableNames: ''
!
ScaleDemo
!
buildBottomPanel
  | sp |
  sp := StackPanel horizontal.
  sp add: (Button content: 'Reset' callback: [self reset]).
  sp add: (Button content: 'Scale 1' callback: [self scale1]).
  sp add: (Button content: 'Scale 2' callback: [self scale2]).
  sp add: (Button content: 'Skew 1' callback: [self skew1]).
  sp add: (Button content: 'Skew 2' callback: [self skew2]).
  ^ sp
!
buildTopPanel
  | canvas |
  canvas := Canvas new.
  text := TextBox new.
  text fontsize: 50; textalignment: TextAlignment center; fontweight: FontWeights ultrabold.
  text isenabled: false; foreground: Brushes blue.
  text text: 'SAMPLE'.
  canvas add: text.
  Canvas setLeft: text to: 0.
  Canvas setTop: text to: 0.
  canvas clipToBounds: true.
  ^ canvas
!
open
  | bottom dockpanel window |
  window := self topWindowClass new.
  window title: 'Scale Demo'.
  dockpanel := DockPanel new.
  bottom := self buildBottomPanel.
  dockpanel add: bottom.
  DockPanel setDock: bottom to: Dock bottom.
  dockpanel add: self buildTopPanel.
  window add: dockpanel.
  window open
!
reset
   text renderTransform: Transform identity
!
scale1
   | transform |
   transform := ScaleTransform new.
   transform scaleX: 0.5; scaleY: 2.
   text renderTransform: transform
!
scale2
   | transform |
   transform := ScaleTransform new.
   transform scaleX: 2; scaleY: 0.5.
   text renderTransform: transform
!
skew1
   | transform |
   transform := SkewTransform new.
   transform angleX: 45.
   text renderTransform: transform
!
skew2
   | transform |
   transform := SkewTransform new.
   transform angleY: 30.
   text renderTransform: transform
!
Graphics subclass: #SketchPad
instanceVariableNames: 'inkcanvas'
classVariableNames: ''
!
SketchPad
!
open
  | w |
  inkcanvas := InkCanvas new.
  w := self topWindowClass new.
  w title: 'SketchPad'.
  w add: inkcanvas.
  inkcanvas background: Brushes yellow.
  " inkcanvas editingMode: InkCanvasEditingMode inkAndGesture."
  w open
!
Graphics subclass: #WheelDemo
instanceVariableNames: 'canvas storyboard'
classVariableNames: ''
!
WheelDemo
!
addAnimation: aWheel center: aPoint radius: aRadius
  | animation transform tname1 tname2 xstart xend |
  tname1 := 'RotateWheel'.
  transform := RotateTransform new.
  canvas registerName: tname1 for: transform.
  transform angle: 0; centerX: aPoint x; centerY: aPoint y.
  aWheel renderTransform: transform.
  animation := DoubleAnimation from: 0.0 to: 360.0 duration: (Duration new: (TimeSpan fromSeconds: 2.0)).
  StoryBoard setTargetName: animation to: tname1.
  StoryBoard setTargetProperty: animation to: (PropertyPath new: RotateTransform angleProperty).
  storyboard children add: animation.
  xstart := aPoint x - aRadius.
  xend := xstart + (Math pi * 2 * aRadius).
  animation := DoubleAnimation from:  xstart to: xend duration: (Duration new: (TimeSpan fromSeconds: 2.0)).
  tname2 := 'MoveWheel'.
  canvas registerName: tname2 for: aWheel.
  StoryBoard setTargetName: animation to: tname2.
  StoryBoard setTargetProperty: animation to: (PropertyPath new: Canvas leftProperty).
  storyboard children add: animation
!
open
  | btn center radius dp w wheel |
  storyboard := StoryBoard new.
  w := self topWindowClass new.
  w title: 'Wheel Demo'.
  dp := DockPanel new.
  btn := Button new.
  btn content: 'Start'.
  btn addEvent: 'Click' action: [self start].
  dp add: btn.
  DockPanel setDock: btn to: Dock bottom.
  canvas := Canvas new.
  canvas clipToBounds: true.
  NameScope setNameScope: canvas to: NameScope new.
  dp add: canvas.
  w add: dp.
  w height: 250; width: 350.
  w open.
  center := Point x: 100 y: 100.
  radius := 50.
  wheel := Wheel createWheel: 6 radius: radius center: center.
  canvas add: wheel.
  self addAnimation: wheel center: center radius: radius
!
start
    storyboard begin: canvas
!
UserApps subclass: #Remote
instanceVariableNames: ''
classVariableNames: ''
!
Remote subclass: #ConnectedObjects
instanceVariableNames: 'connection view'
classVariableNames: ''
!
ConnectedObjects class
!
jabber: anId passwd: passwd contact: anId2
  ^ self new jabber: anId passwd: passwd contact: anId2
!
new
 ^ super new init: '<Grid
xmlns="http://schemas.microsoft.com/winfx/2006/xaml/presentation"
xmlns:x="http://schemas.microsoft.com/winfx/2006/xaml"
x:Name="DocumentRoot"
>
<Button
 Name="Button0" Content="Button0" Margin="128,41,0,0" Width="70" Height="30" Background="Honeydew" Foreground="SlateBlue">
</Button>
<Ellipse
 Name="Ellipse0" Margin="45,72,0,0" Width="60" Height="60" Fill="MediumSeaGreen" Stroke="Black">
</Ellipse>
<Ellipse
 Name="Ellipse1" Margin="224,73,0,0" Width="60" Height="60" Fill="PaleVioletRed" Stroke="Black">
</Ellipse>
<Rectangle
 Name="Rect0" Margin="113,80,0,0" RadiusX="20" RadiusY="20" Width="100" Height="50" Fill="Firebrick" Stroke="Black">
</Rectangle>
</Grid>
'
!
tms: anId listenTo: anArray
  ^ self new tms: anId listenTo: anArray
!
ConnectedObjects
!
button0
 ^ self view find: 'Button0'
!
button0Click: aSender
  Transcript showCr: 'Button0 event Click'
!
elementMoved: elementMovedArgs
 | name x y |
 name := elementMovedArgs name.
 x := elementMovedArgs x.
 y := elementMovedArgs y.
 self sendMessage: (Array with: 'setLocation:' with: (Array with: name with: x with: y)).
!
ellipse0
 ^ self view find: 'Ellipse0'
!
ellipse1
 ^ self view find: 'Ellipse1'
!
init: aXamlString
 view := View new.
 view designMode: false.
 view packager xaml: aXamlString.
 view setDraggable: self ellipse0 to: true.
 view setDraggable: self ellipse1 to: true.
 view setDraggable: self rect0 to: true.
 self button0 addEvent: 'Click' action: [self button0Click: self button0].
 self view addEvent: 'ElementMoved' action: [:x | self elementMoved: x].
!
jabber: anId passwd: passwd contact: anId2
  | w |
  connection := JabberConnect new: true.
  connection user: anId; passwd: passwd; contact: anId2.
  connection callback: [:array | self performArray: array].
  connection connect.
  w := self topWindowClass new.
  w title: 'ConnectedObjects (' + anId + ')'.
  w add: view.
  w open
!
rect0
 ^ self view find: 'Rect0'
!
sendMessage: anArray
  connection send: anArray
!
setLocation: anArray
  | name x y |
  name := anArray at: 1.
  x := anArray at: 2.
  y := anArray at: 3.
  self view setLocation: name x: x y: y
!
tms: myId listenTo: anArray
  | listener w |
  connection := TmsConnect channel: 'test' name: 'connectedobjects' + myId.
  anArray do: [:theirId |
    listener := TmsConnect channel: 'test' name: 'connectedobjects' + theirId
                        callback: [:array | self performArray: array].
    listener startPolling: 1].
  w := self topWindowClass new.
  w title: 'ConnectedObjects (' + myId + ')'.
  w add: view.
  w open
!
view
 ^ view
!
Remote subclass: #DrawAndChat
instanceVariableNames: 'connection designer textin textout'
classVariableNames: ''
!
DrawAndChat class
!
jabber: anId passwd: passwd contact: anId2
  ^ super new jabber: anId passwd: passwd contact: anId2
!
tms: anId listenTo: anArray
  ^ super new tms: anId listenTo: anArray
!
DrawAndChat
!
buildChatPanel
  | button dockpanel grid |
  textin := TextBox new.
  textout := TextBox new.
  grid := Grid vsplit: 0.45 child1: textin child2: textout.
  grid background: Brushes gray.
  dockpanel := DockPanel new.
  button := Button new.
  button content: 'Send'.
  button addEvent: 'Click' action: [self sendText].
  dockpanel add: button.
  DockPanel setDock: button to: Dock bottom.
  dockpanel add: grid.
  ^ dockpanel
!
buildDesignerPanel
  | button dockpanel |
  designer := Designer new.
  dockpanel := DockPanel new.
  button := Button new.
  button content: 'Send'.
  button addEvent: 'Click' action: [self sendDrawing].
  dockpanel add: button.
  DockPanel setDock: button to: Dock bottom.
  dockpanel add: designer.
  ^ dockpanel
!
jabber: anId passwd: passwd contact: anId2
  | w |
  connection := JabberConnect new: true.
  connection user: anId; passwd: passwd; contact: anId2.
  connection callback: [:array | self performArray: array].
  connection connect.
  w := self topWindowClass new.
  w title: 'Draw ''N Chat (' + anId + ')'.
  w add: (Grid hsplit: 0.45
               child1: self buildDesignerPanel
               child2: self buildChatPanel).
  w open
!
printText: aMessage
  textin println: aMessage
!
sendDrawing
  self sendMessage: (Array with: 'setLocalPackage:' with: designer view packager package)
!
sendMessage: anArray
  connection send: anArray
!
sendText
  self sendMessage: (Array with: 'printText:' with: textout text trim).
  textout text: ''
!
setLocalPackage: anObject
  designer view packager package: anObject
!
tms: myId listenTo: anArray
  | listener w |
  connection := TmsConnect channel: 'test' name: 'drawandchat' + myId.
  anArray do: [:theirId |
    listener := TmsConnect channel: 'test' name: 'drawandchat' + theirId
                        callback: [:array | self performArray: array].
    listener startPolling: 1].
  w := self topWindowClass new.
  w title: 'Draw ''N Chat (' + myId + ')'.
  w add: (Grid hsplit: 0.45
               child1: self buildDesignerPanel
               child2: self buildChatPanel).
  w open
!
Remote subclass: #RemoteLauncher
instanceVariableNames: ''
classVariableNames: ''
!
RemoteLauncher
!
open
  "   RemoteLauncher open   "
  | panel w |
  panel := StackPanel new.
  panel add: (Button content: 'DrawAndChat-A' callback: [DrawAndChat tms: 'A' listenTo: #('B' 'C')]).
  panel add: (Button content: 'DrawAndChat-B' callback: [DrawAndChat tms: 'B' listenTo: #('A' 'C')]).
  panel add: (Button content: 'DrawAndChat-C' callback: [DrawAndChat tms: 'C' listenTo: #('A' 'B')]).
  panel add: (Button content: 'Robot TicTacToe' callback: [RobotTicTacToe open]).
  panel add: (Button content: 'TicTacToe-X' callback: [TmsTicTacToe token1: 'X' token2: 'O']).
  panel add: (Button content: 'TicTacToe-O' callback: [TmsTicTacToe token1: 'O' token2: 'X']).
  panel add: (Button content: 'TmsInspect-1' callback: [TmsInspect me: 1 you: 2]).
  panel add: (Button content: 'TmsInspect-2' callback: [TmsInspect me: 2 you: 1]).
  panel add: (Button content: 'TmsXaml-1' callback: [TmsXaml me: 1 you: 2]).
  panel add: (Button content: 'TmsXaml-2' callback: [TmsXaml me: 2 you: 1]).
  w := self topWindowClass new.
  w width: 150; height: 255; title: 'Remote'; add: panel; open
!
Remote subclass: #RobotTicTacToe
instanceVariableNames: 'canvas textin json tileArray token'
classVariableNames: ''
!
RobotTicTacToe class
!
open
  ^ super new open
!
RobotTicTacToe
!
buildBoardPanel
  | dockpanel tile block |
  tileArray := Array new: 9.
  canvas := Canvas new.
  1 to: 9 do: [:i |
    tile := self createButton: i with: token.
    tileArray at: i put: tile.
    canvas add: tile].
  canvas clipToBounds: true.
  canvas addEvent: 'SizeChanged' action: [self placeTiles].
  dockpanel := DockPanel new.
  dockpanel add: canvas.
  ^ dockpanel
!
buildChatPanel
  | button dockpanel |
  textin := TextBox new.
  dockpanel := DockPanel new.
  button := Button new.
  button content: 'Restart'.
  button addEvent: 'Click' action: [self restart].
  dockpanel add: button.
  DockPanel setDock: button to: Dock bottom.
  dockpanel add: textin.
  ^ dockpanel
!
createButton: anIndex with: aString
   | tile |
   tile := Button new.
   tile content: ''.
   tile addEvent: 'Click' action: [self markTiles: anIndex with: aString].
   ^ tile
!
markLocalTile: index with: aString
  | tile |
  tile := tileArray at: index.
  tile content: aString
!
markTiles: index with: aString
  self markLocalTile: index with: aString.
  self sendMessageToRobot
!
open
  | w |
  token := 'X'.
  json := JsonConnect new.
  json url: 'http://vistascript.net/vistascript/webserv/t3bot.php'.
  json callback: [:response | self performRobotMessages: (response at: 'data')].
  w := self topWindowClass new.
  w title: 'Robot Tic-Tac-Toe'.
  w add: (Grid hsplit: 0.45
               child1: self buildBoardPanel
               child2: self buildChatPanel).
  w open
!
performRobotMessages: messages
  messages do:[:msg | self performArray: msg]
!
placeTiles
  | tile row col x y size |
  1 to: 9 do:[:nr | 
    size := 3.
    tile := tileArray at: nr.
    tile width: canvas actualWidth / size .
    tile height: canvas actualHeight / size .
    row := ((nr - 1) // size) + 1.
    col := ((nr - 1) \\ size) + 1.
    x := canvas actualWidth * (col - 1) / size .
    y := canvas actualHeight * (row - 1) / size .
    Canvas setLeft: tile to: x.
    Canvas setTop: tile to: y]
!
printMessage: aMessage
  textin println: aMessage
!
restart
  tileArray do:[:tile | tile content: ''].
  textin text: ''
!
sendMessageToRobot
  | board |
  board := (tileArray collect: [:x | x content]) asArray.
  json sendData: (Array with: 'O' with: board)
!
Remote subclass: #TicTacToe
instanceVariableNames: 'canvas textin textout jabber user contact tileArray token'
classVariableNames: ''
!
TicTacToe class
!
gtalk: aUser passwd: aPasswd contact: aContact token: anXorO
  ^ super new gtalk: true user: aUser passwd: aPasswd contact: aContact token: anXorO
!
vst: aUser passwd: aPasswd contact: aContact token: anXorO
  ^ super new gtalk: false user: aUser passwd: aPasswd contact: aContact token: anXorO
!
TicTacToe
!
buildBoardPanel
  | dockpanel tile block |
  tileArray := Array new: 9.
  canvas := Canvas new.
  1 to: 9 do: [:i |
    tile := self createButton: i with: token.
    tileArray at: i put: tile.
    canvas add: tile].
  canvas clipToBounds: true.
  canvas addEvent: 'SizeChanged' action: [self placeTiles].
  dockpanel := DockPanel new.
  dockpanel add: canvas.
  ^ dockpanel
!
buildChatPanel
  | button dockpanel grid |
  textin := TextBox new.
  textout := TextBox new.
  grid := Grid vsplit: 0.45 child1: textin child2: textout.
  grid background: Brushes gray.
  dockpanel := DockPanel new.
  button := Button new.
  button content: 'Send'.
  button addEvent: 'Click' action: [self sendText].
  dockpanel add: button.
  DockPanel setDock: button to: Dock bottom.
  dockpanel add: grid.
  ^ dockpanel
!
createButton: anIndex with: aString
   | tile |
   tile := Button new.
   tile addEvent: 'Click' action: [self markTiles: anIndex with: aString].
   ^ tile
!
gtalk: isGtalk user: aUser passwd: aPasswd contact: aContact token: anXorO
  | w |
  Proxy := self.
  user := aUser.
  contact := aContact.
  token := anXorO.
  self login: isGtalk with: aPasswd.
  w := self topWindowClass new.
  w title: 'Tic-Tac-Toe (' + user + ')'.
  w add: (Grid hsplit: 0.45
               child1: self buildBoardPanel
               child2: self buildChatPanel).
  w open
!
login: isGtalk with: aPasswd
  jabber := JabberConnect new: isGtalk.
  jabber user: user; passwd: aPasswd.
  jabber callback: [:array | self performArray: array].
  jabber connect
!
markLocalTile: index with: aString
  | tile |
  tile := tileArray at: index.
  tile content: aString
!
markRemoteTile: index with: aString
  self sendMessage: (Array with: 'markLocalTile:with:' with: index with: aString)
!
markTiles: index with: aString
  self markLocalTile: index with: aString.
  self markRemoteTile: index with: aString
!
placeTiles
  | tile row col x y size |
  1 to: 9 do:[:nr | 
    size := 3.
    tile := tileArray at: nr.
    tile width: canvas actualWidth / size .
    tile height: canvas actualHeight / size .
    row := ((nr - 1) // size) + 1.
    col := ((nr - 1) \\ size) + 1.
    x := canvas actualWidth * (col - 1) / size .
    y := canvas actualHeight * (row - 1) / size .
    Canvas setLeft: tile to: x.
    Canvas setTop: tile to: y]
!
printMessage: aMessage
  textin println: aMessage
!
sendMessage: anArray
  jabber send: contact object: anArray
!
sendText
  self sendMessage: (Array with: 'printMessage:' with: textout text trim).
  textout text: ''
!
Remote subclass: #TmsInspect
instanceVariableNames: ''
classVariableNames: ''
!
TmsInspect class
!
me: tag1 you: tag2
  TmsOut := TmsConnect channel: 'test' name: 'tmsinspect-' + tag2.
  TmsIn := TmsConnect channel: 'test' name: 'tmsinspect-' + tag1 callback:[:x | x inspect].
  TmsIn startPolling: 1.
  Transcript showCr: 'TmsInspect for: ' + tag1
!
stop
  TmsIn stopPolling
!
Remote subclass: #TmsTicTacToe
instanceVariableNames: 'canvas textin textout tmsin tmsout tileArray token'
classVariableNames: ''
!
TmsTicTacToe class
!
token1: mytoken token2: theirtoken
  ^ super new token1: mytoken token2: theirtoken
!
TmsTicTacToe
!
buildBoardPanel
  | dockpanel tile block |
  tileArray := Array new: 9.
  canvas := Canvas new.
  1 to: 9 do: [:i |
    tile := self createButton: i with: token.
    tileArray at: i put: tile.
    canvas add: tile].
  canvas clipToBounds: true.
  canvas addEvent: 'SizeChanged' action: [self placeTiles].
  dockpanel := DockPanel new.
  dockpanel add: canvas.
  ^ dockpanel
!
buildChatPanel
  | button dockpanel grid |
  textin := TextBox new.
  textout := TextBox new.
  grid := Grid vsplit: 0.45 child1: textin child2: textout.
  grid background: Brushes gray.
  dockpanel := DockPanel new.
  button := Button new.
  button content: 'Send'.
  button addEvent: 'Click' action: [self sendText].
  dockpanel add: button.
  DockPanel setDock: button to: Dock bottom.
  dockpanel add: grid.
  ^ dockpanel
!
createButton: anIndex with: aString
   | tile |
   tile := Button new.
   tile addEvent: 'Click' action: [self markTiles: anIndex with: aString].
   ^ tile
!
markLocalTile: index with: aString
  | tile |
  tile := tileArray at: index.
  tile content: aString
!
markRemoteTile: index with: aString
  self sendMessage: (Array with: 'markLocalTile:with:' with: index with: aString)
!
markTiles: index with: aString
  self markLocalTile: index with: aString.
  self markRemoteTile: index with: aString
!
placeTiles
  | tile row col x y size |
  1 to: 9 do:[:nr | 
    size := 3.
    tile := tileArray at: nr.
    tile width: canvas actualWidth / size .
    tile height: canvas actualHeight / size .
    row := ((nr - 1) // size) + 1.
    col := ((nr - 1) \\ size) + 1.
    x := canvas actualWidth * (col - 1) / size .
    y := canvas actualHeight * (row - 1) / size .
    Canvas setLeft: tile to: x.
    Canvas setTop: tile to: y]
!
printMessage: aMessage
  textin println: aMessage
!
sendMessage: anArray
  tmsout send: anArray
!
sendText
  self sendMessage: (Array with: 'printMessage:' with: textout text trim).
  textout text: ''
!
token1: mytoken token2: theirtoken
  | w |
  token := mytoken.
  tmsout := TmsConnect channel: 'test' name: 'tictactoe' + mytoken.
  tmsin := TmsConnect channel: 'test' name: 'tictactoe' + theirtoken
                      callback: [:array | self performArray: array].
  tmsin startPolling: 1.
  w := self topWindowClass new.
  w title: 'Tic-Tac-Toe (' + token + ')'.
  w add: (Grid hsplit: 0.45
               child1: self buildBoardPanel
               child2: self buildChatPanel).
  w open
!
Remote subclass: #TmsXaml
instanceVariableNames: ''
classVariableNames: ''
!
TmsXaml class
!
me: tag1 you: tag2
  TmsOut := TmsConnect channel: 'test' name: 'tmsxaml-' + tag2.
  TmsIn := TmsConnect channel: 'test' name: 'tmsxaml-' + tag1 callback:[:string | self window: string].
  TmsIn startPolling: 1.
  Transcript showCr: 'TmsXaml for: ' + tag1
!
stop
  TmsIn stopPolling
!
window: aString
  | w x |
  w := self topWindowClass new.
  x := XamlUtility xamlFromString: aString decodeBase64.
  x isNil ifFalse: [w add: x].
  w width: 150; height: 150; title: 'Xaml Object'.
  w open
!
UserApps subclass: #Xaml
instanceVariableNames: ''
classVariableNames: ''
!
Xaml subclass: #ColorButtons
instanceVariableNames: 'ellipse'
classVariableNames: ''
!
ColorButtons
!
greenClick
  ellipse fill: Brushes green
!
onWikiResponse: aString
  | btn w x |
  w := self topWindowClass new.
  x := XamlUtility xamlFromString: aString.
  x isNil ifFalse: [w add: x].
  ellipse := x findName: 'Ellipse'.
  btn := x findName: 'Btn01'.
  btn addEvent: 'Click' action: [self redClick].
  btn := x findName: 'Btn02'.
  btn addEvent: 'Click' action: [self greenClick].
  btn := x findName: 'Btn03'.
  btn addEvent: 'Click' action: [self yellowClick].
  w width: 450; height: 250; title: 'Color Buttons'.
  w open
!
open
  self readWiki: 'libraries:xaml:tests:colorbuttons.txt'
        replace: '$$Label$$@Color Buttons:$$Btn01$$@Red:$$Btn02$$@Green:$$Btn03$$@Yellow'
!
redClick
  ellipse fill: Brushes red
!
yellowClick
  ellipse fill: Brushes yellow
!
Xaml subclass: #CombinedXaml
instanceVariableNames: 'border canvas grid'
classVariableNames: ''
!
CombinedXaml
!
addWheel: aRadius x: x
  | center wheel |
  center := Point x: x y: 225 - aRadius.
  wheel := Wheel createWheel: 14 radius: aRadius center: center.
  canvas add: wheel
!
onCanvasResponse: aString
  | x |
  x := XamlUtility xamlFromString: aString.
  canvas := x findName: 'Canvas'.
  x children clear.
  border child: canvas.
  self addWheel: 100 x: 150;
       addWheel:  75 x: 325;
       addWheel:  50 x: 450;
       show
!
onContainerResponse: aString
  grid := XamlUtility xamlFromString: aString.
  border := grid findName: 'Border'.
  self readWiki: 'libraries:xaml:canvases:colorfill.txt'
       callback: [:s | self onCanvasResponse: s]
!
open
  self readWiki: 'libraries:xaml:containers:redcontainer.txt'
        replace: '$$Label$$@Combined Xaml'
       callback: [:s | self onContainerResponse: s]
!
show
  | w |
  w := self topWindowClass new.
  grid isNil ifFalse: [w add: grid].
  w width: 550; height: 350; title: 'Combined Xaml'.
  w open
!
Xaml subclass: #Greetings
instanceVariableNames: 'window'
classVariableNames: ''
!
Greetings
!
onWikiResponse: aString
  | x |
  x := XamlUtility xamlFromString: aString.
  x isNil ifFalse: [window add: x].
  window width: 650; height: 260
!
open
  | panel |
  panel := StackPanel new.
  panel add: (Button content: 'English' callback: [self readWiki: 'libraries:xaml:tests:greetings:english.txt']).
  panel add: (Button content: 'French' callback: [self readWiki: 'libraries:xaml:tests:greetings:french.txt']).
  panel add: (Button content: 'German' callback: [self readWiki: 'libraries:xaml:tests:greetings:german.txt']).
  panel add: (Button content: 'Hungarian' callback: [self readWiki: 'libraries:xaml:tests:greetings:hungarian.txt']).
  panel add: (Button content: 'Italian' callback: [self readWiki: 'libraries:xaml:tests:greetings:italian.txt']).
  panel add: (Button content: 'Spanish' callback: [self readWiki: 'libraries:xaml:tests:greetings:spanish.txt']).
  window := self topWindowClass new.
  window width: 150; height: 170; title: 'Languages Demo'; add: panel; open
!
Xaml subclass: #List2Text
instanceVariableNames: 'border grid inner'
classVariableNames: ''
!
List2Text
!
onContainerResponse: aString
  grid := XamlUtility xamlFromString: aString.
  border := grid findName: 'Border'.
  self readWiki: 'libraries:xaml:combinations:list2text.txt'
       callback: [:s | self onGridResponse: s]
!
onGridResponse: aString
  | x |
  x := XamlUtility xamlFromString: aString.
  inner := x findName: 'InnerGrid'.
  x children clear.
  border child: inner.
  self show
!
open
  self readWiki: 'libraries:xaml:containers:redcontainer.txt'
        replace: '$$Label$$@List2Text'
       callback: [:s | self onContainerResponse: s]
!
show
  | w |
  w := self topWindowClass new.
  grid isNil ifFalse: [w add: grid].
  w width: 550; height: 350; title: 'List2Text Xaml'.
  w open
!
Xaml subclass: #VideoStore2
instanceVariableNames: 'border clientsLb grid inner rentalsLb textbox url'
classVariableNames: ''
!
VideoStore2
!
clientDetail: aString
  | lines |
  lines := aString splitStr: ':'.
  textbox clear.
  lines do: [:line | textbox println: line]
!
clientRentals: aList
  | li |
  rentalsLb clear.
  aList do: [:item |
    li := ListBoxItem new.
    li content: (item at: 1).
    li tag: item.
    rentalsLb items add: li]
!
clientSelection
  | id php |
  clientsLb selectedItem isNil ifTrue:[^nil].
  id := clientsLb selectedItem tag.
  php := PhpConnect new.
  php url: url.
  php callback: [:detail | self clientDetail: detail].
  php serialized: true.
  php queryServer: 'cmd=clientdetail&id=' + id.
  php := PhpConnect new.
  php url: url.
  php callback: [:rentals | self clientRentals: rentals].
  php serialized: true.
  php queryServer: 'cmd=clientrentals&id=' + id
!
onContainerResponse: aString
  grid := XamlUtility xamlFromString: aString.
  border := grid findName: 'Border'.
  self readWiki: 'libraries:xaml:combinations:list2text.txt'
       callback: [:s | self onInnerResponse: s]
!
onInnerResponse: aString
  | top |
  top := XamlUtility xamlFromString: aString.
  inner := top findName: 'InnerGrid'.
  clientsLb := inner findName: 'ListBox01'.
  clientsLb background: (SolidColorBrush new: Color customGreen); foreground: Brushes darkGreen.
  clientsLb addEvent: 'SelectionChanged' action: [self clientSelection].
  rentalsLb := inner findName: 'ListBox02'.
  rentalsLb background: (SolidColorBrush new: Color customBlue); foreground: Brushes darkBlue.
  rentalsLb addEvent: 'SelectionChanged' action: [self rentalSelection].
  textbox := inner findName: 'TextBox01'.
  textbox background: Brushes ivory; foreground: Brushes navy.
  top children clear.
  border child: inner.
  self show
!
open
  url := 'http://vistascript.net/vistascript/webserv/videostore.php'.
  self readWiki: 'libraries:xaml:containers:redcontainer.txt'
        replace: '$$Label$$@Video Store'
       callback: [:s | self onContainerResponse: s]
!
refreshClientList
  | php |
  php := PhpConnect new.
  php url: url.
  php callback: [:list | self refreshClientList: list].
  php serialized: true.
  php queryServer: 'cmd=clientlist'
!
refreshClientList: aList
  | li |
  clientsLb clear.
  aList do: [:item |
    li := ListBoxItem new.
    li content: (item at: 1).
    li tag: (item at: 2).
    clientsLb items add: li]
!
rentalSelection
  | rental |
  rentalsLb selectedItem isNil ifTrue:[^nil].
  rental := rentalsLb selectedItem tag.
  textbox clear.
  rental do:[:item | textbox println: item]
!
show
  | w |
  w := self topWindowClass new.
  grid isNil ifFalse: [w add: grid].
  w width: 550; height: 350; title: 'Video Store'.
  w open.
  self refreshClientList
!
Xaml subclass: #XamlDemo
instanceVariableNames: ''
classVariableNames: ''
!
XamlDemo
!
onWikiResponse: aString
  | w x |
  w := self topWindowClass new.
  x := XamlUtility xamlFromString: aString.
  x isNil ifFalse: [w add: x].
  w width: 550; height: 500; title: 'Xaml Demo'.
  w open
!
open
 self readWiki: 'libraries:xaml:tests:test1.txt'
!
Xaml subclass: #XamlLauncher
instanceVariableNames: ''
classVariableNames: ''
!
XamlLauncher
!
open
  "   XamlLauncher open   "
  | panel w |
  panel := StackPanel new.
  panel add: (Button content: 'ColorButtons' callback: [ColorButtons open]).
  panel add: (Button content: 'CombinedXaml' callback: [CombinedXaml open]).
  panel add: (Button content: 'Greetings' callback: [Greetings open]).
  panel add: (Button content: 'List2Text' callback: [List2Text open]).
  panel add: (Button content: 'VideoStore2' callback: [VideoStore2 open]).
  panel add: (Button content: 'XamlDemo' callback: [XamlDemo open]).
  w := self topWindowClass new.
  w width: 150; height: 170; title: 'Xaml'; add: panel; open
!
Object subclass: #Utility
instanceVariableNames: ''
classVariableNames: ''
!
Utility subclass: #FileUtility
instanceVariableNames: ''
classVariableNames: ''
maps: 'fileutility'
!
FileUtility class
!
readServerFile: aString
  <primitive: 'fileutility readserverfile string'>
!
Utility subclass: #JsonConvert
instanceVariableNames: ''
classVariableNames: ''
maps: 'jsonconvert'
!
JsonConvert class
!
fromJson: aString
  <primitive: 'jsonconvert fromjson string'>
!
toJson: aDictionary
  <primitive: 'jsonconvert tojson idictionary'>
!
Utility subclass: #StringUtility
instanceVariableNames: ''
classVariableNames: ''
maps: 'stringutility'
!
StringUtility class
!
asSmalltalkString: aString
  <primitive: 'stringutility assmalltalkstring string'>
!
base64Decode: aString
  <primitive: 'stringutility base64decode string'>
!
base64Encode: aString
  <primitive: 'stringutility base64encode string'>
!
Utility subclass: #ViewPackager
instanceVariableNames: ''
classVariableNames: ''
maps: 'viewpackager'
!
ViewPackager
!
package
  <primitive: 'viewpackager get_package'>
!
package: anObject
  <primitive: 'viewpackager set_package object'>
!
xaml
  <primitive: 'viewpackager get_xaml'>
!
xaml: aString
  <primitive: 'viewpackager set_xaml string'>
!
Utility subclass: #XamlUtility
instanceVariableNames: ''
classVariableNames: ''
maps: 'xamlutility'
!
XamlUtility class
!
wpfToLisp: aPanel
  <primitive: 'xamlutility wpftolisp panel'>
!
wpfToXaml: aPanel
  <primitive: 'xamlutility wpftoxaml panel'>
!
xamlFromString: aString
  <primitive: 'xamlutility xamlfromstring string'>
!
Utility subclass: #XmlUtility
instanceVariableNames: ''
classVariableNames: ''
maps: 'xmlutility'
!
XmlUtility class
!
childNodes: anXmlElement
  <primitive: 'xmlutility childnodes xmlelement'>
!
Object subclass: #Views
instanceVariableNames: ''
classVariableNames: ''
!
Views subclass: #Android
instanceVariableNames: 'view'
classVariableNames: ''
!
Android class
!
new
 ^ super new init: '<Grid
xmlns="http://schemas.microsoft.com/winfx/2006/xaml/presentation"
xmlns:x="http://schemas.microsoft.com/winfx/2006/xaml"
x:Name="DocumentRoot"
>
<ItemsControl Name="Android" Margin="45,30,0,0" Width="100" Height="100">
<ItemsControl.Template>
<ControlTemplate TargetType="{x:Type ItemsControl }">
<Viewbox>
<Viewbox.Child>
<Canvas Width="100" Height="100" IsItemsHost="True" />
</Viewbox.Child>
</Viewbox>
</ControlTemplate>
</ItemsControl.Template>
<Rectangle
 Name="Body" Margin="32,68,0,0" RadiusX="20" RadiusY="20" Width="70" Height="80" Fill="DarkOrange" Stroke="Black">
</Rectangle>
<Path
 Name="LeftArm" StrokeThickness="7" Margin="0,113,0,0" Stroke="DarkSeaGreen">
<Path.Data>
<LineGeometry
 StartPoint="0,0" EndPoint="28.2842712474619,-28.2842712474619" />
</Path.Data>
</Path>
<Path
 Name="LeftLeg" StrokeThickness="7" Margin="53,197,0,0" Stroke="DarkSeaGreen">
<Path.Data>
<LineGeometry
 StartPoint="0,0" EndPoint="-9.18454765366783E-15,-50" />
</Path.Data>
</Path>
<Ellipse
 Name="LeftShoulder" Margin="26,68,0,0" Width="20" Height="20" Fill="DarkOrange" Stroke="Black">
</Ellipse>
<Path
 Name="RightLeg" StrokeThickness="7" Margin="79,197,0,0" Stroke="DarkSeaGreen">
<Path.Data>
<LineGeometry
 StartPoint="0,0" EndPoint="-9.18454765366783E-15,-50" />
</Path.Data>
</Path>
<Ellipse
 Name="RightShoulder" Margin="86,67,0,0" Width="20" Height="20" Fill="DarkOrange" Stroke="Black">
</Ellipse>
<Ellipse
 Name="Head" Margin="41,0,0,0" Width="50" Height="50" Fill="PowderBlue" Stroke="Black">
</Ellipse>
<Path
 Name="Neck" StrokeThickness="10" Margin="66,68,0,0" Fill="Silver" Stroke="DarkSeaGreen">
<Path.Data>
<LineGeometry
 StartPoint="0,0" EndPoint="-3.30643715532042E-15,-18" />
</Path.Data>
</Path>
<Path
 Name="RightArm" StrokeThickness="7" Margin="104,83,0,0" Stroke="DarkSeaGreen">
<Path.Data>
<LineGeometry
 StartPoint="0,0" EndPoint="28.2842712474619,28.2842712474619" />
</Path.Data>
</Path>
</ItemsControl>
</Grid>
'
!
open
  | v w |
  v := self new.
  w := OnePane new.
  w pane: v view.
  w open.
  ^ v
!
player
  ^ self new android
!
Android
!
android
 ^ self view findAndRemove: 'Android'
!
elementMoved: elementMovedArgs
 | name x y |
 name := elementMovedArgs name.
 x := elementMovedArgs x.
 y := elementMovedArgs y.
 Transcript showCr: name + ' moved to ' + x + ' ' + y
!
init: aXamlString
 view := View new.
 view designMode: false.
 view packager xaml: aXamlString.
 view setDraggable: self android to: true.
 view addEvent: 'ElementMoved' action: [:x | self elementMoved: x].
!
view
 ^ view
!
Object subclass: #Widgets
instanceVariableNames: ''
classVariableNames: ''
!
Widgets subclass: #Desktop
instanceVariableNames: ''
classVariableNames: ''
!
Widgets subclass: #Layouts
instanceVariableNames: 'pane window'
classVariableNames: ''
!
Layouts class
!
defaultTitle
  ^ self printString
!
new
  | w |
  w := super new init.
  ^ w
!
new: aPane
  | w |
  w := self new.
  w pane: aPane.
  ^ w
!
open
  ^ self new open
!
openOn: aPane
  | w |
  w := self new: aPane.
  w open.
  ^ w
!
Layouts
!
color: aColor
  window color: aColor
!
init
  window := self topWindowClass new.
  window title: self class defaultTitle
!
open
  window open
!
pane
  ^ pane
!
pane: aPane
  pane := aPane.
  window add: pane
!
title
  ^ window title
!
title: aString
  window title: aString
!
Layouts subclass: #CalmoSoftLayouts
instanceVariableNames: ''
classVariableNames: ''
!
CalmoSoftLayouts class
!
copyright
   "   ~  written by: Gal Zsolt & Cathlyn Cosca ( CalmoSoft ) ~ 2006-2007 ~ calmosoft@gmail.com ~   "
!
CalmoSoftLayouts subclass: #MethodFinderandSystemBrowserLayout
instanceVariableNames: 'dockpanel dockpanel2 methodTextEditor searchText treeLeft typeText'
classVariableNames: ''
!
MethodFinderandSystemBrowserLayout class
!
copyright
   "   ~  written by: Gal Zsolt & Cathlyn Cosca ( CalmoSoft ) ~ 2006-2007 ~ calmosoft@gmail.com ~   "
!
MethodFinderandSystemBrowserLayout
!
dockpanel
  ^dockpanel
!
dockpanel2
  ^dockpanel2
!
init
  | top1 top2 top3 top4 |
  super init.
  treeLeft := TreeView new.
  methodTextEditor := TextEditor new.
  typeText := TextBox new.
  searchText := TextBox new.
  dockpanel := DockPanel new.
  dockpanel2 := DockPanel new.
  top1 := Grid hsplit: 0.385 child1: typeText child2: dockpanel.
  top2 := Grid vsplit: 0.500 child1: searchText child2: top1.
  top3 := Grid hsplit: 0.100 child1: dockpanel2 child2: treeLeft.
  top4 := Grid vsplit: 0.080 child1: top2 child2: top3.
  self pane: (Grid hsplit: 0.370 child1: top4 child2: methodTextEditor)
!
methodTextEditor
  ^methodTextEditor
!
searchText
  ^searchText
!
treeLeft
  ^treeLeft
!
typeText
  ^typeText
!
CalmoSoftLayouts subclass: #PowerBrowserLayout
instanceVariableNames: 'dockpanel dockpanel2 dockpanel3 tabcontrol tabcontrolBottom tabcontrolRight textboxLineBottom textboxLineTop treeviewLeft treeviewRight'
classVariableNames: ''
!
PowerBrowserLayout class
!
copyright
   "   ~  written by: Gal Zsolt & Cathlyn Cosca ( CalmoSoft ) ~ 2006-2007 ~ calmosoft@gmail.com ~   "
!
PowerBrowserLayout
!
dockpanel
  ^ dockpanel
!
dockpanel2
  ^ dockpanel2
!
dockpanel3
  ^ dockpanel3
!
init
  | bottom bottom2 bottom3 bottom4 bottom5 bottomRight topLeft topLeft2 topRight |
  super init.
  treeviewLeft := TreeView new.
  treeviewRight := TreeView new.
  tabcontrol := TabControl new.
  tabcontrolRight := TabControl new.
  tabcontrolBottom := TabControl new.
  textboxLineTop := TextBox new.
  textboxLineBottom := TextBox new.
  dockpanel := DockPanel new.
  dockpanel2 := DockPanel new.
  dockpanel3 := DockPanel new.
  topLeft := Grid hsplit: 0.5 child1: treeviewLeft child2: tabcontrol.
  topLeft2 := Grid hsplit: 0.66 child1: topLeft child2: tabcontrolRight.
  topRight := Grid hsplit: 0.75 child1: topLeft2 child2: treeviewRight.
  bottom := Grid vsplit: 0.89 child1: topRight child2: textboxLineTop. 
  bottom2 := Grid vsplit: 0.89 child1: bottom child2: dockpanel. 
  bottom3 := Grid vsplit: 0.38 child1: bottom2 child2: tabcontrolBottom. 
  bottom4 := Grid hsplit: 0.97 child1: bottom3 child2: dockpanel3. 
  bottom5 := Grid vsplit: 0.96 child1: bottom4 child2: dockpanel2. 
  self pane: (Grid vsplit: 0.965 child1: bottom5 child2: textboxLineBottom)
!
tabcontrol
  ^ tabcontrol
!
tabcontrolBottom
  ^ tabcontrolBottom
!
tabcontrolRight
  ^ tabcontrolRight
!
textboxLineBottom
  ^ textboxLineBottom
!
textboxLineTop
  ^ textboxLineTop
!
treeviewLeft
  ^ treeviewLeft
!
treeviewRight
  ^ treeviewRight
!
CalmoSoftLayouts subclass: #PowerObjectsLayout
instanceVariableNames: 'editorbox listbox'
classVariableNames: ''
!
PowerObjectsLayout class
!
copyright
   "   ~  written by: Gal Zsolt & Cathlyn Cosca ( CalmoSoft ) ~ 2006-2007 ~ calmosoft@gmail.com ~   "
!
PowerObjectsLayout
!
editorbox
  ^ editorbox
!
init
  super init.
  listbox := ListBox new.
  editorbox := TextEditor new.
  self pane: (Grid hsplit: 0.14 child1: listbox child2: editorbox)
!
listbox
  ^ listbox
!
Layouts subclass: #OnePane
instanceVariableNames: ''
classVariableNames: ''
!
OnePane subclass: #OnePaneDesigner
instanceVariableNames: ''
classVariableNames: ''
!
OnePaneDesigner
!
init
  super init.
  self pane: Designer new
!
OnePane subclass: #OnePaneText
instanceVariableNames: ''
classVariableNames: ''
!
OnePaneText
!
init
  super init.
  self pane: TextBox new
!
text
  ^ pane text
!
text: aString
  pane text: aString
!
OnePane subclass: #OnePaneTextEditor
instanceVariableNames: ''
classVariableNames: ''
!
OnePaneTextEditor
!
init
  super init.
  self pane: TextEditor new
!
Layouts subclass: #ThreePane
instanceVariableNames: ''
classVariableNames: ''
!
ThreePane subclass: #ThreePaneTreeTabEditor
instanceVariableNames: 'treeview tabcontrol textbox'
classVariableNames: ''
!
ThreePaneTreeTabEditor
!
init
  | top |
  super init.
  treeview := TreeView new.
  tabcontrol := TabControl new.
  textbox := TextEditor new.
  top := Grid hsplit: 0.45 child1: treeview child2: tabcontrol.
  self pane: (Grid vsplit: 0.5 child1: top child2: textbox)
!
tabcontrol
  ^ tabcontrol
!
textbox
  ^ textbox
!
treeview
  ^ treeview
!
ThreePane subclass: #ThreePaneTreeTabText
instanceVariableNames: 'treeview tabcontrol textbox'
classVariableNames: ''
!
ThreePaneTreeTabText
!
init
  | top |
  super init.
  treeview := TreeView new.
  tabcontrol := TabControl new.
  textbox := TextBox new.
  top := Grid hsplit: 0.45 child1: treeview child2: tabcontrol.
  self pane: (Grid vsplit: 0.5 child1: top child2: textbox)
!
tabcontrol
  ^ tabcontrol
!
textbox
  ^ textbox
!
treeview
  ^ treeview
!
Layouts subclass: #TwoPane
instanceVariableNames: ''
classVariableNames: ''
!
TwoPane subclass: #TwoPaneListText
instanceVariableNames: 'listbox textbox'
classVariableNames: ''
!
TwoPaneListText
!
init
  super init.
  listbox := ListBox new.
  textbox := TextBox new.
  self pane: (Grid hsplit: 0.45 child1: listbox child2: textbox)
!
listbox
  ^ listbox
!
textbox
  ^ textbox
!
Object subclass: #WinFx
instanceVariableNames: ''
classVariableNames: ''
!
WinFx subclass: #Char
instanceVariableNames: ''
classVariableNames: ''
maps: 'char'
!
Char class
!
isUpper: aChar
  <primitive: 'char isupper char'>
!
Char
!
isUpper
  ^ self class isUpper: self
!
WinFx subclass: #Clipboard
instanceVariableNames: ''
classVariableNames: ''
maps: 'clipboard'
!
Clipboard class
!
clear
  <primitive: 'clipboard clear'>
!
getText
  <primitive: 'clipboard gettext'>
!
setText: aString
  <primitive: 'clipboard settext string'>
!
WinFx subclass: #Convert
instanceVariableNames: ''
classVariableNames: ''
maps: 'convert'
!
Convert class
!
toSingle: anObject
  <primitive: 'convert tosingle object'>
!
WinFx subclass: #DateTime
instanceVariableNames: ''
classVariableNames: ''
maps: 'datetime'
!
DateTime class
!
now
  <primitive: 'datetime get_now'>
!
WinFx subclass: #Encoding
instanceVariableNames: ''
classVariableNames: ''
maps: 'encoding'
!
Encoding class
!
ascii
  <primitive: 'encoding get_ascii'>
!
getBytes: aString
  <primitive: 'encoding getbytes string'>
!
WinFx subclass: #Environment
instanceVariableNames: ''
classVariableNames: ''
maps: 'environment'
!
Environment class
!
newline
  <primitive: 'environment get_newline'>
!
WinFx subclass: #GC
instanceVariableNames: ''
classVariableNames: ''
maps: 'gc'
!
GC class
!
getTotalMemory: aBoolean
  <primitive: 'gc gettotalmemory bool'>
!
WinFx subclass: #Math
instanceVariableNames: ''
classVariableNames: ''
maps: 'math'
!
Math class
!
cos: aDouble
  <primitive: 'math cos double'>
!
e
  <primitive: 'math e'>
!
pi
  <primitive: 'math pi'>
!
round: aDouble
  <primitive: 'math round double'>
!
sin: aDouble
  <primitive: 'math sin double'>
!
tan: aDouble
  "Answer the tangent of the receiver taken as an angle in radians."
  ^(Math sin: aDouble) / (Math cos: aDouble)
!
WinFx subclass: #Random
instanceVariableNames: ''
classVariableNames: ''
maps: 'random'
!
Random class
!
new
  <primitive: 'random .ctor'>
!
Random
!
next
  <primitive: 'random next'>
!
nextMax: anInt
  <primitive: 'random next int'>
!
nextMin: aInt1 max: anInt2
  <primitive: 'random next int int'>
!
WinFx subclass: #String
instanceVariableNames: ''
classVariableNames: ''
maps: 'string'
!
String
!
+ aString
   ^ self concatPrim: self with: aString
!
= anObject
   ^ self equals: anObject
!
asString
   ^ self
!
asSymbol
   ^ Symbol intern: self
!
at: anIndex
   <primitive: 'string get_chars int'>
!
clone
   <primitive: 'string clone'>
!
compareTo: aString
   <primitive: 'string compareto string'>
!
concat: aString
   ^ self concatPrim: self with: aString
!
concat: aString1 with: aString2
   ^ self concatPrim: self with: aString1 with: aString2
!
concatPrim: aString1 with: aString2
   <primitive: 'string concat string string'>
!
concatPrim: aString1 with: aString2 with: aString3
   <primitive: 'string concat string string string'>
!
countOf: aString
   | count index start |
   count := 0.
   index := 0.
   start := 0.
   [index >= 0] whileTrue: [
      index := self indexOf: aString start: start.
      index >= 0 ifTrue: [count := count + 1].
      start := index + 1].
   ^ count
!
decodeBase64
  ^ StringUtility base64Decode: self
!
encodeBase64
  ^ StringUtility base64Encode: self
!
endsWith: aString
   <primitive: 'string endswith string'>
!
eval
   ^ Vm eval: self
!
evalInline
   ^ Vm evalInline: self
!
getEnumerator
   <primitive: 'string getenumerator'>
!
getHashCode
   <primitive: 'string gethashCode'>
!
getTypeCode
   <primitive: 'string gettypecode'>
!
indexOf: aString
   <primitive: 'string indexof string'>
!
indexOf: aString start: anInteger
   <primitive: 'string indexof string int'>
!
indexOf: aString start: aStart len: aLength
   <primitive: 'string indexof string int int'>
!
indexOfAny: chars start: aStart len: aLength
   <primitive: 'string indexof char[] int int'>
!
insertAt: anIndex string: aString
   <primitive: 'string insert int string'>
!
intern
  ^ Symbol intern: self
!
isString
   ^ true
!
lastIndexOf: aString
   <primitive: 'string lastindexof string'>
!
lastIndexOfAny: chars start: anIndex len: aLength
   <primitive: 'string lastindexofany char[] int int'>
!
length
   <primitive: 'string get_length'>
!
padLeft: aCount withChar: aChar
   <primitive: 'string padleft int char'>
!
padRight: aCount withChar: aChar
   <primitive: 'string padright int char'>
!
printString
   ^ StringUtility asSmalltalkString: self
!
remove: startIndex count: count
   <primitive: 'string remove int int'>
!
replace: aString1 with: aString2
   <primitive: 'string replace string string'>
!
size
   ^ self length
!
split: aCharArray
   <primitive: 'string split char[]'>
!
split: aCharArray start: anIndex
   <primitive: 'string split char[] int'>
!
splitStr: aString
   ^ self split: aString toCharArray
!
startsWith: aString
   <primitive: 'string startswith string'>
!
stringEquals: aString
   <primitive: 'string equals string'>
!
substring: anIndex
   <primitive: 'string substring int'>
!
substring: anIndex len: aLength
   <primitive: 'string substring int int'>
!
toCharArray
   <primitive: 'string tochararray'>
!
toCharArray: anIndex len: aLength
   <primitive: 'string tochararray int int'>
!
toLower
   <primitive: 'string tolower'>
!
toString
   ^ self
!
toUpper
   <primitive: 'string toupper'>
!
trim
   <primitive: 'string trim'>
!
trimEnd: aCharArray
   <primitive: 'string trimend char[]'>
!
trimStart: aCharArray
   <primitive: 'string trimstart char[]'>
!
WinFx subclass: #Uri
instanceVariableNames: ''
classVariableNames: ''
maps: 'uri'
!
Uri class
!
new: aString
  <primitive: 'uri .ctor string'>
!
WinFx subclass: #WfControl
instanceVariableNames: ''
classVariableNames: ''
maps: 'wfcontrol'
!
WfControl
!
dock
  <primitive: 'wfcontrol get_dock'>
!
dock: aDockStyle
  <primitive: 'wfcontrol set_dock wfdockstyle'>
!
WfControl subclass: #WebBrowserBase
instanceVariableNames: ''
classVariableNames: ''
maps: 'webbrowserbase'
!
WebBrowserBase subclass: #WebBrowser
instanceVariableNames: ''
classVariableNames: ''
maps: 'webbrowser'
!
WebBrowser class
!
new
  <primitive: 'webbrowser .ctor'>
!
WebBrowser
!
navigate: aString
  <primitive: 'webbrowser navigate string'>
!
Object subclass: #Wpf
instanceVariableNames: ''
classVariableNames: ''
!
Wpf subclass: #Brushes
instanceVariableNames: ''
classVariableNames: ''
maps: 'brushes'
!
Brushes class
!
aliceBlue
  <primitive: 'brushes get_aliceblue'>
!
black
  <primitive: 'brushes get_black'>
!
blue
  <primitive: 'brushes get_blue'>
!
cadetBlue
  <primitive: 'brushes get_cadetblue'>
!
darkBlue
  <primitive: 'brushes get_darkblue'>
!
darkGreen
  <primitive: 'brushes get_darkgreen'>
!
darkOrange
  <primitive: 'brushes get_darkorange'>
!
fireBrick
  <primitive: 'brushes get_firebrick'>
!
gray
  <primitive: 'brushes get_gray'>
!
green
  <primitive: 'brushes get_green'>
!
ivory
  <primitive: 'brushes get_ivory'>
!
lightGray
  <primitive: 'brushes get_lightgray'>
!
navy
  <primitive: 'brushes get_navy'>
!
red
  <primitive: 'brushes get_red'>
!
transparent
  <primitive: 'brushes get_transparent'>
!
yellow
  <primitive: 'brushes get_yellow'>
!
Wpf subclass: #Color
instanceVariableNames: ''
classVariableNames: ''
maps: 'color'
!
Color class
!
customBlue
  ^self fromSc: 1 r: 0.89 g: 0.89 b: 1
!
customDarkGray
  ^self fromSc: 1 r: 0.06 g: 0.06 b: 0.06
!
customGray
  ^self fromSc: 1 r: 0.8 g: 0.8 b: 0.8
!
customGreen
  ^self fromSc: 1 r: 0.89 g: 1 b: 0.89
!
customOrange
  ^self fromSc: 1 r: 0.76 g: 0.28 b: 0
!
fromSc: sc r: red g: green b: blue
  ^ Color fromScPrim: sc asFloat r: red asFloat g: green asFloat b: blue asFloat
!
fromScPrim: scFloat r: redFloat g: greenFloat b: blueFloat
  <primitive: 'color fromscrgb float float float float'>
!
Wpf subclass: #Colors
instanceVariableNames: ''
classVariableNames: ''
maps: 'colors'
!
Colors class
!
aliceBlue
  <primitive: 'colors get_aliceblue'>
!
antiqueWhite
  <primitive: 'colors get_antiquewhite'>
!
bisque
  <primitive: 'colors get_bisque'>
!
black
  <primitive: 'colors get_black'>
!
blue
  <primitive: 'colors get_blue'>
!
blueViolet
  <primitive: 'colors get_blueviolet'>
!
burlyWood
  <primitive: 'colors get_burlywood'>
!
chocolate
  <primitive: 'colors get_chocolate'>
!
darkBlue
  <primitive: 'colors get_darkblue'>
!
darkCyan
  <primitive: 'colors get_darkcyan'>
!
darkGoldenrod
  <primitive: 'colors get_darkgoldenrod'>
!
darkGray
  <primitive: 'colors get_darkgray'>
!
darkGreen
  <primitive: 'colors get_darkgreen'>
!
darkKhaki
  <primitive: 'colors get_darkkhaki'>
!
darkMagenta
  <primitive: 'colors get_darkmagenta'>
!
darkOliveGreen
  <primitive: 'colors get_darkolivegreen'>
!
darkOrange
  <primitive: 'colors get_darkorange'>
!
darkOrchid
  <primitive: 'colors get_darkorchid'>
!
darkRed
  <primitive: 'colors get_darkred'>
!
darkSalmon
  <primitive: 'colors get_darksalmon'>
!
darkSeaGreen
  <primitive: 'colors get_darkseagreen'>
!
darkSlateBlue
  <primitive: 'colors get_darkslateblue'>
!
darkSlateGray
  <primitive: 'colors get_darkslategray'>
!
darkTurquoise
  <primitive: 'colors get_darkturquoise'>
!
darkViolet
  <primitive: 'colors get_darkviolet'>
!
deepPink
  <primitive: 'colors get_deeppink'>
!
deepSkyBlue
  <primitive: 'colors get_deepskyblue'>
!
firebrick
  <primitive: 'colors get_firebrick'>
!
gold
  <primitive: 'colors get_gold'>
!
gray
  <primitive: 'colors get_gray'>
!
green
  <primitive: 'colors get_green'>
!
indigo
  <primitive: 'colors get_indigo'>
!
ivory
  <primitive: 'colors get_ivory'>
!
lime
  <primitive: 'colors get_lime'>
!
maroon
  <primitive: 'colors get_maroon'>
!
navy
  <primitive: 'colors get_navy'>
!
oliveDrab
  <primitive: 'colors get_olivedrab'>
!
orange
  <primitive: 'colors get_orange'>
!
paleGreen
  <primitive: 'colors get_palegreen'>
!
purple
  <primitive: 'colors get_purple'>
!
red
  <primitive: 'colors get_red'>
!
silver
  <primitive: 'colors get_silver'>
!
slateBlue
  <primitive: 'colors get_slateBlue'>
!
slateGray
  <primitive: 'colors get_slategray'>
!
tan
  <primitive: 'colors get_tan'>
!
tomato
  <primitive: 'colors get_tomato'>
!
violet
  <primitive: 'colors get_violet'>
!
white
  <primitive: 'colors get_white'>
!
whiteSmoke
  <primitive: 'colors get_whitesmoke'>
!
Wpf subclass: #ColumnDefinitionCollection
instanceVariableNames: ''
classVariableNames: ''
maps: 'columndefinitioncollection'
!
ColumnDefinitionCollection
!
add: aColumnDefinition
  <primitive: 'columndefinitioncollection add columndefinition'>
!
Wpf subclass: #DispatcherObject
instanceVariableNames: ''
classVariableNames: ''
maps: 'dispatcherobject'
!
DispatcherObject subclass: #Clock
instanceVariableNames: ''
classVariableNames: ''
maps: 'clock'
!
Clock subclass: #AnimationClock
instanceVariableNames: ''
classVariableNames: ''
maps: 'animationclock'
!
DispatcherObject subclass: #DependencyObject
instanceVariableNames: ''
classVariableNames: ''
maps: 'dependencyobject'
!
DependencyObject subclass: #ContentElement
instanceVariableNames: ''
classVariableNames: ''
maps: 'contentelement'
!
ContentElement subclass: #FrameworkContentElement
instanceVariableNames: ''
classVariableNames: ''
maps: 'frameworkcontentelement'
!
FrameworkContentElement subclass: #DefinitionBase
instanceVariableNames: ''
classVariableNames: ''
maps: 'definitionbase'
!
DefinitionBase subclass: #ColumnDefinition
instanceVariableNames: ''
classVariableNames: ''
maps: 'columndefinition'
!
ColumnDefinition class
!
new
  <primitive: 'columndefinition .ctor'>
!
star: aDouble
  | def |
  def := self new.
  def width: (GridLength star: aDouble).
  ^ def
!
ColumnDefinition
!
width
  <primitive: 'columndefinition get_width'>
!
width: aGridLength
  <primitive: 'columndefinition set_width gridlength'>
!
DefinitionBase subclass: #RowDefinition
instanceVariableNames: ''
classVariableNames: ''
maps: 'rowdefinition'
!
RowDefinition class
!
new
  <primitive: 'rowdefinition .ctor'>
!
star: aDouble
  | def |
  def := self new.
  def height: (GridLength star: aDouble).
  ^ def
!
RowDefinition
!
height
  <primitive: 'rowdefinition get_height'>
!
height: aGridLength
  <primitive: 'rowdefinition set_height gridlength'>
!
DependencyObject subclass: #Freezable
instanceVariableNames: ''
classVariableNames: ''
maps: 'freezable'
!
Freezable subclass: #Animatible
instanceVariableNames: ''
classVariableNames: ''
!
Animatible subclass: #Brush
instanceVariableNames: ''
classVariableNames: ''
maps: 'brush'
!
Brush subclass: #LinearGradientBrush
instanceVariableNames: ''
classVariableNames: ''
maps: 'lineargradientbrush'
!
LinearGradientBrush class
!
color1: color1 color2: color2 angle: aDouble
  <primitive: 'lineargradientbrush .ctor color color double'>
!
Brush subclass: #SolidColorBrush
instanceVariableNames: ''
classVariableNames: ''
maps: 'solidcolorbrush'
!
SolidColorBrush class
!
new: aColor
  <primitive: 'solidcolorbrush .ctor color'>
!
Animatible subclass: #Drawing
instanceVariableNames: ''
classVariableNames: ''
maps: 'drawing'
!
Drawing subclass: #DrawingGroup
instanceVariableNames: ''
classVariableNames: ''
maps: 'drawinggroup'
!
Animatible subclass: #GeneralTransform
instanceVariableNames: ''
classVariableNames: ''
maps: 'generaltransform'
!
GeneralTransform subclass: #Transform
instanceVariableNames: ''
classVariableNames: ''
maps: 'transform'
!
Transform class
!
identity
  <primitive: 'transform get_identity'>
!
parse: aString
  <primitive: 'transform parse string'>
!
Transform subclass: #MatrixTransform
instanceVariableNames: ''
classVariableNames: ''
maps: 'matrixtransform'
!
MatrixTransform class
!
new
  <primitive: 'matrixtransform .ctor'>
!
MatrixTransform
!
matrix
  <primitive: 'matrixtransform get_matrix'>
!
matrix: aMatrix
  <primitive: 'matrixtransform set_matrix matrix'>
!
Transform subclass: #RotateTransform
instanceVariableNames: ''
classVariableNames: ''
maps: 'rotatetransform'
!
RotateTransform class
!
angleProperty
  <primitive: 'rotatetransform angleproperty'>
!
new
  <primitive: 'rotatetransform .ctor'>
!
new: anAngle
  <primitive: 'rotatetransform .ctor double'>
!
RotateTransform
!
angle
  <primitive: 'rotatetransform get_angle'>
!
angle: aDouble
  <primitive: 'rotatetransform set_angle double'>
!
centerX
  <primitive: 'rotatetransform get_centerx'>
!
centerX: aDouble
  <primitive: 'rotatetransform set_centerx double'>
!
centerY
  <primitive: 'rotatetransform get_centery'>
!
centerY: aDouble
  <primitive: 'rotatetransform set_centery double'>
!
Transform subclass: #ScaleTransform
instanceVariableNames: ''
classVariableNames: ''
maps: 'scaletransform'
!
ScaleTransform class
!
new
  <primitive: 'scaletransform .ctor'>
!
ScaleTransform
!
scaleX
  <primitive: 'scaletransform get_scalex'>
!
scaleX: aDouble
  <primitive: 'scaletransform set_scalex double'>
!
scaleY
  <primitive: 'scaletransform get_scaley'>
!
scaleY: aDouble
  <primitive: 'scaletransform set_scaley double'>
!
Transform subclass: #SkewTransform
instanceVariableNames: ''
classVariableNames: ''
maps: 'skewtransform'
!
SkewTransform class
!
new
  <primitive: 'skewtransform .ctor'>
!
SkewTransform
!
angleX
  <primitive: 'skewtransform get_anglex'>
!
angleX: aDouble
  <primitive: 'skewtransform set_anglex double'>
!
angleY
  <primitive: 'skewtransform get_angley'>
!
angleY: aDouble
  <primitive: 'skewtransform set_angley double'>
!
Transform subclass: #TranslateTransform
instanceVariableNames: ''
classVariableNames: ''
maps: 'translatetransform'
!
TranslateTransform class
!
new
  <primitive: 'translatetransform .ctor'>
!
newX: aDouble1 y: aDouble2
  <primitive: 'translatetransform .ctor double double'>
!
TranslateTransform
!
x
  <primitive: 'translatetransform get_x'>
!
x: aDouble
  <primitive: 'translatetransform set_x double'>
!
y
  <primitive: 'translatetransform get_y'>
!
y: aDouble
  <primitive: 'translatetransform set_y double'>
!
Animatible subclass: #Geometry
instanceVariableNames: ''
classVariableNames: ''
maps: 'geometry'
!
Geometry class
!
parse: aString
  <primitive: 'geometry parse string'>
!
Geometry subclass: #CombinedGeometry
instanceVariableNames: ''
classVariableNames: ''
maps: 'combinedgeometry'
!
Geometry subclass: #EllipseGeometry
instanceVariableNames: ''
classVariableNames: ''
maps: 'ellipsegeometry'
!
EllipseGeometry class
!
center: aPoint radius: aDouble
  | g |
  g := self new.
  g radiusX: aDouble; radiusY: aDouble; center: aPoint.
  ^ g
!
new
  <primitive: 'ellipsegeometry .ctor'>
!
x: aDouble1 y: aDouble2
  | g |
  g := self new.
  g radiusX: aDouble1; radiusY: aDouble2.
  ^ g
!
EllipseGeometry
!
center
  <primitive: 'ellipsegeometry get_center'>
!
center: aPoint
  <primitive: 'ellipsegeometry set_center point'>
!
radiusX
  <primitive: 'ellipsegeometry get_radiusx'>
!
radiusX: aDouble
  <primitive: 'ellipsegeometry set_radiusx double'>
!
radiusY
  <primitive: 'ellipsegeometry get_radiusy'>
!
radiusY: aDouble
  <primitive: 'ellipsegeometry set_radiusy double'>
!
Geometry subclass: #GeometryGroup
instanceVariableNames: ''
classVariableNames: ''
maps: 'geometrygroup'
!
GeometryGroup class
!
new
  <primitive: 'geometrygroup .ctor'>
!
GeometryGroup
!
add: aGeometry
  self children add: aGeometry
!
children
  <primitive: 'geometrygroup get_children'>
!
Geometry subclass: #LineGeometry
instanceVariableNames: ''
classVariableNames: ''
maps: 'linegeometry'
!
LineGeometry class
!
start: aPoint1 end: aPoint2
  <primitive: 'linegeometry .ctor point point'>
!
LineGeometry
!
endPoint
  <primitive: 'linegeometry get_endpoint'>
!
endPoint: aPoint
  <primitive: 'linegeometry set_endpoint point'>
!
startPoint
  <primitive: 'linegeometry get_startpoint'>
!
startPoint: aPoint
  <primitive: 'linegeometry set_startpoint point'>
!
Geometry subclass: #PathGeometry
instanceVariableNames: ''
classVariableNames: ''
maps: 'pathgeometry'
!
Geometry subclass: #RectangleGeometry
instanceVariableNames: ''
classVariableNames: ''
maps: 'rectanglegeometry'
!
Geometry subclass: #StreamGeometry
instanceVariableNames: ''
classVariableNames: ''
maps: 'streamgeometry'
!
Animatible subclass: #Geometry3D
instanceVariableNames: ''
classVariableNames: ''
maps: 'geometry3d'
!
Geometry3D subclass: #MeshGeometry3D
instanceVariableNames: ''
classVariableNames: ''
maps: 'meshgeometry3d'
!
MeshGeometry3D class
!
new
  <primitive: 'meshgeometry3d .ctor'>
!
MeshGeometry3D
!
normals
  <primitive: 'meshgeometry3d get_normals'>
!
normals: aVector3DCollection
  <primitive: 'meshgeometry3d set_normals vector3dcollection'>
!
positions
  <primitive: 'meshgeometry3d get_positions'>
!
positions: aPoint3DCollection
  <primitive: 'meshgeometry3d set_positions point3dcollection'>
!
textureCoordinates
  <primitive: 'meshgeometry3d get_texturecoordinates'>
!
textureCoordinates: aPoint3DCollection
  <primitive: 'meshgeometry3d set_texturecoordinates pointcollection'>
!
triangleIndices
  <primitive: 'meshgeometry3d get_triangleindices'>
!
triangleIndices: aPoint3DCollection
  <primitive: 'meshgeometry3d set_triangleindices int32collection'>
!
Animatible subclass: #GeometryCollection
instanceVariableNames: ''
classVariableNames: ''
maps: 'geometrycollection'
!
GeometryCollection
!
add: aGeometry
  <primitive: 'geometrycollection add geometry'>
!
at: anInteger
  <primitive: 'geometrycollection get_item int'>
!
at: anInteger put: aGeometry
  <primitive: 'geometrycollection set_item int geometry'>
!
clear
  <primitive: 'geometrycollection clear'>
!
count
  <primitive: 'geometrycollection get_count'>
!
Animatible subclass: #Material
instanceVariableNames: ''
classVariableNames: ''
maps: 'material'
!
Material subclass: #DiffuseMaterial
instanceVariableNames: ''
classVariableNames: ''
maps: 'diffusematerial'
!
DiffuseMaterial class
!
new
  <primitive: 'diffusematerial .ctor'>
!
DiffuseMaterial
!
brush
  <primitive: 'diffusematerial get_brush'>
!
brush: aBrush
  <primitive: 'diffusematerial set_brush brush'>
!
Animatible subclass: #Model3D
instanceVariableNames: ''
classVariableNames: ''
maps: 'model3d'
!
Model3D subclass: #GeometryModel3D
instanceVariableNames: ''
classVariableNames: ''
maps: 'geometrymodel3d'
!
GeometryModel3D class
!
new
  <primitive: 'geometrymodel3d .ctor'>
!
GeometryModel3D
!
geometry
  <primitive: 'geometrymodel3d get_geometry'>
!
geometry: aVector3DCollection
  <primitive: 'geometrymodel3d set_geometry geometry3d'>
!
material
  <primitive: 'geometrymodel3d get_material'>
!
material: aMaterial
  <primitive: 'geometrymodel3d set_material material'>
!
Model3D subclass: #Model3DGroup
instanceVariableNames: ''
classVariableNames: ''
maps: 'model3dgroup'
!
Model3DGroup class
!
new
  <primitive: 'model3dgroup .ctor'>
!
Animatible subclass: #Timeline
instanceVariableNames: ''
classVariableNames: ''
maps: 'timeline'
!
Timeline subclass: #AnimationTimeline
instanceVariableNames: ''
classVariableNames: ''
maps: 'animationtimeline'
!
AnimationTimeline subclass: #DoubleAnimationBase
instanceVariableNames: ''
classVariableNames: ''
maps: 'doubleanimationbase'
!
DoubleAnimationBase subclass: #DoubleAnimation
instanceVariableNames: ''
classVariableNames: ''
maps: 'doubleanimation'
!
DoubleAnimation class
!
from: aDouble1 to: aDouble2 duration: aDuration
  <primitive: 'doubleanimation .ctor double double duration'>
!
new
  <primitive: 'doubleanimation .ctor'>
!
DoubleAnimation
!
duration
  <primitive: 'doubleanimation get_duration'>
!
duration: aDuration
  <primitive: 'doubleanimation set_duration duration'>
!
from
  <primitive: 'doubleanimation get_from'>
!
from: aDouble
  <primitive: 'doubleanimation set_from double'>
!
getValue: aDependencyProperty
  <primitive: 'doubleanimation getvalue dependencyproperty'>
!
setValue: aDependencyProperty to: anObject
  <primitive: 'doubleanimation setvalue dependencyproperty object'>
!
to
  <primitive: 'doubleanimation get_to'>
!
to: aDouble
  <primitive: 'doubleanimation set_to double'>
!
AnimationTimeline subclass: #PointAnimationBase
instanceVariableNames: ''
classVariableNames: ''
maps: 'pointanimationbase'
!
PointAnimationBase subclass: #PointAnimation
instanceVariableNames: ''
classVariableNames: ''
maps: 'pointanimation'
!
PointAnimation class
!
from: aPoint1 to: aPoint2 duration: aDuration
  <primitive: 'pointanimation .ctor point point duration'>
!
Timeline subclass: #TimelineGroup
instanceVariableNames: ''
classVariableNames: ''
maps: 'timelinegroup'
!
TimelineGroup subclass: #ParallelTimeline
instanceVariableNames: ''
classVariableNames: ''
maps: 'paralleltimeline'
!
ParallelTimeline subclass: #StoryBoard
instanceVariableNames: ''
classVariableNames: ''
maps: 'storyboard'
!
StoryBoard class
!
getTargetName: aDependencyObject 
  <primitive: 'storyboard gettargetname dependencyobject'>
!
getTargetProperty: aDependencyObject 
  <primitive: 'storyboard gettargetproperty dependencyobject'>
!
new
  <primitive: 'storyboard .ctor'>
!
setTargetName: aDependencyObject to: aString
  <primitive: 'storyboard settargetname dependencyobject string'>
!
setTargetProperty: aDependencyObject to: aPropertyPath
  <primitive: 'storyboard settargetproperty dependencyobject propertypath'>
!
StoryBoard
!
begin: aFrameworkElement
  <primitive: 'storyboard begin frameworkelement'>
!
children
  <primitive: 'storyboard get_children'>
!
Animatible subclass: #TimelineCollection
instanceVariableNames: ''
classVariableNames: ''
maps: 'timelinecollection'
!
TimelineCollection class
!
new
  <primitive: 'timelinecollection .ctor'>
!
TimelineCollection
!
add: aTimeLine
  <primitive: 'timelinecollection add timeline'>
!
clear
  <primitive: 'timelinecollection clear'>
!
Freezable subclass: #Int32Collection
instanceVariableNames: ''
classVariableNames: ''
maps: 'int32collection'
!
Int32Collection class
!
parse: aString
  <primitive: 'int32collection parse string'>
!
Freezable subclass: #Point3DCollection
instanceVariableNames: ''
classVariableNames: ''
maps: 'point3dcollection'
!
Point3DCollection class
!
parse: aString
  <primitive: 'point3dcollection parse string'>
!
Freezable subclass: #PointCollection
instanceVariableNames: ''
classVariableNames: ''
maps: 'pointcollection'
!
PointCollection class
!
parse: aString
  <primitive: 'pointcollection parse string'>
!
Freezable subclass: #Vector3DCollection
instanceVariableNames: ''
classVariableNames: ''
maps: 'vector3dcollection'
!
Vector3DCollection class
!
parse: aString
  <primitive: 'vector3dcollection parse string'>
!
DependencyObject subclass: #TriggerBase
instanceVariableNames: ''
classVariableNames: ''
maps: 'triggerbase'
!
TriggerBase subclass: #EventTrigger
instanceVariableNames: ''
classVariableNames: ''
maps: 'eventtrigger'
!
EventTrigger class
!
new
  <primitive: 'eventtrigger .ctor'>
!
EventTrigger
!
actions
  <primitive: 'eventtrigger get_actions'>
!
routedEvent
  <primitive: 'eventtrigger get_routedevent'>
!
routedEvent: aRoutedEvent
  <primitive: 'eventtrigger set_routedevent routedevent'>
!
DependencyObject subclass: #Visual
instanceVariableNames: ''
classVariableNames: ''
maps: 'visual'
!
Visual subclass: #UIElement
instanceVariableNames: ''
classVariableNames: ''
maps: 'uielement'
!
UIElement
!
mouseEnterEvent
  <primitive: 'uielement mouseenterevent'>
!
renderTransform
  <primitive: 'uielement get_rendertransform'>
!
renderTransform: aTransform
  <primitive: 'uielement set_rendertransform transform'>
!
UIElement subclass: #FrameworkElement
instanceVariableNames: ''
classVariableNames: ''
maps: 'frameworkelement'
!
FrameworkElement
!
actualHeight
  <primitive: 'frameworkelement get_actualheight'>
!
actualWidth
  <primitive: 'frameworkelement get_actualwidth'>
!
contextMenu
  <primitive: 'frameworkelement get_contextmenu'>
!
contextMenu: aMenu
  <primitive: 'frameworkelement set_contextmenu contextmenu'>
!
expandToFill
  self horizontalAlignment: 'Stretch'.
  self verticalAlignment: 'Stretch'.
  self width: Double nan; height: Double nan.
  self margin: (Thickness new: 0)
!
findName: aString
  <primitive: 'frameworkelement findname string'>
!
height
  <primitive: 'frameworkelement get_height'>
!
height: aDouble
  <primitive: 'frameworkelement set_height double'>
!
horizontalAlignment
  <primitive: 'frameworkelement get_horizontalalignment'>
!
horizontalAlignment: anAlignment
  <primitive: 'frameworkelement set_horizontalalignment horizontalalignment'>
!
isEnabled
  <primitive: 'frameworkelement get_isenabled'>
!
isEnabled: aBoolean
  <primitive: 'frameworkelement set_isenabled bool'>
!
location: x y: y
  self margin: (Thickness newLeft: x top: y right: 0 bottom: 0)
!
margin
  <primitive: 'frameworkelement get_margin'>
!
margin: aThickness
  <primitive: 'frameworkelement set_margin thickness'>
!
margins: aDouble
  self margin: (Thickness new: aDouble)
!
name
  <primitive: 'frameworkelement get_name'>
!
name: aString
  <primitive: 'frameworkelement set_name string'>
!
parent
  <primitive: 'frameworkelement get_parent'>
!
registerName: aString for: anObject
  <primitive: 'frameworkelement registername string object'>
!
renderTransform
  <primitive: 'frameworkelement get_rendertransform'>
!
renderTransform: aTransform
  <primitive: 'frameworkelement set_rendertransform transform'>
!
renderTransformOrigin
  <primitive: 'frameworkelement get_rendertransformorigin'>
!
renderTransformOrigin: aPoint
  <primitive: 'frameworkelement set_rendertransformorigin point'>
!
show
  OnePane openOn: self
!
tag
  <primitive: 'frameworkelement get_tag'>
!
tag: anObject
  <primitive: 'frameworkelement set_tag object'>
!
tofront
  self parent children tofront: self
!
triggers
  <primitive: 'frameworkelement get_triggers'>
!
verticalAlignment
  <primitive: 'frameworkelement get_verticalalignment'>
!
verticalAlignment: anAlignment
  <primitive: 'frameworkelement set_verticalalignment verticalalignment'>
!
width
  <primitive: 'frameworkelement get_width'>
!
width: aDouble
  <primitive: 'frameworkelement set_width double'>
!
widthProperty
  <primitive: 'frameworkelement widthproperty'>
!
widthProperty: aDependencyObject
  <primitive: 'frameworkelement widthproperty dependencyobject'>
!
FrameworkElement subclass: #ContentPresenter
instanceVariableNames: ''
classVariableNames: ''
maps: 'contentpresenter'
!
ContentPresenter class
!
new
  <primitive: 'contentpresenter .ctor'>
!
ContentPresenter
!
content
  <primitive: 'contentpresenter get_content'>
!
content: anObject
  <primitive: 'contentpresenter set_content object'>
!
FrameworkElement subclass: #Control
instanceVariableNames: ''
classVariableNames: ''
maps: 'control'
!
Control
!
background
  <primitive: 'control get_background'>
!
background: aBrush
  <primitive: 'control set_background brush'>
!
borderbrush
  <primitive: 'control get_borderbrush'>
!
borderbrush: aBrush
  <primitive: 'control set_borderbrush brush'>
!
borderthickness
  <primitive: 'control get_borderthickness'>
!
borderthickness: aThickness
  <primitive: 'control set_borderthickness thickness'>
!
fontsize
  <primitive: 'control get_fontsize'>
!
fontsize: aDouble
  <primitive: 'control set_fontsize double'>
!
fontweight
  <primitive: 'control get_fontweight'>
!
fontweight: aFontWeight
  <primitive: 'control set_fontweight fontweight'>
!
foreground
  <primitive: 'control get_foreground'>
!
foreground: aBrush
  <primitive: 'control set_foreground brush'>
!
horizontalContentAlignment
  <primitive: 'control get_horizontalcontentalignment'>
!
horizontalContentAlignment: aHorizontalAlignment
  <primitive: 'control set_horizontalcontentalignment horizontalalignment'>
!
isenabled
  <primitive: 'control get_isenabled'>
!
isenabled: aBoolean
  <primitive: 'control set_isenabled bool'>
!
padding
  <primitive: 'control get_padding'>
!
padding: aThickness
  <primitive: 'control set_padding thickness'>
!
Control subclass: #ContentControl
instanceVariableNames: ''
classVariableNames: ''
maps: 'contentcontrol'
!
ContentControl
!
content
  <primitive: 'contentcontrol get_content'>
!
content: anObject
  <primitive: 'contentcontrol set_content object'>
!
ContentControl subclass: #ButtonBase
instanceVariableNames: ''
classVariableNames: ''
maps: 'buttonbase'
!
ButtonBase subclass: #Button
instanceVariableNames: ''
classVariableNames: ''
maps: 'button'
!
Button class
!
content: aContent callback: aBlock
  | btn |
  btn := self new.
  btn content: aContent.
  Handler on: btn event: 'Click' block: aBlock.
  ^ btn
!
new
  <primitive: 'button .ctor'>
!
Button
!
isButton
  ^ true
!
ButtonBase subclass: #ToggleButton
instanceVariableNames: ''
classVariableNames: ''
maps: 'togglebutton'
!
ToggleButton subclass: #RadioButton
instanceVariableNames: ''
classVariableNames: ''
maps: 'radiobutton'
!
RadioButton class
!
new
  <primitive: 'radiobutton .ctor'>
!
RadioButton
!
ischecked
  <primitive: 'radiobutton get_ischecked'>
!
ischecked: aBoolean
  <primitive: 'radiobutton set_ischecked bool'>
!
ContentControl subclass: #Frame
instanceVariableNames: ''
classVariableNames: ''
maps: 'frame'
!
Frame class
!
new
  <primitive: 'frame .ctor'>
!
Frame
!
navigateObject: anObject
  <primitive: 'frame navigate object'>
!
navigateObject: anObject1 with: anObject2
  <primitive: 'frame navigate object object'>
!
navigateUri: aUri
  <primitive: 'frame navigate uri'>
!
navigateUri: aUri with: anObject
  <primitive: 'frame navigate uri object'>
!
source
  <primitive: 'frame get_source'>
!
source: aUri
  <primitive: 'frame set_source uri'>
!
ContentControl subclass: #HeaderedContentControl
instanceVariableNames: ''
classVariableNames: ''
maps: 'headeredcontentcontrol'
!
HeaderedContentControl
!
header
  <primitive: 'headeredcontentcontrol get_header'>
!
header: anObject
  <primitive: 'headeredcontentcontrol set_header object'>
!
HeaderedContentControl subclass: #TabItem
instanceVariableNames: ''
classVariableNames: ''
maps: 'tabitem'
!
TabItem class
!
new
  <primitive: 'tabitem .ctor'>
!
ContentControl subclass: #Label
instanceVariableNames: ''
classVariableNames: ''
maps: 'label'
!
Label class
!
new
  <primitive: 'label .ctor'>
!
ContentControl subclass: #ListBoxItem
instanceVariableNames: ''
classVariableNames: ''
maps: 'listboxitem'
!
ListBoxItem class
!
new
  <primitive: 'listboxitem .ctor'>
!
ContentControl subclass: #UserControl
instanceVariableNames: ''
classVariableNames: ''
maps: 'usercontrol'
!
UserControl subclass: #Designer
instanceVariableNames: ''
classVariableNames: ''
maps: 'designer'
!
Designer class
!
new
  <primitive: 'designer .ctor'>
!
Designer
!
view
  <primitive: 'designer get_view'>
!
UserControl subclass: #TextEditor
instanceVariableNames: ''
classVariableNames: ''
maps: 'texteditor'
!
TextEditor class
!
new
  <primitive: 'texteditor .ctor'>
!
TextEditor
!
appendText: aString
  <primitive: 'texteditor appendtext string'>
!
background
  <primitive: 'texteditor editorbackground'>
!
background: aBrush
  <primitive: 'texteditor editorbackground brush'>
!
clearBreakpoints
  <primitive: 'texteditor clearbreakpoints'>
!
contextMenu
  <primitive: 'texteditor editorcontextmenu'>
!
contextMenu: aMenu
  <primitive: 'texteditor editorcontextmenu contextmenu'>
!
foreground
  <primitive: 'texteditor editorforeground'>
!
foreground: aBrush
  <primitive: 'texteditor editorforeground brush'>
!
insertAtEndOfSelection: aString
  <primitive: 'texteditor insertatendofselection string'>
!
println: aString
  self appendText: aString + Environment newline
!
selectedText
  <primitive: 'texteditor get_selectedtext'>
!
selectedText: aString
  <primitive: 'texteditor set_selectedtext string'>
!
selectionLength
  <primitive: 'texteditor get_selectionlength'>
!
selectionLength: anInteger
  <primitive: 'texteditor set_selectionlength int'>
!
selectionStart
  <primitive: 'texteditor get_selectionstart'>
!
selectionStart: anInteger
  <primitive: 'texteditor set_selectionstart int'>
!
setMethod: aMethod
  <primitive: 'texteditor setmethod ibreakpoints'>
!
showBreakpoints
  <primitive: 'texteditor get_showbreakpoints'>
!
showBreakpoints: aBoolean
  <primitive: 'texteditor set_showbreakpoints bool'>
!
showLines
  <primitive: 'texteditor get_showlines'>
!
showLines: aBoolean
  <primitive: 'texteditor set_showlines bool'>
!
text
  <primitive: 'texteditor get_text'>
!
text: aString
  <primitive: 'texteditor set_text string'>
!
UserControl subclass: #Trackport3D
instanceVariableNames: ''
classVariableNames: ''
maps: 'trackport3d'
!
Trackport3D class
!
new
  <primitive: 'trackport3d .ctor'>
!
Trackport3D
!
model
  <primitive: 'trackport3d get_model'>
!
model: aModel3D
  <primitive: 'trackport3d set_model model3d'>
!
viewmode
  <primitive: 'trackport3d get_viewmode'>
!
viewmode: aString
  <primitive: 'trackport3d set_viewmode string'>
!
ContentControl subclass: #Window
instanceVariableNames: ''
classVariableNames: ''
maps: 'window'
!
Window class
!
new
  | w |
  w := self newPrim.
  w width: 300; height: 250.
  ^ w
!
newPrim
  <primitive: 'window .ctor'>
!
open
  | w |
  w := self new.
  w open.
  ^ w
!
Window
!
add: anElement
  anElement width: Double nan; height: Double nan.
  self content: anElement
!
clear
  self add: Canvas new
!
color: aColor
  ^ nil
!
content
  <primitive: 'window get_content'>
!
content: anObject
  <primitive: 'window set_content object'>
!
height
  <primitive: 'window get_height'>
!
height: aDouble
  <primitive: 'window set_height double'>
!
left
  <primitive: 'window get_left'>
!
left: aDouble
  <primitive: 'window set_left double'>
!
open
  self show
!
show
  <primitive: 'window show'>
!
showDialog
  <primitive: 'window showdialog'>
!
title
  <primitive: 'window get_title'>
!
title: aString
  <primitive: 'window set_title string'>
!
top
  <primitive: 'window get_top'>
!
top: aDouble
  <primitive: 'window set_top double'>
!
width
  <primitive: 'window get_width'>
!
width: aDouble
  <primitive: 'window set_width double'>
!
Control subclass: #ItemsControl
instanceVariableNames: ''
classVariableNames: ''
maps: 'itemscontrol'
!
ItemsControl
!
add: anObject
  self items add: anObject
!
clear
  self items clear
!
items
  <primitive: 'itemscontrol get_items'>
!
ItemsControl subclass: #HeaderedItemsControl
instanceVariableNames: ''
classVariableNames: ''
maps: 'headereditemscontrol'
!
HeaderedItemsControl
!
header
  <primitive: 'headereditemscontrol get_header'>
!
header: anObject
  <primitive: 'headereditemscontrol set_header object'>
!
items
  <primitive: 'headereditemscontrol get_items'>
!
HeaderedItemsControl subclass: #MenuItem
instanceVariableNames: ''
classVariableNames: ''
maps: 'menuitem'
!
MenuItem class
!
name: aName action: aBlock
  | mi |
  mi := self new.
  mi header: aName.
  mi addEvent: 'Click' action: aBlock.
  ^ mi
!
new
  <primitive: 'menuitem .ctor'>
!
MenuItem
!
name: aName action: aBlock
  | mi |
  mi := self new.
  mi header: aName.
  mi addEvent: 'Click' action: aBlock.
  ^ mi
!
HeaderedItemsControl subclass: #TreeViewItem
instanceVariableNames: ''
classVariableNames: ''
maps: 'treeviewitem'
!
TreeViewItem class
!
new
  <primitive: 'treeviewitem .ctor'>
!
ItemsControl subclass: #MenuBase
instanceVariableNames: ''
classVariableNames: ''
maps: 'menubase'
!
MenuBase
!
add: anItem
  self items add: anItem
!
MenuBase subclass: #ContextMenu
instanceVariableNames: ''
classVariableNames: ''
maps: 'contextmenu'
!
ContextMenu class
!
new
  <primitive: 'contextmenu .ctor'>
!
ContextMenu
!
items
  <primitive: 'contextmenu get_items'>
!
MenuBase subclass: #Menu
instanceVariableNames: ''
classVariableNames: ''
maps: 'menu'
!
Menu class
!
new
  <primitive: 'menu .ctor'>
!
Menu
!
items
  <primitive: 'menu get_items'>
!
ItemsControl subclass: #Selector
instanceVariableNames: ''
classVariableNames: ''
maps: 'selector'
!
Selector
!
selectedIndex
  <primitive: 'selector get_selectedindex'>
!
selectedIndex: anIndex
  <primitive: 'selector set_selectedindex int'>
!
selectedItem
  <primitive: 'selector get_selecteditem'>
!
selectedItem: anObject
  <primitive: 'selector set_selecteditem object'>
!
selectedValue
  <primitive: 'selector get_selectedvalue'>
!
selectedValue: aValue
  <primitive: 'selector set_selectedvalue object'>
!
Selector subclass: #ComboBox
instanceVariableNames: ''
classVariableNames: ''
maps: 'combobox'
!
ComboBox class
!
new
  <primitive: 'combobox .ctor'>
!
Selector subclass: #ListBox
instanceVariableNames: ''
classVariableNames: ''
maps: 'listbox'
!
ListBox class
!
new
  <primitive: 'listbox .ctor'>
!
Selector subclass: #TabControl
instanceVariableNames: ''
classVariableNames: ''
maps: 'tabcontrol'
!
TabControl class
!
new
  <primitive: 'tabcontrol .ctor'>
!
TabControl
!
selectedIndex
  <primitive: 'tabcontrol get_selectedindex'>
!
tabStripPlacement
  <primitive: 'tabcontrol get_tabstripplacement'>
!
tabStripPlacement: aDock
  <primitive: 'tabcontrol set_tabstripplacement dock'>
!
ItemsControl subclass: #TreeView
instanceVariableNames: ''
classVariableNames: ''
maps: 'treeview'
!
TreeView class
!
new
  <primitive: 'treeview .ctor'>
!
TreeView
!
selectedItem
  <primitive: 'treeview get_selecteditem'>
!
Control subclass: #RangeBase
instanceVariableNames: ''
classVariableNames: ''
maps: 'rangebase'
!
RangeBase
!
maximum
  <primitive: 'rangebase get_maximum'>
!
maximum: aDouble
  <primitive: 'rangebase set_maximum double'>
!
minimum
  <primitive: 'rangebase get_minimum'>
!
minimum: aDouble
  <primitive: 'rangebase set_minimum double'>
!
value
  <primitive: 'rangebase get_value'>
!
value: aDouble
  <primitive: 'rangebase set_value double'>
!
RangeBase subclass: #Slider
instanceVariableNames: ''
classVariableNames: ''
maps: 'slider'
!
Slider class
!
new
  <primitive: 'slider .ctor'>
!
Control subclass: #Separator
instanceVariableNames: ''
classVariableNames: ''
maps: 'separator'
!
Separator class
!
new
  <primitive: 'separator .ctor'>
!
Control subclass: #TextBoxBase
instanceVariableNames: ''
classVariableNames: ''
maps: 'textboxbase'
!
TextBoxBase
!
acceptsReturn
  <primitive: 'textboxbase get_acceptsreturn'>
!
acceptsReturn: aBoolean
  <primitive: 'textboxbase set_acceptsreturn bool'>
!
appendText: aString
  <primitive: 'textboxbase appendtext string'>
!
hideSelection
  <primitive: 'textboxbase get_hideselection'>
!
hideSelection: aBoolean
  <primitive: 'textboxbase set_hideselection bool'>
!
horizontalScrollBarVisibility
  <primitive: 'textboxbase get_horizontalscrollbarvisibility'>
!
horizontalScrollBarVisibility: aVisibility
  <primitive: 'textboxbase set_horizontalscrollbarvisibility scrollbarvisibility'>
!
verticalScrollBarVisibility
  <primitive: 'textboxbase get_verticalscrollbarvisibility'>
!
verticalScrollBarVisibility: aVisibility
  <primitive: 'textboxbase set_verticalscrollbarvisibility scrollbarvisibility'>
!
TextBoxBase subclass: #TextBox
instanceVariableNames: ''
classVariableNames: ''
maps: 'textbox'
!
TextBox class
!
new
  ^ self newprim init
!
newprim
  <primitive: 'textbox .ctor'>
!
TextBox
!
clear
  self text: ''
!
init
  self acceptsReturn: true;
       width: Double nan;
       height: Double nan;
       background: Brushes ivory;
       foreground: Brushes navy;
       horizontalScrollBarVisibility: 'Auto';
       verticalScrollBarVisibility: 'Auto'
!
print: aString
  self appendText: aString
!
println: aString
  self appendText: aString + Environment newline
!
selectedText
  <primitive: 'textbox get_selectedtext'>
!
selectedText: aString
  <primitive: 'textbox set_selectedtext string'>
!
selectionLength
  <primitive: 'textbox get_selectionlength'>
!
selectionLength: anInt
  <primitive: 'textbox set_selectionlength int'>
!
selectionStart
  <primitive: 'textbox get_selectionStart'>
!
selectionStart: anInt
  <primitive: 'textbox set_selectionstart int'>
!
text
  <primitive: 'textbox get_text'>
!
text: aString
  <primitive: 'textbox set_text string'>
!
textalignment
  <primitive: 'textbox get_textalignment'>
!
textalignment: aTextAlignment
  <primitive: 'textbox set_textalignment textalignment'>
!
textwrapping
  <primitive: 'textbox get_textwrapping'>
!
textwrapping: aWrapping
  <primitive: 'textbox set_textwrapping textwrapping'>
!
Control subclass: #Thumb
instanceVariableNames: ''
classVariableNames: ''
maps: 'thumb'
!
Thumb subclass: #GridSplitter
instanceVariableNames: ''
classVariableNames: ''
maps: 'gridsplitter'
!
GridSplitter class
!
new
  <primitive: 'gridsplitter .ctor'>
!
FrameworkElement subclass: #Decorator
instanceVariableNames: ''
classVariableNames: ''
maps: 'decorator'
!
Decorator
!
child
  <primitive: 'decorator get_child'>
!
child: aUiElement
  <primitive: 'decorator set_child uielement'>
!
Decorator subclass: #Border
instanceVariableNames: ''
classVariableNames: ''
maps: 'border'
!
Border class
!
new
  <primitive: 'border .ctor'>
!
Border
!
background
  <primitive: 'border get_background'>
!
background: aBrush
  <primitive: 'border set_background brush'>
!
borderBrush
  <primitive: 'border get_borderbrush'>
!
borderBrush: aBrush
  <primitive: 'border set_borderbrush brush'>
!
borderThickness
  <primitive: 'border get_borderthickness'>
!
borderThickness: aThickness
  <primitive: 'border set_borderthickness thickness'>
!
child
  <primitive: 'border get_child'>
!
child: aUiElement
  <primitive: 'border set_child uielement'>
!
Border subclass: #MdiChildBase
instanceVariableNames: ''
classVariableNames: ''
maps: 'mdichildbase'
!
MdiChildBase
!
close
  <primitive: 'mdichildbase close'>
!
color: aColor
  <primitive: 'mdichildbase setbordercolor color'>
!
location: x y: y
  <primitive: 'mdichildbase location double double'>
!
open
  <primitive: 'mdichildbase open'>
!
size: w height: h
  <primitive: 'mdichildbase size double double'>
!
tofront
  <primitive: 'mdichildbase tofront'>
!
MdiChildBase subclass: #DesktopWindow
instanceVariableNames: ''
classVariableNames: ''
maps: 'vdesktopwindow'
!
DesktopWindow class
!
new
  <primitive: 'vdesktopwindow .ctor'>
!
new: aColor
  <primitive: 'vdesktopwindow .ctor color'>
!
open
  | w |
  w := self new.
  w open.
  ^ w
!
DesktopWindow
!
add: anElement
  anElement width: Double nan; height: Double nan.
  self content: anElement
!
clear
  self add: Canvas new
!
content
  <primitive: 'vdesktopwindow get_content'>
!
content: aUiElement
  <primitive: 'vdesktopwindow set_content uielement'>
!
title
  <primitive: 'vdesktopwindow get_title'>
!
title: aString
  <primitive: 'vdesktopwindow set_title string'>
!
Decorator subclass: #ViewBox
instanceVariableNames: ''
classVariableNames: ''
maps: 'viewbox'
!
FrameworkElement subclass: #HwndHost
instanceVariableNames: ''
classVariableNames: ''
maps: 'hwndhost'
!
HwndHost subclass: #WindowsFormsHost
instanceVariableNames: ''
classVariableNames: ''
maps: 'windowsformshost'
!
WindowsFormsHost class
!
new
  <primitive: 'windowsformshost .ctor'>
!
WindowsFormsHost
!
child
  <primitive: 'windowsformshost get_child'>
!
child: aWfControl
  <primitive: 'windowsformshost set_child wfcontrol'>
!
FrameworkElement subclass: #InkCanvas
instanceVariableNames: ''
classVariableNames: ''
maps: 'inkcanvas'
!
InkCanvas class
!
new
  <primitive: 'inkcanvas .ctor'>
!
InkCanvas
!
background
  <primitive: 'inkcanvas get_background'>
!
background: aBrush
  <primitive: 'inkcanvas set_background brush'>
!
editingMode
  <primitive: 'inkcanvas get_editingmode'>
!
editingMode: anInkCanvasEditingMode
  <primitive: 'inkcanvas set_editingmode inkcanvaseditingmode'>
!
FrameworkElement subclass: #Panel
instanceVariableNames: ''
classVariableNames: ''
maps: 'panel'
!
Panel
!
add: anElement
  self children add: anElement
!
background
  <primitive: 'panel get_background'>
!
background: aBrush
  <primitive: 'panel set_background brush'>
!
children
  <primitive: 'panel get_children'>
!
clear
  self children clear
!
clipToBounds
  <primitive: 'panel get_cliptobounds'>
!
clipToBounds: aBoolean
  <primitive: 'panel set_cliptobounds bool'>
!
getZindex: anElement
  <primitive: 'panel getzindex uielement'>
!
setZindex: anElement to: anInt
  <primitive: 'panel setzindex uielement int'>
!
Panel subclass: #Canvas
instanceVariableNames: ''
classVariableNames: ''
maps: 'canvas'
!
Canvas class
!
getBottom: anElement
  <primitive: 'canvas getbottom uielement'>
!
getLeft: anElement
  <primitive: 'canvas getleft uielement'>
!
getRight: anElement
  <primitive: 'canvas getright uielement'>
!
getTop: anElement
  <primitive: 'canvas gettop uielement'>
!
leftProperty
  <primitive: 'canvas leftproperty'>
!
new
  <primitive: 'canvas .ctor'>
!
setBottom: anElement to: aDouble
  <primitive: 'canvas setbottom uielement double'>
!
setLeft: anElement to: aDouble
  <primitive: 'canvas setleft uielement double'>
!
setRight: anElement to: aDouble
  <primitive: 'canvas setright uielement double'>
!
setTop: anElement to: aDouble
  <primitive: 'canvas settop uielement double'>
!
topProperty
  <primitive: 'canvas topproperty'>
!
Panel subclass: #DockPanel
instanceVariableNames: ''
classVariableNames: ''
maps: 'dockpanel'
!
DockPanel class
!
new
  <primitive: 'dockpanel .ctor'>
!
setDock: aUiElement to: aDock
  <primitive: 'dockpanel setdock uielement dock'>
!
DockPanel
!
lastChildFill
  <primitive: 'dockpanel get_lastchildfill'>
!
lastChildFill: aBoolean
  <primitive: 'dockpanel set_lastchildfill bool'>
!
Panel subclass: #Grid
instanceVariableNames: ''
classVariableNames: ''
maps: 'grid'
!
Grid class
!
hsplit: percent child1: c1 child2: c2
  ^ self new hsplit: percent child1: c1 child2: c2
!
hsplit: aBrush child1: c1 child2: c2 child3: c3 child4: c4
  ^ self new hsplit: aBrush child1: c1 child2: c2 child3: c3 child4: c4
!
new
  <primitive: 'grid .ctor'>
!
setColumn: anElement to: anInt
  <primitive: 'grid setcolumn uielement int'>
!
setRow: anElement to: anInt
  <primitive: 'grid setrow uielement int'>
!
vsplit: percent child1: c1 child2: c2
  ^ self new vsplit: percent child1: c1 child2: c2
!
Grid
!
columnDefinitions
  <primitive: 'grid get_columnDefinitions'>
!
hsplit: percent child1: c1 child2: c2
  | splitter |
  self columnDefinitions add: (ColumnDefinition star: percent).
  self columnDefinitions add: (ColumnDefinition star: 1 - percent).
  splitter := GridSplitter new.
  splitter horizontalAlignment: HorizontalAlignment right.
  splitter width: 3.
  splitter background: (SolidColorBrush new: Color customOrange).
  Grid setColumn: splitter to: 0.
  Grid setColumn: c1 to: 0.
  Grid setColumn: c2 to: 1.
  self children add: c1.
  self children add: splitter.
  self children add: c2.
  c1 expandToFill.
  c2 expandToFill.
  c1 margin: (Thickness newLeft: 0 top: 0 right: 3 bottom: 0)
!
hsplit: aBrush child1: c1 child2: c2 child3: c3 child4: c4
  | splitter1 splitter2 splitter3 |
  self columnDefinitions add: (ColumnDefinition star: 0.25).
  self columnDefinitions add: (ColumnDefinition star: 0.25).
  self columnDefinitions add: (ColumnDefinition star: 0.25).
  self columnDefinitions add: (ColumnDefinition star: 0.25).
  splitter1 := GridSplitter new.
  splitter1 horizontalAlignment: HorizontalAlignment right.
  splitter1 width: 3.
  splitter1 background: aBrush.
  splitter2 := GridSplitter new.
  splitter2 horizontalAlignment: HorizontalAlignment right.
  splitter2 width: 3.
  splitter2 background: aBrush.
  splitter3 := GridSplitter new.
  splitter3 horizontalAlignment: HorizontalAlignment right.
  splitter3 width: 3.
  splitter3 background: aBrush.
  Grid setColumn: splitter1 to: 0.
  Grid setColumn: splitter2 to: 1.
  Grid setColumn: splitter3 to: 2.
  Grid setColumn: c1 to: 0.
  Grid setColumn: c2 to: 1.
  Grid setColumn: c3 to: 2.
  Grid setColumn: c4 to: 3.
  self children add: c1.
  self children add: splitter1.
  self children add: c2.
  self children add: splitter2.
  self children add: c3.
  self children add: splitter3.
  self children add: c4.
  c1 expandToFill.
  c2 expandToFill.
  c3 expandToFill.
  c4 expandToFill.
  c1 margin: (Thickness newLeft: 0 top: 0 right: 3 bottom: 0).
  c2 margin: (Thickness newLeft: 0 top: 0 right: 3 bottom: 0).
  c3 margin: (Thickness newLeft: 0 top: 0 right: 3 bottom: 0)
!
rowDefinitions
  <primitive: 'grid get_rowDefinitions'>
!
vsplit: percent child1: c1 child2: c2
  | splitter |
  self rowDefinitions add: (RowDefinition star: percent).
  self rowDefinitions add: (RowDefinition star: 1 - percent).
  splitter := GridSplitter new.
  splitter horizontalAlignment: HorizontalAlignment stretch.
  splitter verticalAlignment: VerticalAlignment bottom.
  splitter height: 3.
  splitter width: Double nan.
  splitter background: (SolidColorBrush new: Color customOrange).
  Grid setRow: splitter to: 0.
  Grid setRow: c1 to: 0.
  Grid setRow: c2 to: 1.
  self children add: c1.
  self children add: splitter.
  self children add: c2.
  c1 expandToFill.
  c2 expandToFill.
  c1 margin: (Thickness newLeft: 0 top: 0 right: 0 bottom: 3)
!
Grid subclass: #View
instanceVariableNames: ''
classVariableNames: ''
maps: 'view'
!
View class
!
new
  <primitive: 'view .ctor'>
!
views
  <primitive: 'view get_views'>
!
View
!
designMode
  <primitive: 'view get_designmode'>
!
designMode: aBoolean
  <primitive: 'view set_designmode bool'>
!
find: aString
  <primitive: 'view find string'>
!
findAndRemove: aString
  <primitive: 'view findandremove string'>
!
generate
  <primitive: 'view generate'>
!
generate: aClassName parent: aSuperClassName
  <primitive: 'view generate string string'>
!
id
  <primitive: 'view get_id'>
!
isDraggable: aUiElement
  <primitive: 'view getdraggable uielement'>
!
keepInBounds
  <primitive: 'view get_keepinbounds'>
!
keepInBounds: aBoolean
  <primitive: 'view set_keepinbounds bool'>
!
packager
  <primitive: 'view get_packager'>
!
setDraggable: aUiElement to: aBoolean
  <primitive: 'view setdraggable uielement bool'>
!
setLocation: aName x: aDouble1 y: aDouble2
  <primitive: 'view setlocation string double double'>
!
Panel subclass: #StackPanel
instanceVariableNames: ''
classVariableNames: ''
maps: 'stackpanel'
!
StackPanel class
!
horizontal
  | sp |
  sp := self new.
  sp orientation: Orientation horizontal.
  ^ sp
!
new
  <primitive: 'stackpanel .ctor'>
!
vertical
  | sp |
  sp := self new.
  sp orientation: Orientation vertical.
  ^ sp
!
StackPanel
!
orientation
  <primitive: 'stackpanel get_orientation'>
!
orientation: anOrientation
  <primitive: 'stackpanel set_orientation orientation'>
!
FrameworkElement subclass: #Popup
instanceVariableNames: ''
classVariableNames: ''
maps: 'popup'
!
FrameworkElement subclass: #Shape
instanceVariableNames: ''
classVariableNames: ''
maps: 'shape'
!
Shape class
!
new
  ^ self newprim init
!
Shape
!
black
  self fill: Brushes black
!
blue
  self fill: Brushes blue.
  ^ self
!
fill
  <primitive: 'shape get_fill'>
!
fill: aBrush
  <primitive: 'shape set_fill brush'>
!
green
  self fill: Brushes green
!
init
  self size: 50; blue
!
opacity
  <primitive: 'control get_opacity'>
!
opacity: aDouble
  <primitive: 'shape set_opacity double'>
!
red
  self fill: Brushes red
!
size: anInteger
  self height: anInteger; width: anInteger
!
stroke
  <primitive: 'control get_stroke'>
!
stroke: aBrush
  <primitive: 'shape set_stroke brush'>
!
strokethickness
  <primitive: 'shape get_strokethickness'>
!
strokethickness: aDouble
  <primitive: 'shape set_strokethickness double'>
!
yellow
  self fill: Brushes yellow
!
Shape subclass: #Ellipse
instanceVariableNames: ''
classVariableNames: ''
maps: 'ellipse'
!
Ellipse class
!
newprim
  <primitive: 'ellipse .ctor'>
!
Ellipse
!
radius: aDouble
  self width: aDouble; height: aDouble
!
Shape subclass: #Line
instanceVariableNames: ''
classVariableNames: ''
maps: 'line'
!
Line class
!
from: aPoint1 to: aPoint2
  | line |
  line := self new.
  line x1: aPoint1 x.
  line y1: aPoint1 y.
  line x2: aPoint2 x.
  line y2: aPoint2 y.
  ^ line
!
newprim
  <primitive: 'line .ctor'>
!
Line
!
init
  self x1: 0;
       y1: 0;
       x2: 100;
       y2: 100;
       stroke: Brushes red;
       strokethickness: 10
!
x1
  <primitive: 'line get_x1'>
!
x1: aDouble
  <primitive: 'line set_x1 double'>
!
x2
  <primitive: 'line get_x2'>
!
x2: aDouble
  <primitive: 'line set_x2 double'>
!
y1
  <primitive: 'line get_y1'>
!
y1: aDouble
  <primitive: 'line set_y1 double'>
!
y2
  <primitive: 'line get_y2'>
!
y2: aDouble
  <primitive: 'line set_y2 double'>
!
Shape subclass: #Path
instanceVariableNames: ''
classVariableNames: ''
maps: 'path'
!
Path class
!
new
  <primitive: 'path .ctor'>
!
Path
!
data
  <primitive: 'path get_data'>
!
data: aGeometry
  <primitive: 'path set_data geometry'>
!
Shape subclass: #Polygon
instanceVariableNames: ''
classVariableNames: ''
maps: 'polygon'
!
Shape subclass: #Rectangle
instanceVariableNames: ''
classVariableNames: ''
maps: 'rectangle'
!
Rectangle class
!
newprim
  <primitive: 'rectangle .ctor'>
!
FrameworkElement subclass: #TextBlock
instanceVariableNames: ''
classVariableNames: ''
maps: 'textblock'
!
TextBlock class
!
new
  <primitive: 'textblock .ctor'>
!
new: aString
  | tb |
  tb := self new.
  tb text: aString.
  ^ tb
!
TextBlock
!
fontSize
  <primitive: 'textblock get_fontsize'>
!
fontSize: aDouble
  <primitive: 'textblock set_fontsize double'>
!
foreground
  <primitive: 'textblock get_foreground'>
!
foreground: aBrush
  <primitive: 'textblock set_foreground brush'>
!
text
  <primitive: 'textblock get_text'>
!
text: aString
  <primitive: 'textblock set_text string'>
!
Wpf subclass: #Duration
instanceVariableNames: ''
classVariableNames: ''
maps: 'duration'
!
Duration class
!
new: aDuration
  <primitive: 'duration .ctor timespan'>
!
Wpf subclass: #FontWeights
instanceVariableNames: ''
classVariableNames: ''
maps: 'fontweights'
!
FontWeights class
!
black
 <primitive: 'fontweights get_black'>
!
bold
 <primitive: 'fontweights get_bold'>
!
demibold
 <primitive: 'fontweights get_demibold'>
!
extrablack
 <primitive: 'fontweights get_extrablack'>
!
extrabold
 <primitive: 'fontweights get_extrabold'>
!
extralight
 <primitive: 'fontweights get_extralight'>
!
heavy
 <primitive: 'fontweights get_heavy'>
!
light
 <primitive: 'fontweights get_light'>
!
medium
 <primitive: 'fontweights get_medium'>
!
normal
 <primitive: 'fontweights get_normal'>
!
regular
 <primitive: 'fontweights get_regular'>
!
semibold
 <primitive: 'fontweights get_semibold'>
!
thin
 <primitive: 'fontweights get_thin'>
!
ultrablack
 <primitive: 'fontweights get_ultrablack'>
!
ultrabold
 <primitive: 'fontweights get_ultrabold'>
!
ultrathin
 <primitive: 'fontweights get_ultrathin'>
!
Wpf subclass: #INameScope
instanceVariableNames: ''
classVariableNames: ''
maps: 'inamescope'
!
Wpf subclass: #ItemCollection
instanceVariableNames: ''
classVariableNames: ''
maps: 'itemcollection'
!
ItemCollection
!
add: anObject
  <primitive: 'itemcollection add object'>
!
at: anInteger
  <primitive: 'itemcollection get_item int'>
!
clear
  <primitive: 'itemcollection clear'>
!
do: aBlock
  1 to: self size do:[:i | aBlock value: (self at: (i - 1))]
!
size
  <primitive: 'itemcollection get_count'>
!
Wpf subclass: #NameScope
instanceVariableNames: ''
classVariableNames: ''
maps: 'namescope'
!
NameScope class
!
new
  <primitive: 'namescope .ctor'>
!
setNameScope: aDependencyObject to: aNameScope
  <primitive: 'namescope setnamescope dependencyobject inamescope'>
!
Wpf subclass: #PropertyPath
instanceVariableNames: ''
classVariableNames: ''
maps: 'propertypath'
!
PropertyPath class
!
new: aDependencyProperty
  <primitive: 'propertypath .ctor object'>
!
Wpf subclass: #ResourceDictionary
instanceVariableNames: ''
classVariableNames: ''
maps: 'resourcedictionary'
!
Wpf subclass: #RowDefinitionCollection
instanceVariableNames: ''
classVariableNames: ''
maps: 'rowdefinitioncollection'
!
RowDefinitionCollection
!
add: aUiElement
  <primitive: 'rowdefinitioncollection add rowdefinition'>
!
Wpf subclass: #TriggerActionCollection
instanceVariableNames: ''
classVariableNames: ''
maps: 'triggeractioncollection'
!
TriggerActionCollection
!
add: aTriggerAction
  <primitive: 'triggeractioncollection add triggeraction'>
!
clear
  <primitive: 'triggeractioncollection clear'>
!
Wpf subclass: #TriggerCollection
instanceVariableNames: ''
classVariableNames: ''
maps: 'triggercollection'
!
TriggerCollection
!
add: aTriggerBase
  <primitive: 'triggercollection add triggerbase'>
!
clear
  <primitive: 'triggercollection clear'>
!
Wpf subclass: #UIElementCollection
instanceVariableNames: ''
classVariableNames: ''
maps: 'uielementcollection'
!
UIElementCollection
!
add: aTriggerAction
  <primitive: 'uielementcollection add uielement'>
!
at: index
  <primitive: 'uielementcollection get_item int'>
!
at: index put: anElement
  self removeAt: index.
  self insert: index element: anElement
!
clear
  <primitive: 'uielementcollection clear'>
!
do: aBlock
  1 to: self size do:[:i | aBlock value: (self at: (i - 1))]
!
insert: index element: anElement
  <primitive: 'uielementcollection insert int uielement'>
!
last
  ^ self at: self size - 1
!
remove: aUielement
  <primitive: 'uielementcollection remove uielement'>
!
removeAt: index
  <primitive: 'uielementcollection removeat int'>
!
size
  <primitive: 'uielementcollection count'>
!
tofront: aUielement
  self remove: aUielement; add: aUielement
!
Wpf subclass: #ValueType
instanceVariableNames: ''
classVariableNames: ''
!
ValueType subclass: #Enum
instanceVariableNames: ''
classVariableNames: ''
maps: 'enum'
!
Enum subclass: #Dock
instanceVariableNames: ''
classVariableNames: ''
maps: 'dock'
!
Dock class
!
bottom
  ^ Vm findEnum: 'dock' for: 'bottom'
!
left
  ^ Vm findEnum: 'dock' for: 'left'
!
right
  ^ Vm findEnum: 'dock' for: 'right'
!
top
  ^ Vm findEnum: 'dock' for: 'top'
!
Enum subclass: #GridUnitType
instanceVariableNames: ''
classVariableNames: ''
maps: 'gridunittype'
!
Enum subclass: #HorizontalAlignment
instanceVariableNames: ''
classVariableNames: ''
maps: 'horizontalalignment'
!
HorizontalAlignment class
!
center
  ^ Vm findEnum: 'horizontalalignment' for: 'center'
!
left
  ^ Vm findEnum: 'horizontalalignment' for: 'left'
!
right
  ^ Vm findEnum: 'horizontalalignment' for: 'right'
!
stretch
  ^ Vm findEnum: 'horizontalalignment' for: 'stretch'
!
Enum subclass: #InkCanvasEditingMode
instanceVariableNames: ''
classVariableNames: ''
maps: 'inkcanvaseditingmode'
!
InkCanvasEditingMode class
!
eraseByPoint
  ^ Vm findEnum: 'inkcanvaseditingmode' for: 'erasebypoint'
!
eraseByStroke
  ^ Vm findEnum: 'inkcanvaseditingmode' for: 'erasebystroke'
!
gestureOnly
  ^ Vm findEnum: 'inkcanvaseditingmode' for: 'gestureonly'
!
ink
  ^ Vm findEnum: 'inkcanvaseditingmode' for: 'ink'
!
inkAndGesture
  ^ Vm findEnum: 'inkcanvaseditingmode' for: 'inkandgesture'
!
none
  ^ Vm findEnum: 'inkcanvaseditingmode' for: 'none'
!
select
  ^ Vm findEnum: 'inkcanvaseditingmode' for: 'select'
!
Enum subclass: #Orientation
instanceVariableNames: ''
classVariableNames: ''
maps: 'orientation'
!
Orientation class
!
horizontal
  ^ Vm findEnum: 'orientation' for: 'horizontal'
!
vertical
  ^ Vm findEnum: 'orientation' for: 'vertical'
!
Enum subclass: #ScrollBarVisibility
instanceVariableNames: ''
classVariableNames: ''
maps: 'scrollbarvisibility'
!
ScrollBarVisibility class
!
auto
  ^ Vm findEnum: 'scrollbarvisibility' for: 'auto'
!
disabled
  ^ Vm findEnum: 'scrollbarvisibility' for: 'disabled'
!
hidden
  ^ Vm findEnum: 'scrollbarvisibility' for: 'hidden'
!
visible
  ^ Vm findEnum: 'scrollbarvisibility' for: 'visible'
!
Enum subclass: #TextAlignment
instanceVariableNames: ''
classVariableNames: ''
maps: 'textalignment'
!
TextAlignment class
!
center
  ^ Vm findEnum: 'textalignment' for: 'center'
!
justify
  ^ Vm findEnum: 'textalignment' for: 'justify'
!
left
  ^ Vm findEnum: 'textalignment' for: 'left'
!
right
  ^ Vm findEnum: 'textalignment' for: 'right'
!
Enum subclass: #TextWrapping
instanceVariableNames: ''
classVariableNames: ''
maps: 'textwrapping'
!
TextWrapping class
!
nowrap
  ^ Vm findEnum: 'textwrapping' for: 'nowrap'
!
wrap
  ^ Vm findEnum: 'textwrapping' for: 'wrap'
!
wrapWithOverflow
  ^ Vm findEnum: 'textwrapping' for: 'wrapwithoverflow'
!
Enum subclass: #VerticalAlignment
instanceVariableNames: ''
classVariableNames: ''
maps: 'verticalalignment'
!
VerticalAlignment class
!
bottom
  ^ Vm findEnum: 'verticalalignment' for: 'bottom'
!
center
  ^ Vm findEnum: 'verticalalignment' for: 'center'
!
stretch
  ^ Vm findEnum: 'verticalalignment' for: 'stretch'
!
top
  ^ Vm findEnum: 'verticalalignment' for: 'top'
!
Enum subclass: #WfDockStyle
instanceVariableNames: ''
classVariableNames: ''
maps: 'wfdockstyle'
!
WfDockStyle class
!
bottom
  ^ Vm findEnum: 'wfdockstyle' for: 'bottom'
!
fill
  ^ Vm findEnum: 'wfdockstyle' for: 'fill'
!
left
  ^ Vm findEnum: 'wfdockstyle' for: 'left'
!
right
  ^ Vm findEnum: 'wfdockstyle' for: 'right'
!
top
  ^ Vm findEnum: 'wfdockstyle' for: 'top'
!
ValueType subclass: #FontWeight
instanceVariableNames: ''
classVariableNames: ''
maps: 'fontweight'
!
ValueType subclass: #GridLength
instanceVariableNames: ''
classVariableNames: ''
maps: 'gridlength'
!
GridLength class
!
new: aDouble type: aGridUnitType
  <primitive: 'gridlength .ctor double gridunittype'>
!
star: aDouble
  ^ self new: aDouble type: (Vm findEnum: 'gridunittype' for: 'star')
!
ValueType subclass: #Matrix
instanceVariableNames: ''
classVariableNames: ''
maps: 'matrix'
!
Matrix class
!
m11: d1 m12: d2 m21: d3 m22: d4 x: d5 y: d6
  <primitive: 'matrix .ctor double double double double double double'>
!
Matrix
!
scaleX: aDouble1 y: aDouble2
  <primitive: 'matrix scale double double'>
!
skewX: aDouble1 y: aDouble2
  <primitive: 'matrix skew double double'>
!
translateX: aDouble1 y: aDouble2
  <primitive: 'matrix translate double double'>
!
ValueType subclass: #Point
instanceVariableNames: ''
classVariableNames: ''
maps: 'point'
!
Point class
!
x: d1 y: d2
  <primitive: 'point .ctor double double'>
!
Point
!
+ aPoint
  | x1 y1 x2 y2 |
  x1 := self x.
  y1 := self y.
  x2 := aPoint x.
  y2 := aPoint y.
  ^ Point x: x1+x2 y: y1+y2
!
x
  <primitive: 'point get_x'>
!
x: anInt
  <primitive: 'point set_x int'>
!
y
  <primitive: 'point get_y'>
!
y: anInt
  <primitive: 'point set_y int'>
!
ValueType subclass: #Thickness
instanceVariableNames: ''
classVariableNames: ''
maps: 'thickness'
!
Thickness class
!
left: n1 top: n2 right: n3 bottom: n4
  <primitive: 'thickness .ctor double double double double'>
!
new: aDouble
  <primitive: 'thickness .ctor double'>
!
newLeft: n1 top: n2 right: n3 bottom: n4
  <primitive: 'thickness .ctor double double double double'>
!
Thickness
!
bottom
  <primitive: 'thickness get_bottom'>
!
left
  <primitive: 'thickness get_left'>
!
right
  <primitive: 'thickness get_right'>
!
top
  <primitive: 'thickness get_top'>
!
ValueType subclass: #TimeSpan
instanceVariableNames: ''
classVariableNames: ''
maps: 'timespan'
!
TimeSpan class
!
fromSeconds: aDouble
  <primitive: 'timespan fromseconds double'>
!
$eval Transcript cr
$eval Transcript showCr: 'CalmoSoft Project for Vista Smalltalk'
$eval Transcript showCr: '[build 842] for Aug 30, 2013'
$eval PowerBrowser new open